Class: Aws::OpenSearchService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::OpenSearchService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-opensearchservice/client.rb,
sig/client.rbs
Overview
An API client for OpenSearchService. To construct a client, you need to configure a :region and :credentials.
client = Aws::OpenSearchService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptInboundConnectionResponseSuccess, _AddDataSourceResponseSuccess, _AddDirectQueryDataSourceResponseSuccess, _AssociatePackageResponseSuccess, _AssociatePackagesResponseSuccess, _AttachDataSourceResponseSuccess, _AuthorizeVpcEndpointAccessResponseSuccess, _CancelDomainConfigChangeResponseSuccess, _CancelServiceSoftwareUpdateResponseSuccess, _CreateApplicationResponseSuccess, _CreateDomainResponseSuccess, _CreateIndexResponseSuccess, _CreateOutboundConnectionResponseSuccess, _CreatePackageResponseSuccess, _CreateVpcEndpointResponseSuccess, _DeleteApplicationResponseSuccess, _DeleteDataSourceResponseSuccess, _DeleteDomainResponseSuccess, _DeleteInboundConnectionResponseSuccess, _DeleteIndexResponseSuccess, _DeleteOutboundConnectionResponseSuccess, _DeletePackageResponseSuccess, _DeleteVpcEndpointResponseSuccess, _DeregisterCapabilityResponseSuccess, _DescribeDataSourceAttachmentResponseSuccess, _DescribeDomainAutoTunesResponseSuccess, _DescribeDomainChangeProgressResponseSuccess, _DescribeDomainConfigResponseSuccess, _DescribeDomainHealthResponseSuccess, _DescribeDomainNodesResponseSuccess, _DescribeDomainResponseSuccess, _DescribeDomainsResponseSuccess, _DescribeDryRunProgressResponseSuccess, _DescribeInboundConnectionsResponseSuccess, _DescribeInsightDetailsResponseSuccess, _DescribeInstanceTypeLimitsResponseSuccess, _DescribeOutboundConnectionsResponseSuccess, _DescribePackagesResponseSuccess, _DescribeReservedInstanceOfferingsResponseSuccess, _DescribeReservedInstancesResponseSuccess, _DescribeVpcEndpointsResponseSuccess, _DetachDataSourceResponseSuccess, _DissociatePackageResponseSuccess, _DissociatePackagesResponseSuccess, _GetApplicationResponseSuccess, _GetCapabilityResponseSuccess, _GetCompatibleVersionsResponseSuccess, _GetDataSourceResponseSuccess, _GetDefaultApplicationSettingResponseSuccess, _GetDirectQueryDataSourceResponseSuccess, _GetDomainMaintenanceStatusResponseSuccess, _GetIndexResponseSuccess, _GetMigrationResponseSuccess, _GetPackageVersionHistoryResponseSuccess, _GetUpgradeHistoryResponseSuccess, _GetUpgradeStatusResponseSuccess, _InsightFeedbackResponseSuccess, _ListApplicationsResponseSuccess, _ListDataSourceAttachmentsResponseSuccess, _ListDataSourcesResponseSuccess, _ListDirectQueryDataSourcesResponseSuccess, _ListDomainMaintenancesResponseSuccess, _ListDomainNamesResponseSuccess, _ListDomainsForPackageResponseSuccess, _ListInsightsResponseSuccess, _ListInstanceTypeDetailsResponseSuccess, _ListMigrationsResponseSuccess, _ListPackagesForDomainResponseSuccess, _ListScheduledActionsResponseSuccess, _ListTagsResponseSuccess, _ListVersionsResponseSuccess, _ListVpcEndpointAccessResponseSuccess, _ListVpcEndpointsForDomainResponseSuccess, _ListVpcEndpointsResponseSuccess, _PurchaseReservedInstanceOfferingResponseSuccess, _PutDefaultApplicationSettingResponseSuccess, _RegisterCapabilityResponseSuccess, _RejectInboundConnectionResponseSuccess, _RevokeVpcEndpointAccessResponseSuccess, _RollbackServiceSoftwareUpdateResponseSuccess, _StartDomainMaintenanceResponseSuccess, _StartMigrationResponseSuccess, _StartServiceSoftwareUpdateResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateDataSourceResponseSuccess, _UpdateDirectQueryDataSourceResponseSuccess, _UpdateDomainConfigResponseSuccess, _UpdateIndexResponseSuccess, _UpdatePackageResponseSuccess, _UpdatePackageScopeResponseSuccess, _UpdateScheduledActionResponseSuccess, _UpdateVpcEndpointResponseSuccess, _UpgradeDomainResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_inbound_connection(params = {}) ⇒ Types::AcceptInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to accept an inbound cross-cluster search connection request.
-
#add_data_source(params = {}) ⇒ Types::AddDataSourceResponse
Creates a new direct-query data source to the specified domain.
-
#add_direct_query_data_source(params = {}) ⇒ Types::AddDirectQueryDataSourceResponse
Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data.
-
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Amazon OpenSearch Service domain, data source, or application.
-
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon OpenSearch Service domain.
-
#associate_packages(params = {}) ⇒ Types::AssociatePackagesResponse
Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.
-
#attach_data_source(params = {}) ⇒ Types::AttachDataSourceResponse
Attaches a data source to an OpenSearch application.
-
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
-
#cancel_service_software_update(params = {}) ⇒ Types::CancelServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon OpenSearch Service domain.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an OpenSearch UI application.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates an Amazon OpenSearch Service domain.
-
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an OpenSearch index with optional automatic semantic enrichment for specified text fields.
-
#create_outbound_connection(params = {}) ⇒ Types::CreateOutboundConnectionResponse
Creates a new cross-cluster search connection from a source Amazon OpenSearch Service domain to a destination domain.
-
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Creates a package for use with Amazon OpenSearch Service domains.
-
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
-
#delete_application(params = {}) ⇒ Struct
Deletes a specified OpenSearch application.
-
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceResponse
Deletes a direct-query data source.
-
#delete_direct_query_data_source(params = {}) ⇒ Struct
Deletes a previously configured direct query data source from Amazon OpenSearch Service.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Deletes an Amazon OpenSearch Service domain and all of its data.
-
#delete_inbound_connection(params = {}) ⇒ Types::DeleteInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to delete an existing inbound cross-cluster search connection.
-
#delete_index(params = {}) ⇒ Types::DeleteIndexResponse
Deletes an OpenSearch index.
-
#delete_outbound_connection(params = {}) ⇒ Types::DeleteOutboundConnectionResponse
Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection.
-
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Deletes an Amazon OpenSearch Service package.
-
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#deregister_capability(params = {}) ⇒ Types::DeregisterCapabilityResponse
Deregisters a capability from an OpenSearch UI application.
-
#describe_data_source_attachment(params = {}) ⇒ Types::DescribeDataSourceAttachmentResponse
Returns the current status and details of a specific data source attachment for an OpenSearch application.
-
#describe_domain(params = {}) ⇒ Types::DescribeDomainResponse
Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN.
-
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain.
-
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain.
-
#describe_domain_config(params = {}) ⇒ Types::DescribeDomainConfigResponse
Returns the configuration of an Amazon OpenSearch Service domain.
-
#describe_domain_health(params = {}) ⇒ Types::DescribeDomainHealthResponse
Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node.
-
#describe_domain_nodes(params = {}) ⇒ Types::DescribeDomainNodesResponse
Returns information about domain and nodes, including data nodes, master nodes, ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and node states.
-
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Returns domain configuration information about the specified Amazon OpenSearch Service domains.
-
#describe_dry_run_progress(params = {}) ⇒ Types::DescribeDryRunProgressResponse
Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain.
-
#describe_inbound_connections(params = {}) ⇒ Types::DescribeInboundConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain.
-
#describe_insight_details(params = {}) ⇒ Types::DescribeInsightDetailsResponse
Describes the details of an existing insight for an Amazon OpenSearch Service domain.
-
#describe_instance_type_limits(params = {}) ⇒ Types::DescribeInstanceTypeLimitsResponse
Describes the instance count, storage, and master node limits for a given OpenSearch or Elasticsearch version and instance type.
-
#describe_outbound_connections(params = {}) ⇒ Types::DescribeOutboundConnectionsResponse
Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain.
-
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to OpenSearch Service.
-
#describe_reserved_instance_offerings(params = {}) ⇒ Types::DescribeReservedInstanceOfferingsResponse
Describes the available Amazon OpenSearch Service Reserved Instance offerings for a given Region.
-
#describe_reserved_instances(params = {}) ⇒ Types::DescribeReservedInstancesResponse
Describes the Amazon OpenSearch Service instances that you have reserved in a given Region.
-
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
-
#detach_data_source(params = {}) ⇒ Types::DetachDataSourceResponse
Removes a data source from an OpenSearch application.
-
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Removes a package from the specified Amazon OpenSearch Service domain.
-
#dissociate_packages(params = {}) ⇒ Types::DissociatePackagesResponse
Dissociates multiple packages from a domain simultaneously.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves the configuration and status of an existing OpenSearch application.
-
#get_capability(params = {}) ⇒ Types::GetCapabilityResponse
Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
-
#get_compatible_versions(params = {}) ⇒ Types::GetCompatibleVersionsResponse
Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to.
-
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves information about a direct query data source.
-
#get_default_application_setting(params = {}) ⇒ Types::GetDefaultApplicationSettingResponse
Gets the ARN of the current default application.
-
#get_direct_query_data_source(params = {}) ⇒ Types::GetDirectQueryDataSourceResponse
Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service.
-
#get_domain_maintenance_status(params = {}) ⇒ Types::GetDomainMaintenanceStatusResponse
The status of the maintenance action.
-
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an OpenSearch index including its schema and semantic enrichment configuration.
-
#get_migration(params = {}) ⇒ Types::GetMigrationResponse
Retrieves the current status and progress of a migration job, including the number of exported and imported objects and error details if the migration failed.
-
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of Amazon OpenSearch Service package versions, along with their creation time, commit message, and plugin properties (if the package is a zip plugin package).
-
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades performed on an Amazon OpenSearch Service domain.
-
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain.
-
#insight_feedback(params = {}) ⇒ Types::InsightFeedbackResponse
Submits feedback for an existing insight in an Amazon OpenSearch Service domain.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all OpenSearch applications under your account.
-
#list_data_source_attachments(params = {}) ⇒ Types::ListDataSourceAttachmentsResponse
Returns a paginated list of all data source attachments for an OpenSearch application, including attachments in all states (
PENDING,ATTACHED, andFAILED). -
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists direct-query data sources for a specific domain.
-
#list_direct_query_data_sources(params = {}) ⇒ Types::ListDirectQueryDataSourcesResponse
Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.
-
#list_domain_maintenances(params = {}) ⇒ Types::ListDomainMaintenancesResponse
A list of maintenance actions for the domain.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the names of all Amazon OpenSearch Service domains owned by the current user in the active Region.
-
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon OpenSearch Service domains associated with a given package.
-
#list_insights(params = {}) ⇒ Types::ListInsightsResponse
Lists insights for an Amazon OpenSearch Service domain or Amazon Web Services account.
-
#list_instance_type_details(params = {}) ⇒ Types::ListInstanceTypeDetailsResponse
Lists all instance types and available features for a given OpenSearch or Elasticsearch version.
-
#list_migrations(params = {}) ⇒ Types::ListMigrationsResponse
Lists migration jobs for an Amazon OpenSearch Service application.
-
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with an Amazon OpenSearch Service domain.
-
#list_scheduled_actions(params = {}) ⇒ Types::ListScheduledActionsResponse
Retrieves a list of configuration changes that are scheduled for a domain.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all resource tags for an Amazon OpenSearch Service domain, data source, or application.
-
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
-
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.
-
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
-
#purchase_reserved_instance_offering(params = {}) ⇒ Types::PurchaseReservedInstanceOfferingResponse
Allows you to purchase Amazon OpenSearch Service Reserved Instances.
-
#put_default_application_setting(params = {}) ⇒ Types::PutDefaultApplicationSettingResponse
Sets the default application to the application with the specified ARN.
-
#register_capability(params = {}) ⇒ Types::RegisterCapabilityResponse
Registers a capability for an OpenSearch UI application.
-
#reject_inbound_connection(params = {}) ⇒ Types::RejectInboundConnectionResponse
Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request.
-
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from an Amazon OpenSearch Service domain, data source, or application.
-
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
-
#rollback_service_software_update(params = {}) ⇒ Types::RollbackServiceSoftwareUpdateResponse
Rolls back a service software update for a domain to the previous version.
-
#start_domain_maintenance(params = {}) ⇒ Types::StartDomainMaintenanceResponse
Starts the node maintenance process on the data node.
-
#start_migration(params = {}) ⇒ Types::StartMigrationResponse
Initiates a migration job to migrate saved objects from a data source to an Amazon OpenSearch Service application workspace.
-
#start_service_software_update(params = {}) ⇒ Types::StartServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon OpenSearch Service domain.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration and settings of an existing OpenSearch application.
-
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a direct-query data source.
-
#update_direct_query_data_source(params = {}) ⇒ Types::UpdateDirectQueryDataSourceResponse
Updates the configuration or properties of an existing direct query data source in Amazon OpenSearch Service.
-
#update_domain_config(params = {}) ⇒ Types::UpdateDomainConfigResponse
Modifies the cluster configuration of the specified Amazon OpenSearch Service domain.
-
#update_index(params = {}) ⇒ Types::UpdateIndexResponse
Updates an existing OpenSearch index schema and semantic enrichment configuration.
-
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon OpenSearch Service domains.
-
#update_package_scope(params = {}) ⇒ Types::UpdatePackageScopeResponse
Updates the scope of a package.
-
#update_scheduled_action(params = {}) ⇒ Types::UpdateScheduledActionResponse
Reschedules a planned domain configuration change for a later time.
-
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#upgrade_domain(params = {}) ⇒ Types::UpgradeDomainResponse
Allows you to either upgrade your Amazon OpenSearch Service domain or perform an upgrade eligibility check to a compatible version of OpenSearch or Elasticsearch.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7110 7111 7112 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 7110 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7113 7114 7115 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 7113 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_inbound_connection(params = {}) ⇒ Types::AcceptInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to accept an inbound cross-cluster search connection request. For more information, see Cross-cluster search for Amazon OpenSearch Service.
86 |
# File 'sig/client.rbs', line 86
def accept_inbound_connection: (
|
#add_data_source(params = {}) ⇒ Types::AddDataSourceResponse
Creates a new direct-query data source to the specified domain. For more information, see Creating Amazon OpenSearch Service data source integrations with Amazon S3.
96 |
# File 'sig/client.rbs', line 96
def add_data_source: (
|
#add_direct_query_data_source(params = {}) ⇒ Types::AddDirectQueryDataSourceResponse
Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data.
113 |
# File 'sig/client.rbs', line 113
def add_direct_query_data_source: (
|
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Amazon OpenSearch Service domain, data source, or application.
Tags are a set of case-sensitive key-value pairs. A domain, data source, or application can have up to 10 tags. For more information, see Tagging Amazon OpenSearch Service resources.
129 |
# File 'sig/client.rbs', line 129
def add_tags: (
|
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon OpenSearch Service domain. For more information, see Custom packages for Amazon OpenSearch Service.
145 |
# File 'sig/client.rbs', line 145
def associate_package: (
|
#associate_packages(params = {}) ⇒ Types::AssociatePackagesResponse
Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.
163 |
# File 'sig/client.rbs', line 163
def associate_packages: (
|
#attach_data_source(params = {}) ⇒ Types::AttachDataSourceResponse
Attaches a data source to an OpenSearch application. The data source
must be an Amazon OpenSearch Service domain. If both the application
and the data source are active, the attachment completes immediately
with a status of ATTACHED. Otherwise, the operation returns
PENDING and completes the attachment automatically once both become
active. If the attachment cannot be completed, its status becomes
FAILED. This operation is idempotent: If the data source is already
attached or pending, the operation returns the existing attachment.
189 |
# File 'sig/client.rbs', line 189
def attach_data_source: (
|
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
206 |
# File 'sig/client.rbs', line 206
def authorize_vpc_endpoint_access: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 7083 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::OpenSearchService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-opensearchservice' context[:gem_version] = '1.108.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
223 |
# File 'sig/client.rbs', line 223
def cancel_domain_config_change: (
|
#cancel_service_software_update(params = {}) ⇒ Types::CancelServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon OpenSearch
Service domain. You can only perform this operation before the
AutomatedUpdateDate and when the domain's UpdateStatus is
PENDING_UPDATE. For more information, see Service software updates
in Amazon OpenSearch Service.
234 |
# File 'sig/client.rbs', line 234
def cancel_service_software_update: (
|
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an OpenSearch UI application. For more information, see Using the OpenSearch user interface in Amazon OpenSearch Service.
252 |
# File 'sig/client.rbs', line 252
def create_application: (
|
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates an Amazon OpenSearch Service domain. For more information, see Creating and managing Amazon OpenSearch Service domains.
288 |
# File 'sig/client.rbs', line 288
def create_domain: (
|
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an OpenSearch index with optional automatic semantic enrichment for specified text fields. Automatic semantic enrichment enables semantic search capabilities without requiring machine learning expertise, improving search relevance by up to 20% by understanding search intent and contextual meaning beyond keyword matching. The semantic enrichment process has zero impact on search latency as sparse encodings are stored directly within the index during indexing. For more information, see Automatic semantic enrichment.
379 |
# File 'sig/client.rbs', line 379
def create_index: (
|
#create_outbound_connection(params = {}) ⇒ Types::CreateOutboundConnectionResponse
Creates a new cross-cluster search connection from a source Amazon OpenSearch Service domain to a destination domain. For more information, see Cross-cluster search for Amazon OpenSearch Service.
398 |
# File 'sig/client.rbs', line 398
def create_outbound_connection: (
|
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Creates a package for use with Amazon OpenSearch Service domains. For more information, see Custom packages for Amazon OpenSearch Service.
429 |
# File 'sig/client.rbs', line 429
def create_package: (
|
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
459 |
# File 'sig/client.rbs', line 459
def create_vpc_endpoint: (
|
#delete_application(params = {}) ⇒ Struct
Deletes a specified OpenSearch application.
474 |
# File 'sig/client.rbs', line 474
def delete_application: (
|
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceResponse
Deletes a direct-query data source. For more information, see Deleting an Amazon OpenSearch Service data source with Amazon S3.
484 |
# File 'sig/client.rbs', line 484
def delete_data_source: (
|
#delete_direct_query_data_source(params = {}) ⇒ Struct
Deletes a previously configured direct query data source from Amazon OpenSearch Service.
491 |
# File 'sig/client.rbs', line 491
def delete_direct_query_data_source: (
|
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Deletes an Amazon OpenSearch Service domain and all of its data. You can't recover a domain after you delete it.
501 |
# File 'sig/client.rbs', line 501
def delete_domain: (
|
#delete_inbound_connection(params = {}) ⇒ Types::DeleteInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to delete an existing inbound cross-cluster search connection. For more information, see Cross-cluster search for Amazon OpenSearch Service.
511 |
# File 'sig/client.rbs', line 511
def delete_inbound_connection: (
|
#delete_index(params = {}) ⇒ Types::DeleteIndexResponse
Deletes an OpenSearch index. This operation permanently removes the index and cannot be undone.
521 |
# File 'sig/client.rbs', line 521
def delete_index: (
|
#delete_outbound_connection(params = {}) ⇒ Types::DeleteOutboundConnectionResponse
Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection. For more information, see Cross-cluster search for Amazon OpenSearch Service.
532 |
# File 'sig/client.rbs', line 532
def delete_outbound_connection: (
|
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Deletes an Amazon OpenSearch Service package. For more information, see Custom packages for Amazon OpenSearch Service.
542 |
# File 'sig/client.rbs', line 542
def delete_package: (
|
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
552 |
# File 'sig/client.rbs', line 552
def delete_vpc_endpoint: (
|
#deregister_capability(params = {}) ⇒ Types::DeregisterCapabilityResponse
Deregisters a capability from an OpenSearch UI application. This operation removes the capability and its associated configuration.
562 |
# File 'sig/client.rbs', line 562
def deregister_capability: (
|
#describe_data_source_attachment(params = {}) ⇒ Types::DescribeDataSourceAttachmentResponse
Returns the current status and details of a specific data source
attachment for an OpenSearch application. Throws a
ResourceNotFoundException if no attachment record exists for the
specified application and data source combination.
577 |
# File 'sig/client.rbs', line 577
def describe_data_source_attachment: (
|
#describe_domain(params = {}) ⇒ Types::DescribeDomainResponse
Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN.
588 |
# File 'sig/client.rbs', line 588
def describe_domain: (
|
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain. For more information, see Auto-Tune for Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
599 |
# File 'sig/client.rbs', line 599
def describe_domain_auto_tunes: (
|
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain. For more information, see Making configuration changes in Amazon OpenSearch Service.
611 |
# File 'sig/client.rbs', line 611
def describe_domain_change_progress: (
|
#describe_domain_config(params = {}) ⇒ Types::DescribeDomainConfigResponse
Returns the configuration of an Amazon OpenSearch Service domain.
622 |
# File 'sig/client.rbs', line 622
def describe_domain_config: (
|
#describe_domain_health(params = {}) ⇒ Types::DescribeDomainHealthResponse
Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node.
644 |
# File 'sig/client.rbs', line 644
def describe_domain_health: (
|
#describe_domain_nodes(params = {}) ⇒ Types::DescribeDomainNodesResponse
Returns information about domain and nodes, including data nodes, master nodes, ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and node states.
654 |
# File 'sig/client.rbs', line 654
def describe_domain_nodes: (
|
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Returns domain configuration information about the specified Amazon OpenSearch Service domains.
664 |
# File 'sig/client.rbs', line 664
def describe_domains: (
|
#describe_dry_run_progress(params = {}) ⇒ Types::DescribeDryRunProgressResponse
Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain. For more information, see Determining whether a change will cause a blue/green deployment.
676 |
# File 'sig/client.rbs', line 676
def describe_dry_run_progress: (
|
#describe_inbound_connections(params = {}) ⇒ Types::DescribeInboundConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain. For more information, see Cross-cluster search for Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
689 |
# File 'sig/client.rbs', line 689
def describe_inbound_connections: (
|
#describe_insight_details(params = {}) ⇒ Types::DescribeInsightDetailsResponse
Describes the details of an existing insight for an Amazon OpenSearch Service domain. Returns detailed fields associated with the specified insight, such as text descriptions and metric data.
706 |
# File 'sig/client.rbs', line 706
def describe_insight_details: (
|
#describe_instance_type_limits(params = {}) ⇒ Types::DescribeInstanceTypeLimitsResponse
Describes the instance count, storage, and master node limits for a given OpenSearch or Elasticsearch version and instance type.
721 |
# File 'sig/client.rbs', line 721
def describe_instance_type_limits: (
|
#describe_outbound_connections(params = {}) ⇒ Types::DescribeOutboundConnectionsResponse
Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain. For more information, see Cross-cluster search for Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
734 |
# File 'sig/client.rbs', line 734
def describe_outbound_connections: (
|
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to OpenSearch Service. For more information, see Custom packages for Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
752 |
# File 'sig/client.rbs', line 752
def describe_packages: (
|
#describe_reserved_instance_offerings(params = {}) ⇒ Types::DescribeReservedInstanceOfferingsResponse
Describes the available Amazon OpenSearch Service Reserved Instance offerings for a given Region. For more information, see Reserved Instances in Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
770 |
# File 'sig/client.rbs', line 770
def describe_reserved_instance_offerings: (
|
#describe_reserved_instances(params = {}) ⇒ Types::DescribeReservedInstancesResponse
Describes the Amazon OpenSearch Service instances that you have reserved in a given Region. For more information, see Reserved Instances in Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
783 |
# File 'sig/client.rbs', line 783
def describe_reserved_instances: (
|
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
796 |
# File 'sig/client.rbs', line 796
def describe_vpc_endpoints: (
|
#detach_data_source(params = {}) ⇒ Types::DetachDataSourceResponse
Removes a data source from an OpenSearch application. The application
must be in the ACTIVE state. This operation removes the data source
saved object from the application and deletes the attachment record.
Throws a ConflictException if the specified data source has a
PENDING attachment, and a ResourceNotFoundException if the data
source is not currently attached to the application.
808 |
# File 'sig/client.rbs', line 808
def detach_data_source: (
|
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Removes a package from the specified Amazon OpenSearch Service domain. The package can't be in use with any OpenSearch index for the dissociation to succeed. The package is still available in OpenSearch Service for association later. For more information, see Custom packages for Amazon OpenSearch Service.
819 |
# File 'sig/client.rbs', line 819
def dissociate_package: (
|
#dissociate_packages(params = {}) ⇒ Types::DissociatePackagesResponse
Dissociates multiple packages from a domain simultaneously.
830 |
# File 'sig/client.rbs', line 830
def dissociate_packages: (
|
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves the configuration and status of an existing OpenSearch application.
851 |
# File 'sig/client.rbs', line 851
def get_application: (
|
#get_capability(params = {}) ⇒ Types::GetCapabilityResponse
Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
865 |
# File 'sig/client.rbs', line 865
def get_capability: (
|
#get_compatible_versions(params = {}) ⇒ Types::GetCompatibleVersionsResponse
Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to.
876 |
# File 'sig/client.rbs', line 876
def get_compatible_versions: (
|
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves information about a direct query data source.
889 |
# File 'sig/client.rbs', line 889
def get_data_source: (
|
#get_default_application_setting(params = {}) ⇒ Types::GetDefaultApplicationSettingResponse
Gets the ARN of the current default application.
If the default application isn't set, the operation returns a resource not found error.
900 |
# File 'sig/client.rbs', line 900
def get_default_application_setting: (
|
#get_direct_query_data_source(params = {}) ⇒ Types::GetDirectQueryDataSourceResponse
Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service.
914 |
# File 'sig/client.rbs', line 914
def get_direct_query_data_source: (
|
#get_domain_maintenance_status(params = {}) ⇒ Types::GetDomainMaintenanceStatusResponse
The status of the maintenance action.
929 |
# File 'sig/client.rbs', line 929
def get_domain_maintenance_status: (
|
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an OpenSearch index including its schema and semantic enrichment configuration. Use this operation to view the current index structure and semantic search settings.
940 |
# File 'sig/client.rbs', line 940
def get_index: (
|
#get_migration(params = {}) ⇒ Types::GetMigrationResponse
Retrieves the current status and progress of a migration job, including the number of exported and imported objects and error details if the migration failed.
958 |
# File 'sig/client.rbs', line 958
def get_migration: (
|
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of Amazon OpenSearch Service package versions, along with their creation time, commit message, and plugin properties (if the package is a zip plugin package). For more information, see Custom packages for Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
970 |
# File 'sig/client.rbs', line 970
def get_package_version_history: (
|
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades performed on an Amazon OpenSearch Service domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
983 |
# File 'sig/client.rbs', line 983
def get_upgrade_history: (
|
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain.
997 |
# File 'sig/client.rbs', line 997
def get_upgrade_status: (
|
#insight_feedback(params = {}) ⇒ Types::InsightFeedbackResponse
Submits feedback for an existing insight in an Amazon OpenSearch Service domain. Allows users to provide a thumbs up or thumbs down rating and optional text feedback for a specific insight.
1007 |
# File 'sig/client.rbs', line 1007
def insight_feedback: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all OpenSearch applications under your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1024 |
# File 'sig/client.rbs', line 1024
def list_applications: (
|
#list_data_source_attachments(params = {}) ⇒ Types::ListDataSourceAttachmentsResponse
Returns a paginated list of all data source attachments for an
OpenSearch application, including attachments in all states
(PENDING, ATTACHED, and FAILED).
1037 |
# File 'sig/client.rbs', line 1037
def list_data_source_attachments: (
|
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists direct-query data sources for a specific domain. For more information, see For more information, see Working with Amazon OpenSearch Service direct queries with Amazon S3.
1049 |
# File 'sig/client.rbs', line 1049
def list_data_sources: (
|
#list_direct_query_data_sources(params = {}) ⇒ Types::ListDirectQueryDataSourcesResponse
Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.
1060 |
# File 'sig/client.rbs', line 1060
def list_direct_query_data_sources: (
|
#list_domain_maintenances(params = {}) ⇒ Types::ListDomainMaintenancesResponse
A list of maintenance actions for the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1071 |
# File 'sig/client.rbs', line 1071
def list_domain_maintenances: (
|
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the names of all Amazon OpenSearch Service domains owned by the current user in the active Region.
1085 |
# File 'sig/client.rbs', line 1085
def list_domain_names: (
|
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon OpenSearch Service domains associated with a given package. For more information, see Custom packages for Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1096 |
# File 'sig/client.rbs', line 1096
def list_domains_for_package: (
|
#list_insights(params = {}) ⇒ Types::ListInsightsResponse
Lists insights for an Amazon OpenSearch Service domain or Amazon Web Services account. Returns a paginated list of insights based on the specified entity, filters, time range, and sort order.
1109 |
# File 'sig/client.rbs', line 1109
def list_insights: (
|
#list_instance_type_details(params = {}) ⇒ Types::ListInstanceTypeDetailsResponse
Lists all instance types and available features for a given OpenSearch or Elasticsearch version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1130 |
# File 'sig/client.rbs', line 1130
def list_instance_type_details: (
|
#list_migrations(params = {}) ⇒ Types::ListMigrationsResponse
Lists migration jobs for an Amazon OpenSearch Service application. You can filter results by migration status. Use pagination to ensure that the operation returns quickly and successfully.
1146 |
# File 'sig/client.rbs', line 1146
def list_migrations: (
|
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with an Amazon OpenSearch Service domain. For more information, see Custom packages for Amazon OpenSearch Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1160 |
# File 'sig/client.rbs', line 1160
def list_packages_for_domain: (
|
#list_scheduled_actions(params = {}) ⇒ Types::ListScheduledActionsResponse
Retrieves a list of configuration changes that are scheduled for a domain. These changes can be service software updates or blue/green Auto-Tune enhancements.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1173 |
# File 'sig/client.rbs', line 1173
def list_scheduled_actions: (
|
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all resource tags for an Amazon OpenSearch Service domain, data source, or application. For more information, see Tagging Amazon OpenSearch Service resources.
1185 |
# File 'sig/client.rbs', line 1185
def list_tags: (
|
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1196 |
# File 'sig/client.rbs', line 1196
def list_versions: (
|
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
1208 |
# File 'sig/client.rbs', line 1208
def list_vpc_endpoint_access: (
|
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.
1220 |
# File 'sig/client.rbs', line 1220
def list_vpc_endpoints: (
|
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
1231 |
# File 'sig/client.rbs', line 1231
def list_vpc_endpoints_for_domain: (
|
#purchase_reserved_instance_offering(params = {}) ⇒ Types::PurchaseReservedInstanceOfferingResponse
Allows you to purchase Amazon OpenSearch Service Reserved Instances.
1243 |
# File 'sig/client.rbs', line 1243
def purchase_reserved_instance_offering: (
|
#put_default_application_setting(params = {}) ⇒ Types::PutDefaultApplicationSettingResponse
Sets the default application to the application with the specified ARN.
To remove the default application, use the
GetDefaultApplicationSetting operation to get the current default
and then call the PutDefaultApplicationSetting with the current
applications ARN and the setAsDefault parameter set to false.
1255 |
# File 'sig/client.rbs', line 1255
def put_default_application_setting: (
|
#register_capability(params = {}) ⇒ Types::RegisterCapabilityResponse
Registers a capability for an OpenSearch UI application. Use this operation to enable specific capabilities, such as AI features, for a given application. The capability configuration defines the type and settings of the capability to register. For more information about the AI features, see Agentic AI for OpenSearch UI.
1269 |
# File 'sig/client.rbs', line 1269
def register_capability: (
|
#reject_inbound_connection(params = {}) ⇒ Types::RejectInboundConnectionResponse
Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request.
1284 |
# File 'sig/client.rbs', line 1284
def reject_inbound_connection: (
|
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from an Amazon OpenSearch Service domain, data source, or application. For more information, see Tagging Amazon OpenSearch Service resources.
1290 |
# File 'sig/client.rbs', line 1290
def remove_tags: (
|
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
1300 |
# File 'sig/client.rbs', line 1300
def revoke_vpc_endpoint_access: (
|
#rollback_service_software_update(params = {}) ⇒ Types::RollbackServiceSoftwareUpdateResponse
Rolls back a service software update for a domain to the previous version. For more information, see Service software updates in Amazon OpenSearch Service.
1315 |
# File 'sig/client.rbs', line 1315
def rollback_service_software_update: (
|
#start_domain_maintenance(params = {}) ⇒ Types::StartDomainMaintenanceResponse
Starts the node maintenance process on the data node. These processes can include a node reboot, an Opensearch or Elasticsearch process restart, or a Dashboard or Kibana restart.
1325 |
# File 'sig/client.rbs', line 1325
def start_domain_maintenance: (
|
#start_migration(params = {}) ⇒ Types::StartMigrationResponse
Initiates a migration job to migrate saved objects from a data source to an Amazon OpenSearch Service application workspace. Saved objects include dashboards, visualizations, index patterns, and searches. You can specify export filters to control the scope of the migration and a conflict resolution strategy for handling existing objects in the target workspace.
1338 |
# File 'sig/client.rbs', line 1338
def start_migration: (
|
#start_service_software_update(params = {}) ⇒ Types::StartServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon OpenSearch Service domain. For more information, see Service software updates in Amazon OpenSearch Service.
1371 |
# File 'sig/client.rbs', line 1371
def start_service_software_update: (
|
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration and settings of an existing OpenSearch application.
1390 |
# File 'sig/client.rbs', line 1390
def update_application: (
|
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a direct-query data source. For more information, see Working with Amazon OpenSearch Service data source integrations with Amazon S3.
1418 |
# File 'sig/client.rbs', line 1418
def update_data_source: (
|
#update_direct_query_data_source(params = {}) ⇒ Types::UpdateDirectQueryDataSourceResponse
Updates the configuration or properties of an existing direct query data source in Amazon OpenSearch Service.
1436 |
# File 'sig/client.rbs', line 1436
def update_direct_query_data_source: (
|
#update_domain_config(params = {}) ⇒ Types::UpdateDomainConfigResponse
Modifies the cluster configuration of the specified Amazon OpenSearch Service domain.
1452 |
# File 'sig/client.rbs', line 1452
def update_domain_config: (
|
#update_index(params = {}) ⇒ Types::UpdateIndexResponse
Updates an existing OpenSearch index schema and semantic enrichment configuration. This operation allows modification of field mappings and semantic search settings for text fields. Changes to semantic enrichment configuration will apply to newly ingested documents.
1539 |
# File 'sig/client.rbs', line 1539
def update_index: (
|
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon OpenSearch Service domains. For more information, see Custom packages for Amazon OpenSearch Service.
1552 |
# File 'sig/client.rbs', line 1552
def update_package: (
|
#update_package_scope(params = {}) ⇒ Types::UpdatePackageScopeResponse
Updates the scope of a package. Scope of the package defines users who can view and associate a package.
1580 |
# File 'sig/client.rbs', line 1580
def update_package_scope: (
|
#update_scheduled_action(params = {}) ⇒ Types::UpdateScheduledActionResponse
Reschedules a planned domain configuration change for a later time. This change can be a scheduled service software update or a blue/green Auto-Tune enhancement.
1592 |
# File 'sig/client.rbs', line 1592
def update_scheduled_action: (
|
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
1606 |
# File 'sig/client.rbs', line 1606
def update_vpc_endpoint: (
|
#upgrade_domain(params = {}) ⇒ Types::UpgradeDomainResponse
Allows you to either upgrade your Amazon OpenSearch Service domain or perform an upgrade eligibility check to a compatible version of OpenSearch or Elasticsearch.
1626 |
# File 'sig/client.rbs', line 1626
def upgrade_domain: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7103 7104 7105 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 7103 def waiter_names [] end |