Class: Aws::OpenSearchService::Types::AddDirectQueryDataSourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::AddDirectQueryDataSourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_access_policy ⇒ String
An optional IAM access policy document that defines the permissions for accessing the data source.
-
#data_source_name ⇒ String
A unique, user-defined label to identify the data source within your OpenSearch Service environment.
-
#data_source_type ⇒ Types::DirectQueryDataSourceType
The supported Amazon Web Services service that you want to use as the source for direct queries in OpenSearch Service.
-
#description ⇒ String
An optional text field for providing additional context and details about the data source.
-
#open_search_arns ⇒ Array<String>
A list of Amazon Resource Names (ARNs) for the OpenSearch collections that are associated with the direct query data source.
-
#tag_list ⇒ Array<Types::Tag>
A list of tags attached to a domain.
Instance Attribute Details
#data_source_access_policy ⇒ String
An optional IAM access policy document that defines the permissions for accessing the data source. The policy document must be in valid JSON format and follow IAM policy syntax.
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 254 class AddDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :tag_list) SENSITIVE = [] include Aws::Structure end |
#data_source_name ⇒ String
A unique, user-defined label to identify the data source within your OpenSearch Service environment.
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 254 class AddDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :tag_list) SENSITIVE = [] include Aws::Structure end |
#data_source_type ⇒ Types::DirectQueryDataSourceType
The supported Amazon Web Services service that you want to use as the source for direct queries in OpenSearch Service.
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 254 class AddDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :tag_list) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional text field for providing additional context and details about the data source.
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 254 class AddDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :tag_list) SENSITIVE = [] include Aws::Structure end |
#open_search_arns ⇒ Array<String>
A list of Amazon Resource Names (ARNs) for the OpenSearch collections that are associated with the direct query data source.
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 254 class AddDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tag_list ⇒ Array<Types::Tag>
A list of tags attached to a domain.
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 254 class AddDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :tag_list) SENSITIVE = [] include Aws::Structure end |