Class: Aws::OpenSearchService::Types::AppConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::AppConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Configuration settings for an OpenSearch application. For more information, see [Using the OpenSearch user interface in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/application.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The configuration item to set, such as the admin role for the OpenSearch application.
-
#value ⇒ String
The value assigned to the configuration key, such as an IAM user ARN.
Instance Attribute Details
#key ⇒ String
The configuration item to set, such as the admin role for the OpenSearch application.
524 525 526 527 528 529 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 524 class AppConfig < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value assigned to the configuration key, such as an IAM user ARN.
524 525 526 527 528 529 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 524 class AppConfig < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |