Class: Aws::OpenSearchService::Types::AssociatePackagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::AssociatePackagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an OpenSearch Service domain.
-
#package_list ⇒ Array<Types::PackageDetailsForAssociation>
A list of packages and their prerequisites to be associated with a domain.
Instance Attribute Details
#domain_name ⇒ String
The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.
651 652 653 654 655 656 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 651 class AssociatePackagesRequest < Struct.new( :package_list, :domain_name) SENSITIVE = [] include Aws::Structure end |
#package_list ⇒ Array<Types::PackageDetailsForAssociation>
A list of packages and their prerequisites to be associated with a domain.
651 652 653 654 655 656 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 651 class AssociatePackagesRequest < Struct.new( :package_list, :domain_name) SENSITIVE = [] include Aws::Structure end |