Class: Aws::OpenSearchService::Types::AttachDataSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::AttachDataSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the domain.
-
#attachment_id ⇒ String
The unique identifier assigned to the data source attachment.
-
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the domain.
-
#id ⇒ String
The unique identifier of the OpenSearch application.
-
#status ⇒ String
The status of the data source attachment.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the domain. See [Identifiers for IAM Entities ][1] in *Using Amazon Web Services Identity and Access Management* for more information.
766 767 768 769 770 771 772 773 774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 766 class AttachDataSourceResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#attachment_id ⇒ String
The unique identifier assigned to the data source attachment.
766 767 768 769 770 771 772 773 774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 766 class AttachDataSourceResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the domain. See [Identifiers for IAM Entities ][1] in *Using Amazon Web Services Identity and Access Management* for more information.
766 767 768 769 770 771 772 773 774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 766 class AttachDataSourceResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the OpenSearch application.
766 767 768 769 770 771 772 773 774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 766 class AttachDataSourceResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data source attachment. Valid values are ‘PENDING` (waiting for resources to become active), `ATTACHED` (successfully attached), and `FAILED` (attachment timed out or encountered a non-retryable error).
766 767 768 769 770 771 772 773 774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 766 class AttachDataSourceResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |