Class: Aws::OpenSearchService::Types::AuthorizedPrincipal

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Information about an Amazon Web Services account or service that has access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#principalString

The [IAM principal][1] that is allowed access to the domain.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html

Returns:

  • (String)


726
727
728
729
730
731
# File 'lib/aws-sdk-opensearchservice/types.rb', line 726

class AuthorizedPrincipal < Struct.new(
  :principal_type,
  :principal)
  SENSITIVE = []
  include Aws::Structure
end

#principal_typeString

The type of principal.

Returns:

  • (String)


726
727
728
729
730
731
# File 'lib/aws-sdk-opensearchservice/types.rb', line 726

class AuthorizedPrincipal < Struct.new(
  :principal_type,
  :principal)
  SENSITIVE = []
  include Aws::Structure
end