Class: Aws::OpenSearchService::Types::AutoTuneOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::AutoTuneOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Auto-Tune settings when updating a domain. For more information, see [Auto-Tune for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#desired_state ⇒ String
Whether Auto-Tune is enabled or disabled.
-
#maintenance_schedules ⇒ Array<Types::AutoTuneMaintenanceSchedule>
DEPRECATED.
-
#rollback_on_disable ⇒ String
When disabling Auto-Tune, specify
NO_ROLLBACKto retain all prior Auto-Tune settings orDEFAULT_ROLLBACKto revert to the OpenSearch Service defaults. -
#use_off_peak_window ⇒ Boolean
Whether to use the domain’s [off-peak window] to deploy configuration changes on the domain rather than a maintenance schedule.
Instance Attribute Details
#desired_state ⇒ String
Whether Auto-Tune is enabled or disabled.
849 850 851 852 853 854 855 856 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 849 class AutoTuneOptions < Struct.new( :desired_state, :rollback_on_disable, :maintenance_schedules, :use_off_peak_window) SENSITIVE = [] include Aws::Structure end |
#maintenance_schedules ⇒ Array<Types::AutoTuneMaintenanceSchedule>
DEPRECATED. Use [off-peak window] instead.
A list of maintenance schedules during which Auto-Tune can deploy changes.
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/off-peak.html
849 850 851 852 853 854 855 856 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 849 class AutoTuneOptions < Struct.new( :desired_state, :rollback_on_disable, :maintenance_schedules, :use_off_peak_window) SENSITIVE = [] include Aws::Structure end |
#rollback_on_disable ⇒ String
When disabling Auto-Tune, specify NO_ROLLBACK to retain all prior Auto-Tune settings or DEFAULT_ROLLBACK to revert to the OpenSearch Service defaults. If you specify DEFAULT_ROLLBACK, you must include a MaintenanceSchedule in the request. Otherwise, OpenSearch Service is unable to perform the rollback.
849 850 851 852 853 854 855 856 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 849 class AutoTuneOptions < Struct.new( :desired_state, :rollback_on_disable, :maintenance_schedules, :use_off_peak_window) SENSITIVE = [] include Aws::Structure end |
#use_off_peak_window ⇒ Boolean
Whether to use the domain’s [off-peak window] to deploy configuration changes on the domain rather than a maintenance schedule.
[1]: docs.aws.amazon.com/opensearch-service/latest/APIReference/API_OffPeakWindow.html
849 850 851 852 853 854 855 856 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 849 class AutoTuneOptions < Struct.new( :desired_state, :rollback_on_disable, :maintenance_schedules, :use_off_peak_window) SENSITIVE = [] include Aws::Structure end |