Class: Aws::OpenSearchService::Types::AutomatedSnapshotPauseRequestOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::AutomatedSnapshotPauseRequestOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Specifies the automated snapshot pause request options for the domain.
Suspending snapshots reduces data protection. You cannot restore your domain to points in time when snapshots are suspended. Use this feature only for short-term operational needs such as migrations or maintenance windows.
Maximum suspension duration: 3 days.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Whether to enable or disable automated snapshot pause for the domain.
-
#end_time ⇒ Time
The timestamp at which the automated snapshot pause should end.
-
#start_time ⇒ Time
The timestamp at which the automated snapshot pause should begin.
Instance Attribute Details
#enabled ⇒ Boolean
Whether to enable or disable automated snapshot pause for the domain.
1186 1187 1188 1189 1190 1191 1192 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1186 class AutomatedSnapshotPauseRequestOptions < Struct.new( :enabled, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The timestamp at which the automated snapshot pause should end. The maximum allowed duration between ‘StartTime` and `EndTime` is 3 days.
1186 1187 1188 1189 1190 1191 1192 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1186 class AutomatedSnapshotPauseRequestOptions < Struct.new( :enabled, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp at which the automated snapshot pause should begin.
1186 1187 1188 1189 1190 1191 1192 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1186 class AutomatedSnapshotPauseRequestOptions < Struct.new( :enabled, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |