Class: Aws::OpenSearchService::Types::AvailabilityZoneInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Information about an Availability Zone on a domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone_nameString

The name of the Availability Zone.



1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1031

class AvailabilityZoneInfo < Struct.new(
  :availability_zone_name,
  :zone_status,
  :configured_data_node_count,
  :available_data_node_count,
  :total_shards,
  :total_un_assigned_shards)
  SENSITIVE = []
  include Aws::Structure
end

#available_data_node_countString

The number of data nodes active in the Availability Zone.



1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1031

class AvailabilityZoneInfo < Struct.new(
  :availability_zone_name,
  :zone_status,
  :configured_data_node_count,
  :available_data_node_count,
  :total_shards,
  :total_un_assigned_shards)
  SENSITIVE = []
  include Aws::Structure
end

#configured_data_node_countString

The total number of data nodes configured in the Availability Zone.



1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1031

class AvailabilityZoneInfo < Struct.new(
  :availability_zone_name,
  :zone_status,
  :configured_data_node_count,
  :available_data_node_count,
  :total_shards,
  :total_un_assigned_shards)
  SENSITIVE = []
  include Aws::Structure
end

#total_shardsString

The total number of primary and replica shards in the Availability Zone.



1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1031

class AvailabilityZoneInfo < Struct.new(
  :availability_zone_name,
  :zone_status,
  :configured_data_node_count,
  :available_data_node_count,
  :total_shards,
  :total_un_assigned_shards)
  SENSITIVE = []
  include Aws::Structure
end

#total_un_assigned_shardsString

The total number of primary and replica shards that aren’t allocated to any of the nodes in the Availability Zone.



1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1031

class AvailabilityZoneInfo < Struct.new(
  :availability_zone_name,
  :zone_status,
  :configured_data_node_count,
  :available_data_node_count,
  :total_shards,
  :total_un_assigned_shards)
  SENSITIVE = []
  include Aws::Structure
end

#zone_statusString

The current state of the Availability Zone. Current options are Active and StandBy.

  • Active - Data nodes in the Availability Zone are in use.

  • StandBy - Data nodes in the Availability Zone are in a standby state.

  • NotAvailable - Unable to retrieve information.



1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1031

class AvailabilityZoneInfo < Struct.new(
  :availability_zone_name,
  :zone_status,
  :configured_data_node_count,
  :available_data_node_count,
  :total_shards,
  :total_un_assigned_shards)
  SENSITIVE = []
  include Aws::Structure
end