Class: Aws::OpenSearchService::Types::CancelledChangeProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::CancelledChangeProperty
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
A property change that was cancelled for an Amazon OpenSearch Service domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_value ⇒ String
The current value of the property, after the change was cancelled.
-
#cancelled_value ⇒ String
The pending value of the property that was cancelled.
-
#property_name ⇒ String
The name of the property whose change was cancelled.
Instance Attribute Details
#active_value ⇒ String
The current value of the property, after the change was cancelled.
1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1171 class CancelledChangeProperty < Struct.new( :property_name, :cancelled_value, :active_value) SENSITIVE = [] include Aws::Structure end |
#cancelled_value ⇒ String
The pending value of the property that was cancelled. This would have been the eventual value of the property if the chance had not been cancelled.
1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1171 class CancelledChangeProperty < Struct.new( :property_name, :cancelled_value, :active_value) SENSITIVE = [] include Aws::Structure end |
#property_name ⇒ String
The name of the property whose change was cancelled.
1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1171 class CancelledChangeProperty < Struct.new( :property_name, :cancelled_value, :active_value) SENSITIVE = [] include Aws::Structure end |