Class: Aws::OpenSearchService::Types::CapabilityBaseResponseConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::CapabilityBaseResponseConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Note:
CapabilityBaseResponseConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CapabilityBaseResponseConfig corresponding to the set member.
The base configuration returned for a registered capability.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_config ⇒ Types::AIConfig
Configuration settings for AI-powered capabilities.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#ai_config ⇒ Types::AIConfig
Configuration settings for AI-powered capabilities.
1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1211 class CapabilityBaseResponseConfig < Struct.new( :ai_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AiConfig < CapabilityBaseResponseConfig; end class Unknown < CapabilityBaseResponseConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1211 1212 1213 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1211 def unknown @unknown end |