Class: Aws::OpenSearchService::Types::CapabilityExtendedResponseConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::CapabilityExtendedResponseConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Note:
CapabilityExtendedResponseConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CapabilityExtendedResponseConfig corresponding to the set member.
The extended configuration returned for a registered capability, including additional details beyond the base configuration.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_config ⇒ Types::AIConfig
Configuration settings for AI-powered capabilities.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#ai_config ⇒ Types::AIConfig
Configuration settings for AI-powered capabilities.
1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1233 class CapabilityExtendedResponseConfig < Struct.new( :ai_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AiConfig < CapabilityExtendedResponseConfig; end class Unknown < CapabilityExtendedResponseConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1233 1234 1235 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1233 def unknown @unknown end |