Class: Aws::OpenSearchService::Types::CognitoOptionsStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::CognitoOptionsStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The status of the Cognito options for the specified domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#options ⇒ Types::CognitoOptions
Cognito options for the specified domain.
-
#status ⇒ Types::OptionStatus
The status of the Cognito options for the specified domain.
Instance Attribute Details
#options ⇒ Types::CognitoOptions
Cognito options for the specified domain.
1585 1586 1587 1588 1589 1590 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1585 class CognitoOptionsStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OptionStatus
The status of the Cognito options for the specified domain.
1585 1586 1587 1588 1589 1590 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1585 class CognitoOptionsStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |