Class: Aws::OpenSearchService::Types::ColdStorageOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ColdStorageOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters required to enable cold storage for an OpenSearch Service domain. For more information, see Cold storage for Amazon OpenSearch Service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Whether to enable or disable cold storage on the domain.
Instance Attribute Details
#enabled ⇒ Boolean
Whether to enable or disable cold storage on the domain. You must enable UltraWarm storage to enable cold storage.
1787 1788 1789 1790 1791 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1787 class ColdStorageOptions < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |