Class: Aws::OpenSearchService::Types::CreateIndexRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.

Returns:



1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1887

class CreateIndexRequest < Struct.new(
  :domain_name,
  :index_name,
  :index_schema)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the index to create. Must be between 1 and 255 characters and follow OpenSearch naming conventions.

Returns:



1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1887

class CreateIndexRequest < Struct.new(
  :domain_name,
  :index_name,
  :index_schema)
  SENSITIVE = []
  include Aws::Structure
end

#index_schemaHash, ...

The JSON schema defining index mappings, settings, and semantic enrichment configuration. The schema specifies which text fields should be automatically enriched for semantic search capabilities and includes OpenSearch index configuration parameters.

Returns:



1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1887

class CreateIndexRequest < Struct.new(
  :domain_name,
  :index_name,
  :index_schema)
  SENSITIVE = []
  include Aws::Structure
end