Class: Aws::OpenSearchService::Types::CreatePackageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Container for request parameters to the CreatePackage operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#engine_versionString

The version of the Amazon OpenSearch Service engine for which is compatible with the package. This can only be specified for package type ZIP-PLUGIN

Returns:



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2027

class CreatePackageRequest < Struct.new(
  :package_name,
  :package_type,
  :package_description,
  :package_source,
  :package_configuration,
  :engine_version,
  :package_vending_options,
  :package_encryption_options)
  SENSITIVE = []
  include Aws::Structure
end

#package_configurationTypes::PackageConfiguration

The configuration parameters for the package being created.

Returns:



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2027

class CreatePackageRequest < Struct.new(
  :package_name,
  :package_type,
  :package_description,
  :package_source,
  :package_configuration,
  :engine_version,
  :package_vending_options,
  :package_encryption_options)
  SENSITIVE = []
  include Aws::Structure
end

#package_descriptionString

Description of the package.

Returns:



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2027

class CreatePackageRequest < Struct.new(
  :package_name,
  :package_type,
  :package_description,
  :package_source,
  :package_configuration,
  :engine_version,
  :package_vending_options,
  :package_encryption_options)
  SENSITIVE = []
  include Aws::Structure
end

#package_encryption_optionsTypes::PackageEncryptionOptions

The encryption parameters for the package being created.

Returns:



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2027

class CreatePackageRequest < Struct.new(
  :package_name,
  :package_type,
  :package_description,
  :package_source,
  :package_configuration,
  :engine_version,
  :package_vending_options,
  :package_encryption_options)
  SENSITIVE = []
  include Aws::Structure
end

#package_nameString

Unique name for the package.

Returns:



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2027

class CreatePackageRequest < Struct.new(
  :package_name,
  :package_type,
  :package_description,
  :package_source,
  :package_configuration,
  :engine_version,
  :package_vending_options,
  :package_encryption_options)
  SENSITIVE = []
  include Aws::Structure
end

#package_sourceTypes::PackageSource

The Amazon S3 location from which to import the package.

Returns:



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2027

class CreatePackageRequest < Struct.new(
  :package_name,
  :package_type,
  :package_description,
  :package_source,
  :package_configuration,
  :engine_version,
  :package_vending_options,
  :package_encryption_options)
  SENSITIVE = []
  include Aws::Structure
end

#package_typeString

The type of package.

Returns:



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2027

class CreatePackageRequest < Struct.new(
  :package_name,
  :package_type,
  :package_description,
  :package_source,
  :package_configuration,
  :engine_version,
  :package_vending_options,
  :package_encryption_options)
  SENSITIVE = []
  include Aws::Structure
end

#package_vending_optionsTypes::PackageVendingOptions

The vending options for the package being created. They determine if the package can be vended to other users.

Returns:



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2027

class CreatePackageRequest < Struct.new(
  :package_name,
  :package_type,
  :package_description,
  :package_source,
  :package_configuration,
  :engine_version,
  :package_vending_options,
  :package_encryption_options)
  SENSITIVE = []
  include Aws::Structure
end