Class: Aws::OpenSearchService::Types::DataSourceAttachmentSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Summary information about a data source attachment, including its identifier, data source ARN, and current status.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_idString

The unique identifier assigned to the data source attachment.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2462

class DataSourceAttachmentSummary < Struct.new(
  :attachment_id,
  :data_source_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_arnString

The Amazon Resource Name (ARN) of the domain. See [Identifiers for IAM Entities ][1] in *Using Amazon Web Services Identity and Access Management* for more information.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/index.html

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2462

class DataSourceAttachmentSummary < Struct.new(
  :attachment_id,
  :data_source_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the data source attachment. Valid values are ‘PENDING`, `ATTACHED`, and `FAILED`.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2462

class DataSourceAttachmentSummary < Struct.new(
  :attachment_id,
  :data_source_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end