Class: Aws::OpenSearchService::Types::DeleteVpcEndpointResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DeleteVpcEndpointResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#vpc_endpoint_summary ⇒ Types::VpcEndpointSummary
Information about the deleted endpoint, including its current status (
DELETINGorDELETE_FAILED).
Instance Attribute Details
#vpc_endpoint_summary ⇒ Types::VpcEndpointSummary
Information about the deleted endpoint, including its current status (DELETING or DELETE_FAILED).
2409 2410 2411 2412 2413 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2409 class DeleteVpcEndpointResponse < Struct.new( :vpc_endpoint_summary) SENSITIVE = [] include Aws::Structure end |