Class: Aws::OpenSearchService::Types::DeploymentStrategyOptionsStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

The status of deployment strategy options for the domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#optionsTypes::DeploymentStrategyOptions

Deployment strategy options for the domain.



2450
2451
2452
2453
2454
2455
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2450

class DeploymentStrategyOptionsStatus < Struct.new(
  :options,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::OptionStatus

The current status of the deployment strategy options for the domain.



2450
2451
2452
2453
2454
2455
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2450

class DeploymentStrategyOptionsStatus < Struct.new(
  :options,
  :status)
  SENSITIVE = []
  include Aws::Structure
end