Class: Aws::OpenSearchService::Types::DescribeDataSourceAttachmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeDataSourceAttachmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the domain.
-
#attachment_id ⇒ String
The unique identifier assigned to the data source attachment.
-
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the domain.
-
#id ⇒ String
The unique identifier of the OpenSearch application.
-
#status ⇒ String
The status of the data source attachment.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the domain. See [Identifiers for IAM Entities ][1] in *Using Amazon Web Services Identity and Access Management* for more information.
2895 2896 2897 2898 2899 2900 2901 2902 2903 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2895 class DescribeDataSourceAttachmentResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#attachment_id ⇒ String
The unique identifier assigned to the data source attachment.
2895 2896 2897 2898 2899 2900 2901 2902 2903 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2895 class DescribeDataSourceAttachmentResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the domain. See [Identifiers for IAM Entities ][1] in *Using Amazon Web Services Identity and Access Management* for more information.
2895 2896 2897 2898 2899 2900 2901 2902 2903 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2895 class DescribeDataSourceAttachmentResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the OpenSearch application.
2895 2896 2897 2898 2899 2900 2901 2902 2903 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2895 class DescribeDataSourceAttachmentResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data source attachment. Valid values are ‘PENDING`, `ATTACHED`, and `FAILED`.
2895 2896 2897 2898 2899 2900 2901 2902 2903 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2895 class DescribeDataSourceAttachmentResponse < Struct.new( :attachment_id, :id, :arn, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |