Class: Aws::OpenSearchService::Types::DescribeDomainAutoTunesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeDomainAutoTunesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters to the DescribeDomainAutoTunes operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
Name of the domain that you want Auto-Tune details about.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
DescribeDomainAutoTunesoperation returns anextToken, you can include the returnednextTokenin subsequentDescribeDomainAutoTunesoperations, which returns results in the next page.
Instance Attribute Details
#domain_name ⇒ String
Name of the domain that you want Auto-Tune details about.
2493 2494 2495 2496 2497 2498 2499 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2493 class DescribeDomainAutoTunesRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.
2493 2494 2495 2496 2497 2498 2499 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2493 class DescribeDomainAutoTunesRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial DescribeDomainAutoTunes operation returns a nextToken, you can include the returned nextToken in subsequent DescribeDomainAutoTunes operations, which returns results in the next page.
2493 2494 2495 2496 2497 2498 2499 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2493 class DescribeDomainAutoTunesRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |