Class: Aws::OpenSearchService::Types::DescribeDomainAutoTunesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeDomainAutoTunesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The result of a DescribeDomainAutoTunes request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_tunes ⇒ Array<Types::AutoTune>
The list of setting adjustments that Auto-Tune has made to the domain.
-
#next_token ⇒ String
When
nextTokenis returned, there are more results available.
Instance Attribute Details
#auto_tunes ⇒ Array<Types::AutoTune>
The list of setting adjustments that Auto-Tune has made to the domain.
2502 2503 2504 2505 2506 2507 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2502 class DescribeDomainAutoTunesResponse < Struct.new( :auto_tunes, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.
2502 2503 2504 2505 2506 2507 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2502 class DescribeDomainAutoTunesResponse < Struct.new( :auto_tunes, :next_token) SENSITIVE = [] include Aws::Structure end |