Class: Aws::OpenSearchService::Types::DescribeInboundConnectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Container for the parameters to the DescribeInboundConnections operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

A list of filters used to match properties for inbound cross-cluster connections.



2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2869

class DescribeInboundConnectionsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.



2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2869

class DescribeInboundConnectionsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your initial DescribeInboundConnections operation returns a nextToken, you can include the returned nextToken in subsequent DescribeInboundConnections operations, which returns results in the next page.



2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2869

class DescribeInboundConnectionsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end