Class: Aws::OpenSearchService::Types::DescribeInsightDetailsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeInsightDetailsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters to the ‘DescribeInsightDetails` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity ⇒ Types::InsightEntity
The entity for which to retrieve insight details.
-
#insight_id ⇒ String
The unique identifier of the insight to describe.
-
#show_html_content ⇒ Boolean
Specifies whether to show response with HTML content in response or not.
Instance Attribute Details
#entity ⇒ Types::InsightEntity
The entity for which to retrieve insight details. Specifies the type and value of the entity, such as a domain name or Amazon Web Services account ID.
3060 3061 3062 3063 3064 3065 3066 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3060 class DescribeInsightDetailsRequest < Struct.new( :entity, :insight_id, :show_html_content) SENSITIVE = [] include Aws::Structure end |
#insight_id ⇒ String
The unique identifier of the insight to describe.
3060 3061 3062 3063 3064 3065 3066 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3060 class DescribeInsightDetailsRequest < Struct.new( :entity, :insight_id, :show_html_content) SENSITIVE = [] include Aws::Structure end |
#show_html_content ⇒ Boolean
Specifies whether to show response with HTML content in response or not.
3060 3061 3062 3063 3064 3065 3066 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3060 class DescribeInsightDetailsRequest < Struct.new( :entity, :insight_id, :show_html_content) SENSITIVE = [] include Aws::Structure end |