Class: Aws::OpenSearchService::Types::DescribeInsightDetailsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

The result of a ‘DescribeInsightDetails` request. Contains the detailed fields associated with the specified insight.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fieldsArray<Types::InsightField>

The list of fields that contain detailed information about the insight.

Returns:



3078
3079
3080
3081
3082
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3078

class DescribeInsightDetailsResponse < Struct.new(
  :fields)
  SENSITIVE = []
  include Aws::Structure
end