Class: Aws::OpenSearchService::Types::DescribeOutboundConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeOutboundConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters to the DescribeOutboundConnections operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
List of filter names and values that you can use for requests.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
DescribeOutboundConnectionsoperation returns anextToken, you can include the returnednextTokenin subsequentDescribeOutboundConnectionsoperations, which returns results in the next page.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
List of filter names and values that you can use for requests.
2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2965 class DescribeOutboundConnectionsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.
2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2965 class DescribeOutboundConnectionsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial DescribeOutboundConnections operation returns a nextToken, you can include the returned nextToken in subsequent DescribeOutboundConnections operations, which returns results in the next page.
2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2965 class DescribeOutboundConnectionsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |