Class: Aws::OpenSearchService::Types::DissociatePackagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DissociatePackagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an OpenSearch Service domain.
-
#package_list ⇒ Array<String>
A list of package IDs to be dissociated from a domain.
Instance Attribute Details
#domain_name ⇒ String
The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.
3527 3528 3529 3530 3531 3532 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3527 class DissociatePackagesRequest < Struct.new( :package_list, :domain_name) SENSITIVE = [] include Aws::Structure end |
#package_list ⇒ Array<String>
A list of package IDs to be dissociated from a domain.
3527 3528 3529 3530 3531 3532 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3527 class DissociatePackagesRequest < Struct.new( :package_list, :domain_name) SENSITIVE = [] include Aws::Structure end |