Class: Aws::OpenSearchService::Types::DomainConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DomainConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the configuration of an OpenSearch Service domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policies ⇒ Types::AccessPoliciesStatus
Specifies the access policies for the domain.
-
#advanced_options ⇒ Types::AdvancedOptionsStatus
Key-value pairs to specify advanced configuration options.
-
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsStatus
Container for fine-grained access control settings for the domain.
-
#aiml_options ⇒ Types::AIMLOptionsStatus
Container for parameters required to enable all machine learning features.
-
#auto_tune_options ⇒ Types::AutoTuneOptionsStatus
Container for Auto-Tune settings for the domain.
-
#change_progress_details ⇒ Types::ChangeProgressDetails
Container for information about the progress of an existing configuration change.
-
#cluster_config ⇒ Types::ClusterConfigStatus
Container for the cluster configuration of a the domain.
-
#cognito_options ⇒ Types::CognitoOptionsStatus
Container for Amazon Cognito options for the domain.
-
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptionsStatus
Specifies
DeploymentStrategyOptionsfor the domain. -
#domain_endpoint_options ⇒ Types::DomainEndpointOptionsStatus
Additional options for the domain endpoint, such as whether to require HTTPS for all traffic.
-
#ebs_options ⇒ Types::EBSOptionsStatus
Container for EBS options configured for the domain.
-
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptionsStatus
Key-value pairs to enable encryption at rest.
-
#engine_version ⇒ Types::VersionStatus
The OpenSearch or Elasticsearch version that the domain is running.
-
#identity_center_options ⇒ Types::IdentityCenterOptionsStatus
Configuration options for enabling and managing IAM Identity Center integration within a domain.
-
#ip_address_type ⇒ Types::IPAddressTypeStatus
Choose either dual stack or IPv4 as your IP address type.
-
#log_publishing_options ⇒ Types::LogPublishingOptionsStatus
Key-value pairs to configure log publishing.
-
#modifying_properties ⇒ Array<Types::ModifyingProperties>
Information about the domain properties that are currently being modified.
-
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptionsStatus
Whether node-to-node encryption is enabled or disabled.
-
#off_peak_window_options ⇒ Types::OffPeakWindowOptionsStatus
Container for off-peak window options for the domain.
-
#snapshot_options ⇒ Types::SnapshotOptionsStatus
DEPRECATED.
-
#software_update_options ⇒ Types::SoftwareUpdateOptionsStatus
Software update options for the domain.
-
#vpc_options ⇒ Types::VPCDerivedInfoStatus
The current VPC options for the domain and the status of any updates to their configuration.
Instance Attribute Details
#access_policies ⇒ Types::AccessPoliciesStatus
Specifies the access policies for the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#advanced_options ⇒ Types::AdvancedOptionsStatus
Key-value pairs to specify advanced configuration options. For more information, see [Advanced options].
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsStatus
Container for fine-grained access control settings for the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#aiml_options ⇒ Types::AIMLOptionsStatus
Container for parameters required to enable all machine learning features.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#auto_tune_options ⇒ Types::AutoTuneOptionsStatus
Container for Auto-Tune settings for the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#change_progress_details ⇒ Types::ChangeProgressDetails
Container for information about the progress of an existing configuration change.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#cluster_config ⇒ Types::ClusterConfigStatus
Container for the cluster configuration of a the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#cognito_options ⇒ Types::CognitoOptionsStatus
Container for Amazon Cognito options for the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptionsStatus
Specifies DeploymentStrategyOptions for the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#domain_endpoint_options ⇒ Types::DomainEndpointOptionsStatus
Additional options for the domain endpoint, such as whether to require HTTPS for all traffic.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#ebs_options ⇒ Types::EBSOptionsStatus
Container for EBS options configured for the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptionsStatus
Key-value pairs to enable encryption at rest.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ Types::VersionStatus
The OpenSearch or Elasticsearch version that the domain is running.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#identity_center_options ⇒ Types::IdentityCenterOptionsStatus
Configuration options for enabling and managing IAM Identity Center integration within a domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ Types::IPAddressTypeStatus
Choose either dual stack or IPv4 as your IP address type. Dual stack allows you to share domain resources across IPv4 and IPv6 address types, and is the recommended option. If you set your IP address type to dual stack, you can’t change your address type later.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#log_publishing_options ⇒ Types::LogPublishingOptionsStatus
Key-value pairs to configure log publishing.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#modifying_properties ⇒ Array<Types::ModifyingProperties>
Information about the domain properties that are currently being modified.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptionsStatus
Whether node-to-node encryption is enabled or disabled.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#off_peak_window_options ⇒ Types::OffPeakWindowOptionsStatus
Container for off-peak window options for the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#snapshot_options ⇒ Types::SnapshotOptionsStatus
DEPRECATED. Container for parameters required to configure automated snapshots of domain indexes.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#software_update_options ⇒ Types::SoftwareUpdateOptionsStatus
Software update options for the domain.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#vpc_options ⇒ Types::VPCDerivedInfoStatus
The current VPC options for the domain and the status of any updates to their configuration.
3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3461 class DomainConfig < Struct.new( :engine_version, :cluster_config, :ebs_options, :access_policies, :ip_address_type, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :change_progress_details, :off_peak_window_options, :software_update_options, :modifying_properties, :aiml_options, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |