Class: Aws::OpenSearchService::Types::Duration
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::Duration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The duration of a maintenance schedule. For more information, see [Auto-Tune for Amazon OpenSearch Service][1].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unit ⇒ String
The unit of measurement for the duration of a maintenance schedule.
-
#value ⇒ Integer
Integer to specify the value of a maintenance schedule duration.
Instance Attribute Details
#unit ⇒ String
The unit of measurement for the duration of a maintenance schedule.
4071 4072 4073 4074 4075 4076 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4071 class Duration < Struct.new( :value, :unit) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Integer
Integer to specify the value of a maintenance schedule duration.
4071 4072 4073 4074 4075 4076 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4071 class Duration < Struct.new( :value, :unit) SENSITIVE = [] include Aws::Structure end |