Class: Aws::OpenSearchService::Types::ExportOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Options to filter the scope of saved objects to export during a migration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#include_references_deepBoolean

Specifies whether to include all objects referenced by the exported objects, recursively.

Returns:

  • (Boolean)


4837
4838
4839
4840
4841
4842
4843
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4837

class ExportOptions < Struct.new(
  :types,
  :objects,
  :include_references_deep)
  SENSITIVE = []
  include Aws::Structure
end

#objectsArray<Types::SavedObjectIdentifier>

A list of specific saved objects to include in the migration, identified by type and ID.

Returns:



4837
4838
4839
4840
4841
4842
4843
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4837

class ExportOptions < Struct.new(
  :types,
  :objects,
  :include_references_deep)
  SENSITIVE = []
  include Aws::Structure
end

#typesArray<String>

A list of saved object types to include in the migration. Valid values include dashboard, visualization, index-pattern, search, and query.

Returns:

  • (Array<String>)


4837
4838
4839
4840
4841
4842
4843
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4837

class ExportOptions < Struct.new(
  :types,
  :objects,
  :include_references_deep)
  SENSITIVE = []
  include Aws::Structure
end