Class: Aws::OpenSearchService::Types::GetDirectQueryDataSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::GetDirectQueryDataSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_access_policy ⇒ String
The IAM access policy document that defines the permissions for accessing the direct query data source.
-
#data_source_arn ⇒ String
The unique, system-generated identifier that represents the data source.
-
#data_source_name ⇒ String
A unique, user-defined label to identify the data source within your OpenSearch Service environment.
-
#data_source_type ⇒ Types::DirectQueryDataSourceType
The supported Amazon Web Services service that is used as the source for direct queries in OpenSearch Service.
-
#description ⇒ String
A description that provides additional context and details about the data source.
-
#open_search_arns ⇒ Array<String>
A list of Amazon Resource Names (ARNs) for the OpenSearch collections that are associated with the direct query data source.
Instance Attribute Details
#data_source_access_policy ⇒ String
The IAM access policy document that defines the permissions for accessing the direct query data source. Returns the current policy configuration in JSON format, or null if no custom policy is configured.
5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5080 class GetDirectQueryDataSourceResponse < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :data_source_arn) SENSITIVE = [] include Aws::Structure end |
#data_source_arn ⇒ String
The unique, system-generated identifier that represents the data source.
5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5080 class GetDirectQueryDataSourceResponse < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :data_source_arn) SENSITIVE = [] include Aws::Structure end |
#data_source_name ⇒ String
A unique, user-defined label to identify the data source within your OpenSearch Service environment.
5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5080 class GetDirectQueryDataSourceResponse < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :data_source_arn) SENSITIVE = [] include Aws::Structure end |
#data_source_type ⇒ Types::DirectQueryDataSourceType
The supported Amazon Web Services service that is used as the source for direct queries in OpenSearch Service.
5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5080 class GetDirectQueryDataSourceResponse < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :data_source_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description that provides additional context and details about the data source.
5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5080 class GetDirectQueryDataSourceResponse < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :data_source_arn) SENSITIVE = [] include Aws::Structure end |
#open_search_arns ⇒ Array<String>
A list of Amazon Resource Names (ARNs) for the OpenSearch collections that are associated with the direct query data source.
5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5080 class GetDirectQueryDataSourceResponse < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy, :data_source_arn) SENSITIVE = [] include Aws::Structure end |