Class: Aws::OpenSearchService::Types::GetIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::GetIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an OpenSearch Service domain.
-
#index_name ⇒ String
The name of the index to retrieve information about.
Instance Attribute Details
#domain_name ⇒ String
The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.
4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4548 class GetIndexRequest < Struct.new( :domain_name, :index_name) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to retrieve information about.
4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4548 class GetIndexRequest < Struct.new( :domain_name, :index_name) SENSITIVE = [] include Aws::Structure end |