Class: Aws::OpenSearchService::Types::GetMigrationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The unique identifier of the OpenSearch application associated with the migration.

Returns:

  • (String)


5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the migration job was created.

Returns:

  • (Time)


5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::MigrationError

Error details if the migration failed or completed with errors.



5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#exported_countInteger

The number of saved objects exported from the source data source.

Returns:

  • (Integer)


5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#imported_countInteger

The number of saved objects successfully imported into the target workspace.

Returns:

  • (Integer)


5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#migration_idString

The unique identifier of the migration job.

Returns:

  • (String)


5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::MigrationSource

The source configuration for the migration, including the data source ARN.



5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the migration job. Valid values are PENDING, IN_PROGRESS, SUCCEEDED, and FAILED.

Returns:

  • (String)


5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time when the migration job was last updated.

Returns:

  • (Time)


5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5317

class GetMigrationResponse < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end