Class: Aws::OpenSearchService::Types::GetPackageVersionHistoryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Container for response returned by GetPackageVersionHistory operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.

Returns:

  • (String)


4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4547

class GetPackageVersionHistoryResponse < Struct.new(
  :package_id,
  :package_version_history_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#package_idString

The unique identifier of the package.

Returns:

  • (String)


4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4547

class GetPackageVersionHistoryResponse < Struct.new(
  :package_id,
  :package_version_history_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#package_version_history_listArray<Types::PackageVersionHistory>

A list of package versions, along with their creation time and commit message.

Returns:



4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4547

class GetPackageVersionHistoryResponse < Struct.new(
  :package_id,
  :package_version_history_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end