Class: Aws::OpenSearchService::Types::IAMFederationOptionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::IAMFederationOptionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Output parameters showing the current IAM identity federation configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Indicates whether IAM identity federation is currently enabled for the domain.
-
#roles_key ⇒ String
The configured key in the SAML assertion for the user’s role information.
-
#subject_key ⇒ String
The configured key in the SAML assertion for the user’s subject identifier.
Instance Attribute Details
#enabled ⇒ Boolean
Indicates whether IAM identity federation is currently enabled for the domain.
4767 4768 4769 4770 4771 4772 4773 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4767 class IAMFederationOptionsOutput < Struct.new( :enabled, :subject_key, :roles_key) SENSITIVE = [] include Aws::Structure end |
#roles_key ⇒ String
The configured key in the SAML assertion for the user’s role information.
4767 4768 4769 4770 4771 4772 4773 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4767 class IAMFederationOptionsOutput < Struct.new( :enabled, :subject_key, :roles_key) SENSITIVE = [] include Aws::Structure end |
#subject_key ⇒ String
The configured key in the SAML assertion for the user’s subject identifier.
4767 4768 4769 4770 4771 4772 4773 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4767 class IAMFederationOptionsOutput < Struct.new( :enabled, :subject_key, :roles_key) SENSITIVE = [] include Aws::Structure end |