Class: Aws::OpenSearchService::Types::IdentityCenterOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::IdentityCenterOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Settings container for integrating IAM Identity Center with OpenSearch UI applications, which enables enabling secure user authentication and access control across multiple data sources. This setup supports single sign-on (SSO) through IAM Identity Center, allowing centralized user management.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled_api_access ⇒ Boolean
Indicates whether IAM Identity Center is enabled for the application.
-
#identity_center_application_arn ⇒ String
The ARN of the IAM Identity Center application that integrates with Amazon OpenSearch Service.
-
#identity_center_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM Identity Center instance.
-
#identity_center_instance_region ⇒ String
The Region of the IAM Identity Center instance.
-
#identity_store_id ⇒ String
The identifier of the IAM Identity Store.
-
#roles_key ⇒ String
Specifies the attribute that contains the backend role identifier (such as group name or group ID) in IAM Identity Center.
-
#subject_key ⇒ String
Specifies the attribute that contains the subject identifier (such as username, user ID, or email) in IAM Identity Center.
Instance Attribute Details
#enabled_api_access ⇒ Boolean
Indicates whether IAM Identity Center is enabled for the application.
5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5163 class IdentityCenterOptions < Struct.new( :enabled_api_access, :identity_center_instance_arn, :identity_center_instance_region, :subject_key, :roles_key, :identity_center_application_arn, :identity_store_id) SENSITIVE = [] include Aws::Structure end |
#identity_center_application_arn ⇒ String
The ARN of the IAM Identity Center application that integrates with Amazon OpenSearch Service.
5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5163 class IdentityCenterOptions < Struct.new( :enabled_api_access, :identity_center_instance_arn, :identity_center_instance_region, :subject_key, :roles_key, :identity_center_application_arn, :identity_store_id) SENSITIVE = [] include Aws::Structure end |
#identity_center_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM Identity Center instance.
5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5163 class IdentityCenterOptions < Struct.new( :enabled_api_access, :identity_center_instance_arn, :identity_center_instance_region, :subject_key, :roles_key, :identity_center_application_arn, :identity_store_id) SENSITIVE = [] include Aws::Structure end |
#identity_center_instance_region ⇒ String
The Region of the IAM Identity Center instance.
5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5163 class IdentityCenterOptions < Struct.new( :enabled_api_access, :identity_center_instance_arn, :identity_center_instance_region, :subject_key, :roles_key, :identity_center_application_arn, :identity_store_id) SENSITIVE = [] include Aws::Structure end |
#identity_store_id ⇒ String
The identifier of the IAM Identity Store.
5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5163 class IdentityCenterOptions < Struct.new( :enabled_api_access, :identity_center_instance_arn, :identity_center_instance_region, :subject_key, :roles_key, :identity_center_application_arn, :identity_store_id) SENSITIVE = [] include Aws::Structure end |
#roles_key ⇒ String
Specifies the attribute that contains the backend role identifier (such as group name or group ID) in IAM Identity Center.
5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5163 class IdentityCenterOptions < Struct.new( :enabled_api_access, :identity_center_instance_arn, :identity_center_instance_region, :subject_key, :roles_key, :identity_center_application_arn, :identity_store_id) SENSITIVE = [] include Aws::Structure end |
#subject_key ⇒ String
Specifies the attribute that contains the subject identifier (such as username, user ID, or email) in IAM Identity Center.
5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5163 class IdentityCenterOptions < Struct.new( :enabled_api_access, :identity_center_instance_arn, :identity_center_instance_region, :subject_key, :roles_key, :identity_center_application_arn, :identity_store_id) SENSITIVE = [] include Aws::Structure end |