Class: Aws::OpenSearchService::Types::Insight
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::Insight
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Represents an insight returned by the ‘ListInsights` operation. An insight is a notification about a domain event or recommendation that helps you optimize your Amazon OpenSearch Service domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The timestamp when the insight was created, in epoch milliseconds.
-
#display_name ⇒ String
The display name of the insight.
-
#insight_id ⇒ String
The unique identifier of the insight.
-
#is_experimental ⇒ Boolean
Indicates whether the insight is experimental.
-
#priority ⇒ String
The priority level of the insight.
-
#status ⇒ String
The current status of the insight.
-
#type ⇒ String
The type of the insight.
-
#update_time ⇒ Time
The timestamp when the insight was last updated, in epoch milliseconds.
Instance Attribute Details
#creation_time ⇒ Time
The timestamp when the insight was created, in epoch milliseconds.
5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5333 class Insight < Struct.new( :insight_id, :display_name, :type, :priority, :status, :creation_time, :update_time, :is_experimental) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the insight.
5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5333 class Insight < Struct.new( :insight_id, :display_name, :type, :priority, :status, :creation_time, :update_time, :is_experimental) SENSITIVE = [] include Aws::Structure end |
#insight_id ⇒ String
The unique identifier of the insight.
5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5333 class Insight < Struct.new( :insight_id, :display_name, :type, :priority, :status, :creation_time, :update_time, :is_experimental) SENSITIVE = [] include Aws::Structure end |
#is_experimental ⇒ Boolean
Indicates whether the insight is experimental.
5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5333 class Insight < Struct.new( :insight_id, :display_name, :type, :priority, :status, :creation_time, :update_time, :is_experimental) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
The priority level of the insight. Possible values are ‘CRITICAL`, `HIGH`, `MEDIUM`, and `LOW`.
5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5333 class Insight < Struct.new( :insight_id, :display_name, :type, :priority, :status, :creation_time, :update_time, :is_experimental) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the insight. Possible values are ‘ACTIVE`, `RESOLVED`, and `DISMISSED`.
5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5333 class Insight < Struct.new( :insight_id, :display_name, :type, :priority, :status, :creation_time, :update_time, :is_experimental) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the insight. Possible values are ‘EVENT` and `RECOMMENDATION`.
5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5333 class Insight < Struct.new( :insight_id, :display_name, :type, :priority, :status, :creation_time, :update_time, :is_experimental) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The timestamp when the insight was last updated, in epoch milliseconds.
5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5333 class Insight < Struct.new( :insight_id, :display_name, :type, :priority, :status, :creation_time, :update_time, :is_experimental) SENSITIVE = [] include Aws::Structure end |