Class: Aws::OpenSearchService::Types::InsightFeedbackEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Specifies the entity for which to submit insight feedback. An entity represents an Amazon OpenSearch Service domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The type of the entity. Possible values are DomainName.

Returns:

  • (String)


5912
5913
5914
5915
5916
5917
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5912

class InsightFeedbackEntity < Struct.new(
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the entity, such as a domain name.

Returns:

  • (String)


5912
5913
5914
5915
5916
5917
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5912

class InsightFeedbackEntity < Struct.new(
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end