Class: Aws::OpenSearchService::Types::InstanceLimits
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::InstanceLimits
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Instance-related attributes that are available for a given instance type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_count_limits ⇒ Types::InstanceCountLimits
Limits on the number of instances that can be created for a given instance type.
Instance Attribute Details
#instance_count_limits ⇒ Types::InstanceCountLimits
Limits on the number of instances that can be created for a given instance type.
5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5087 class InstanceLimits < Struct.new( :instance_count_limits) SENSITIVE = [] include Aws::Structure end |