Class: Aws::OpenSearchService::Types::JWTOptionsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Describes the JWT options configured for the domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

True if JWT use is enabled.

Returns:

  • (Boolean)


5607
5608
5609
5610
5611
5612
5613
5614
5615
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5607

class JWTOptionsOutput < Struct.new(
  :enabled,
  :subject_key,
  :roles_key,
  :jwks_url,
  :public_key)
  SENSITIVE = []
  include Aws::Structure
end

#jwks_urlString

The configured JWKS URL endpoint from which the cluster retrieves public keys to verify JWT requests.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5607

class JWTOptionsOutput < Struct.new(
  :enabled,
  :subject_key,
  :roles_key,
  :jwks_url,
  :public_key)
  SENSITIVE = []
  include Aws::Structure
end

#public_keyString

The key used to verify the signature of incoming JWT requests.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5607

class JWTOptionsOutput < Struct.new(
  :enabled,
  :subject_key,
  :roles_key,
  :jwks_url,
  :public_key)
  SENSITIVE = []
  include Aws::Structure
end

#roles_keyString

The key used for matching the JWT roles attribute.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5607

class JWTOptionsOutput < Struct.new(
  :enabled,
  :subject_key,
  :roles_key,
  :jwks_url,
  :public_key)
  SENSITIVE = []
  include Aws::Structure
end

#subject_keyString

The key used for matching the JWT subject attribute.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5607

class JWTOptionsOutput < Struct.new(
  :enabled,
  :subject_key,
  :roles_key,
  :jwks_url,
  :public_key)
  SENSITIVE = []
  include Aws::Structure
end