Class: Aws::OpenSearchService::Types::ListDataSourceAttachmentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier or name of the OpenSearch application to list attachments for.

Returns:

  • (String)


6312
6313
6314
6315
6316
6317
6318
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6312

class ListDataSourceAttachmentsRequest < Struct.new(
  :id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page. The default is 50.

Returns:

  • (Integer)


6312
6313
6314
6315
6316
6317
6318
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6312

class ListDataSourceAttachmentsRequest < Struct.new(
  :id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token from a previous call to retrieve the next set of results.

Returns:

  • (String)


6312
6313
6314
6315
6316
6317
6318
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6312

class ListDataSourceAttachmentsRequest < Struct.new(
  :id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end