Class: Aws::OpenSearchService::Types::ListDataSourceAttachmentsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachmentsArray<Types::DataSourceAttachmentSummary>

A list of data source attachment summaries for the specified application.



6332
6333
6334
6335
6336
6337
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6332

class ListDataSourceAttachmentsResponse < Struct.new(
  :attachments,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use in a subsequent call to retrieve the next set of results.

Returns:

  • (String)


6332
6333
6334
6335
6336
6337
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6332

class ListDataSourceAttachmentsResponse < Struct.new(
  :attachments,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end