Class: Aws::OpenSearchService::Types::ListDirectQueryDataSourcesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#direct_query_data_sourcesArray<Types::DirectQueryDataSource>

A list of the direct query data sources that are returned by the ListDirectQueryDataSources API operation.

Returns:



5307
5308
5309
5310
5311
5312
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5307

class ListDirectQueryDataSourcesResponse < Struct.new(
  :next_token,
  :direct_query_data_sources)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.

Returns:

  • (String)


5307
5308
5309
5310
5311
5312
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5307

class ListDirectQueryDataSourcesResponse < Struct.new(
  :next_token,
  :direct_query_data_sources)
  SENSITIVE = []
  include Aws::Structure
end