Class: Aws::OpenSearchService::Types::ListDomainMaintenancesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListDomainMaintenancesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The result of a ListDomainMaintenances request that contains information about the requested actions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_maintenances ⇒ Array<Types::DomainMaintenanceDetails>
A list of the submitted maintenance actions.
-
#next_token ⇒ String
When
nextTokenis returned, there are more results available.
Instance Attribute Details
#domain_maintenances ⇒ Array<Types::DomainMaintenanceDetails>
A list of the submitted maintenance actions.
5419 5420 5421 5422 5423 5424 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5419 class ListDomainMaintenancesResponse < Struct.new( :domain_maintenances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.
5419 5420 5421 5422 5423 5424 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5419 class ListDomainMaintenancesResponse < Struct.new( :domain_maintenances, :next_token) SENSITIVE = [] include Aws::Structure end |