Class: Aws::OpenSearchService::Types::ListInsightsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Container for the parameters to the ListInsights operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entityTypes::InsightEntity

The entity for which to list insights. Specifies the type and value of the entity, such as a domain name or Amazon Web Services account ID.



6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580

class ListInsightsRequest < Struct.new(
  :entity,
  :time_range,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

An optional parameter that specifies the maximum number of results to return. You can use NextToken to get the next page of results. Valid values are 1 to 500.

Returns:

  • (Integer)


6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580

class ListInsightsRequest < Struct.new(
  :entity,
  :time_range,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your initial ListInsights operation returns a NextToken, include the returned NextToken in subsequent ListInsights operations to retrieve the next page of results.

Returns:

  • (String)


6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580

class ListInsightsRequest < Struct.new(
  :entity,
  :time_range,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for the results. Possible values are ASC (ascending) and DESC (descending).

Returns:

  • (String)


6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580

class ListInsightsRequest < Struct.new(
  :entity,
  :time_range,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#time_rangeTypes::InsightTimeRange

The time range for filtering insights, specified as epoch millisecond timestamps.



6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580

class ListInsightsRequest < Struct.new(
  :entity,
  :time_range,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end