Class: Aws::OpenSearchService::Types::ListInstanceTypeDetailsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_type_detailsArray<Types::InstanceTypeDetails>

Lists all supported instance types and features for the given OpenSearch or Elasticsearch version.

Returns:



6672
6673
6674
6675
6676
6677
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6672

class ListInstanceTypeDetailsResponse < Struct.new(
  :instance_type_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.

Returns:

  • (String)


6672
6673
6674
6675
6676
6677
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6672

class ListInstanceTypeDetailsResponse < Struct.new(
  :instance_type_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end