Class: Aws::OpenSearchService::Types::ListMigrationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The unique identifier of the OpenSearch application to list migrations for.

Returns:

  • (String)


6700
6701
6702
6703
6704
6705
6706
6707
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6700

class ListMigrationsRequest < Struct.new(
  :application_id,
  :status,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


6700
6701
6702
6703
6704
6705
6706
6707
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6700

class ListMigrationsRequest < Struct.new(
  :application_id,
  :status,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token from a previous call to retrieve the next set of results.

Returns:

  • (String)


6700
6701
6702
6703
6704
6705
6706
6707
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6700

class ListMigrationsRequest < Struct.new(
  :application_id,
  :status,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Filters the results by migration status. Valid values are PENDING, IN_PROGRESS, SUCCEEDED, and FAILED.

Returns:

  • (String)


6700
6701
6702
6703
6704
6705
6706
6707
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6700

class ListMigrationsRequest < Struct.new(
  :application_id,
  :status,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end