Class: Aws::OpenSearchService::Types::ListMigrationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#migrationsArray<Types::MigrationSummary>

A list of migration job summaries for the specified application.

Returns:



6720
6721
6722
6723
6724
6725
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6720

class ListMigrationsResponse < Struct.new(
  :migrations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use in a subsequent call to retrieve the next set of results.

Returns:

  • (String)


6720
6721
6722
6723
6724
6725
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6720

class ListMigrationsResponse < Struct.new(
  :migrations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end