Class: Aws::OpenSearchService::Types::ListScheduledActionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The name of the domain.

Returns:

  • (String)


6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6798

class ListScheduledActionsRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

Returns:

  • (Integer)


6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6798

class ListScheduledActionsRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your initial ListScheduledActions operation returns a nextToken, you can include the returned nextToken in subsequent ListScheduledActions operations, which returns results in the next page.

Returns:

  • (String)


6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6798

class ListScheduledActionsRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end