Class: Aws::OpenSearchService::Types::ListVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the request parameters to the ListVersions operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListVersionsoperation returns anextToken, you can include the returnednextTokenin subsequentListVersionsoperations, which returns results in the next page.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use nextToken to get the next page of results.
6871 6872 6873 6874 6875 6876 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6871 class ListVersionsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListVersions operation returns a nextToken, you
can include the returned nextToken in subsequent ListVersions
operations, which returns results in the next page.
6871 6872 6873 6874 6875 6876 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6871 class ListVersionsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |