Class: Aws::OpenSearchService::Types::ListVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters for response received from the ListVersions operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
When
nextTokenis returned, there are more results available. -
#versions ⇒ Array<String>
A list of all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
Instance Attribute Details
#next_token ⇒ String
When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.
5743 5744 5745 5746 5747 5748 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5743 class ListVersionsResponse < Struct.new( :versions, :next_token) SENSITIVE = [] include Aws::Structure end |
#versions ⇒ Array<String>
A list of all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
5743 5744 5745 5746 5747 5748 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5743 class ListVersionsResponse < Struct.new( :versions, :next_token) SENSITIVE = [] include Aws::Structure end |