Class: Aws::OpenSearchService::Types::ListVpcEndpointsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListVpcEndpointsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
When
nextTokenis returned, there are more results available. -
#vpc_endpoint_summary_list ⇒ Array<Types::VpcEndpointSummary>
Information about each endpoint.
Instance Attribute Details
#next_token ⇒ String
When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.
5813 5814 5815 5816 5817 5818 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5813 class ListVpcEndpointsResponse < Struct.new( :vpc_endpoint_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_summary_list ⇒ Array<Types::VpcEndpointSummary>
Information about each endpoint.
5813 5814 5815 5816 5817 5818 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5813 class ListVpcEndpointsResponse < Struct.new( :vpc_endpoint_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |