Class: Aws::OpenSearchService::Types::MigrationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

A summary of a migration job, including its status and progress.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The unique identifier of the OpenSearch application associated with the migration.

Returns:

  • (String)


7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the migration job was created.

Returns:

  • (Time)


7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::MigrationError

Error details if the migration failed or completed with errors.



7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#exported_countInteger

The number of saved objects exported from the source data source.

Returns:

  • (Integer)


7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#imported_countInteger

The number of saved objects successfully imported into the target workspace.

Returns:

  • (Integer)


7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#migration_idString

The unique identifier of the migration job.

Returns:

  • (String)


7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::MigrationSource

The source configuration for the migration.



7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the migration job.

Returns:

  • (String)


7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time when the migration job was last updated.

Returns:

  • (Time)


7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214

class MigrationSummary < Struct.new(
  :migration_id,
  :status,
  :application_id,
  :source,
  :exported_count,
  :imported_count,
  :error,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end