Class: Aws::OpenSearchService::Types::PackageDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::PackageDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Basic information about a package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_listed_user_list ⇒ Array<String>
A list of users who are allowed to view and associate the package.
-
#available_package_configuration ⇒ Types::PackageConfiguration
This represents the available configuration parameters for the package.
-
#available_package_version ⇒ String
The package version.
-
#available_plugin_properties ⇒ Types::PluginProperties
If the package is a
ZIP-PLUGINpackage, additional information about plugin properties. -
#created_at ⇒ Time
The timestamp when the package was created.
-
#engine_version ⇒ String
Version of OpenSearch or Elasticsearch, in the format Elasticsearch_X.Y or OpenSearch_X.Y.
-
#error_details ⇒ Types::ErrorDetails
Additional information if the package is in an error state.
-
#last_updated_at ⇒ Time
Date and time when the package was last updated.
-
#package_description ⇒ String
User-specified description of the package.
-
#package_encryption_options ⇒ Types::PackageEncryptionOptions
Encryption options for a package.
-
#package_id ⇒ String
The unique identifier of the package.
-
#package_name ⇒ String
The user-specified name of the package.
-
#package_owner ⇒ String
The owner of the package who is allowed to create and update a package and add users to the package scope.
-
#package_status ⇒ String
The current status of the package.
-
#package_type ⇒ String
The type of package.
-
#package_vending_options ⇒ Types::PackageVendingOptions
Package Vending Options for a package.
Instance Attribute Details
#allow_listed_user_list ⇒ Array<String>
A list of users who are allowed to view and associate the package. This field is only visible to the owner of a package.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#available_package_configuration ⇒ Types::PackageConfiguration
This represents the available configuration parameters for the package.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#available_package_version ⇒ String
The package version.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#available_plugin_properties ⇒ Types::PluginProperties
If the package is a ZIP-PLUGIN package, additional information
about plugin properties.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the package was created.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
Version of OpenSearch or Elasticsearch, in the format Elasticsearch_X.Y or OpenSearch_X.Y. Defaults to the latest version of OpenSearch.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#error_details ⇒ Types::ErrorDetails
Additional information if the package is in an error state. Null otherwise.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
Date and time when the package was last updated.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_description ⇒ String
User-specified description of the package.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_encryption_options ⇒ Types::PackageEncryptionOptions
Encryption options for a package.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_id ⇒ String
The unique identifier of the package.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_name ⇒ String
The user-specified name of the package.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_owner ⇒ String
The owner of the package who is allowed to create and update a package and add users to the package scope.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_status ⇒ String
The current status of the package. The available options are
AVAILABLE, COPYING, COPY_FAILED, VALIDATNG,
VALIDATION_FAILED, DELETING, and DELETE_FAILED.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_type ⇒ String
The type of package.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_vending_options ⇒ Types::PackageVendingOptions
Package Vending Options for a package.
7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7755 class PackageDetails < Struct.new( :package_id, :package_name, :package_type, :package_description, :package_status, :created_at, :last_updated_at, :available_package_version, :error_details, :engine_version, :available_plugin_properties, :available_package_configuration, :allow_listed_user_list, :package_owner, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |