Class: Aws::OpenSearchService::Types::PrometheusDirectQueryDataSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Configuration details for a Prometheus data source that can be used for direct queries.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#role_arnString

The unique identifier of the IAM role that grants OpenSearch Service permission to access the specified data source.



6656
6657
6658
6659
6660
6661
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6656

class PrometheusDirectQueryDataSource < Struct.new(
  :role_arn,
  :workspace_arn)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_arnString

The unique identifier of the Amazon Managed Prometheus Workspace that is associated with the specified data source.



6656
6657
6658
6659
6660
6661
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6656

class PrometheusDirectQueryDataSource < Struct.new(
  :role_arn,
  :workspace_arn)
  SENSITIVE = []
  include Aws::Structure
end