Class: Aws::OpenSearchService::Types::RejectInboundConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::RejectInboundConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the request parameters to the ‘RejectInboundConnection` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_id ⇒ String
The unique identifier of the inbound connection to reject.
Instance Attribute Details
#connection_id ⇒ String
The unique identifier of the inbound connection to reject.
7262 7263 7264 7265 7266 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7262 class RejectInboundConnectionRequest < Struct.new( :connection_id) SENSITIVE = [] include Aws::Structure end |