Class: Aws::OpenSearchService::Types::RollbackServiceSoftwareOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Details about the rollback options for a service software update.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_versionString

The current service software version on the domain.

Returns:

  • (String)


8368
8369
8370
8371
8372
8373
8374
8375
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8368

class RollbackServiceSoftwareOptions < Struct.new(
  :current_version,
  :new_version,
  :rollback_available,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the rollback status.

Returns:

  • (String)


8368
8369
8370
8371
8372
8373
8374
8375
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8368

class RollbackServiceSoftwareOptions < Struct.new(
  :current_version,
  :new_version,
  :rollback_available,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#new_versionString

The service software version that the domain will roll back to.

Returns:

  • (String)


8368
8369
8370
8371
8372
8373
8374
8375
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8368

class RollbackServiceSoftwareOptions < Struct.new(
  :current_version,
  :new_version,
  :rollback_available,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_availableBoolean

Whether a service software rollback is available for the domain.

Returns:

  • (Boolean)


8368
8369
8370
8371
8372
8373
8374
8375
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8368

class RollbackServiceSoftwareOptions < Struct.new(
  :current_version,
  :new_version,
  :rollback_available,
  :description)
  SENSITIVE = []
  include Aws::Structure
end