Class: Aws::OpenSearchService::Types::RollbackServiceSoftwareUpdateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::RollbackServiceSoftwareUpdateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the request parameters to the ‘RollbackServiceSoftwareUpdate` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of the domain to roll back the service software update on.
Instance Attribute Details
#domain_name ⇒ String
The name of the domain to roll back the service software update on.
7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7517 class RollbackServiceSoftwareUpdateRequest < Struct.new( :domain_name) SENSITIVE = [] include Aws::Structure end |