Class: Aws::OpenSearchService::Types::SavedObjectIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Identifies a specific saved object by its type and unique identifier.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier of the saved object.

Returns:

  • (String)


8553
8554
8555
8556
8557
8558
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8553

class SavedObjectIdentifier < Struct.new(
  :type,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the saved object, such as dashboard, visualization, index-pattern, search, or query.

Returns:

  • (String)


8553
8554
8555
8556
8557
8558
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8553

class SavedObjectIdentifier < Struct.new(
  :type,
  :id)
  SENSITIVE = []
  include Aws::Structure
end