Class: Aws::OpenSearchService::Types::ServerlessVectorAcceleration
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ServerlessVectorAcceleration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Configuration for serverless vector acceleration, which provides
- GPU-accelerated][1
-
vector search capabilities for improved
performance on vector workloads.
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/gpu-acceleration-vector-index.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether serverless vector acceleration is enabled for the domain.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether serverless vector acceleration is enabled for the domain.
7158 7159 7160 7161 7162 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7158 class ServerlessVectorAcceleration < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |