Class: Aws::OpenSearchService::Types::SnapshotOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

The time, in UTC format, when OpenSearch Service takes a daily automated snapshot of the specified domain. Default is 0 hours.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#automated_snapshot_start_hourInteger

The time, in UTC format, when OpenSearch Service takes a daily automated snapshot of the specified domain. Default is 0 hours.

Returns:

  • (Integer)


7352
7353
7354
7355
7356
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7352

class SnapshotOptions < Struct.new(
  :automated_snapshot_start_hour)
  SENSITIVE = []
  include Aws::Structure
end