Class: Aws::OpenSearchService::Types::StartMigrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::StartMigrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The unique identifier of the OpenSearch application to migrate saved objects into.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#migration_options ⇒ Types::MigrationOptions
The configuration options for the migration, including the source data source, target workspace, export filters, and conflict resolution strategy.
Instance Attribute Details
#application_id ⇒ String
The unique identifier of the OpenSearch application to migrate saved objects into.
8932 8933 8934 8935 8936 8937 8938 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8932 class StartMigrationRequest < Struct.new( :application_id, :migration_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon OpenSearch Service ignores the request but does not return an error.
8932 8933 8934 8935 8936 8937 8938 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8932 class StartMigrationRequest < Struct.new( :application_id, :migration_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#migration_options ⇒ Types::MigrationOptions
The configuration options for the migration, including the source data source, target workspace, export filters, and conflict resolution strategy.
8932 8933 8934 8935 8936 8937 8938 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8932 class StartMigrationRequest < Struct.new( :application_id, :migration_options, :client_token) SENSITIVE = [] include Aws::Structure end |