Class: Aws::OpenSearchService::Types::StartServiceSoftwareUpdateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::StartServiceSoftwareUpdateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the request parameters to the StartServiceSoftwareUpdate operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#desired_start_time ⇒ Integer
The Epoch timestamp when you want the service software update to start.
-
#domain_name ⇒ String
The name of the domain that you want to update to the latest service software.
-
#schedule_at ⇒ String
When to start the service software update.
Instance Attribute Details
#desired_start_time ⇒ Integer
The Epoch timestamp when you want the service software update to start. You only need to specify this parameter if you set ScheduleAt to TIMESTAMP.
7458 7459 7460 7461 7462 7463 7464 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7458 class StartServiceSoftwareUpdateRequest < Struct.new( :domain_name, :schedule_at, :desired_start_time) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain that you want to update to the latest service software.
7458 7459 7460 7461 7462 7463 7464 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7458 class StartServiceSoftwareUpdateRequest < Struct.new( :domain_name, :schedule_at, :desired_start_time) SENSITIVE = [] include Aws::Structure end |
#schedule_at ⇒ String
When to start the service software update.
-
NOW- Immediately schedules the update to happen in the current hour if there’s capacity available. -
TIMESTAMP- Lets you specify a custom date and time to apply the update. If you specify this value, you must also provide a value forDesiredStartTime. -
OFF_PEAK_WINDOW- Marks the update to be picked up during an upcoming off-peak window. There’s no guarantee that the update will happen during the next immediate window. Depending on capacity, it might happen in subsequent days.
Default: NOW if you don’t specify a value for DesiredStartTime, and TIMESTAMP if you do.
7458 7459 7460 7461 7462 7463 7464 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7458 class StartServiceSoftwareUpdateRequest < Struct.new( :domain_name, :schedule_at, :desired_start_time) SENSITIVE = [] include Aws::Structure end |