Class: Aws::OpenSearchService::Types::UpdateDirectQueryDataSourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_source_access_policyString

An optional IAM access policy document that defines the updated permissions for accessing the direct query data source. The policy document must be in valid JSON format and follow IAM policy syntax. If not specified, the existing access policy if present remains unchanged.

Returns:

  • (String)


7733
7734
7735
7736
7737
7738
7739
7740
7741
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7733

class UpdateDirectQueryDataSourceRequest < Struct.new(
  :data_source_name,
  :data_source_type,
  :description,
  :open_search_arns,
  :data_source_access_policy)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_nameString

A unique, user-defined label to identify the data source within your OpenSearch Service environment.

Returns:

  • (String)


7733
7734
7735
7736
7737
7738
7739
7740
7741
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7733

class UpdateDirectQueryDataSourceRequest < Struct.new(
  :data_source_name,
  :data_source_type,
  :description,
  :open_search_arns,
  :data_source_access_policy)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_typeTypes::DirectQueryDataSourceType

The supported Amazon Web Services service that you want to use as the source for direct queries in OpenSearch Service.



7733
7734
7735
7736
7737
7738
7739
7740
7741
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7733

class UpdateDirectQueryDataSourceRequest < Struct.new(
  :data_source_name,
  :data_source_type,
  :description,
  :open_search_arns,
  :data_source_access_policy)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional text field for providing additional context and details about the data source.

Returns:

  • (String)


7733
7734
7735
7736
7737
7738
7739
7740
7741
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7733

class UpdateDirectQueryDataSourceRequest < Struct.new(
  :data_source_name,
  :data_source_type,
  :description,
  :open_search_arns,
  :data_source_access_policy)
  SENSITIVE = []
  include Aws::Structure
end

#open_search_arnsArray<String>

A list of Amazon Resource Names (ARNs) for the OpenSearch collections that are associated with the direct query data source.

Returns:

  • (Array<String>)


7733
7734
7735
7736
7737
7738
7739
7740
7741
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7733

class UpdateDirectQueryDataSourceRequest < Struct.new(
  :data_source_name,
  :data_source_type,
  :description,
  :open_search_arns,
  :data_source_access_policy)
  SENSITIVE = []
  include Aws::Structure
end