Class: Aws::OpenSearchService::Types::UpdateDomainConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::UpdateDomainConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the request parameters to the UpdateDomain operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policies ⇒ String
Identity and Access Management (IAM) access policy as a JSON-formatted string.
-
#advanced_options ⇒ Hash<String,String>
Key-value pairs to specify advanced configuration options.
-
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsInput
Options for fine-grained access control.
-
#aiml_options ⇒ Types::AIMLOptionsInput
Options for all machine learning features for the specified domain.
-
#auto_tune_options ⇒ Types::AutoTuneOptions
Options for Auto-Tune.
-
#automated_snapshot_pause_options ⇒ Types::AutomatedSnapshotPauseRequestOptions
Specifies the automated snapshot pause options for the domain.
-
#cluster_config ⇒ Types::ClusterConfig
Changes that you want to make to the cluster configuration, such as the instance type and number of EC2 instances.
-
#cognito_options ⇒ Types::CognitoOptions
Key-value pairs to configure Amazon Cognito authentication for OpenSearch Dashboards.
-
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptions
Specifies the deployment strategy options for the domain.
-
#domain_endpoint_options ⇒ Types::DomainEndpointOptions
Additional options for the domain endpoint, such as whether to require HTTPS for all traffic.
-
#domain_name ⇒ String
The name of the domain that you're updating.
-
#dry_run ⇒ Boolean
This flag, when set to True, specifies whether the
UpdateDomainrequest should return the results of a dry run analysis without actually applying the change. -
#dry_run_mode ⇒ String
The type of dry run to perform.
-
#ebs_options ⇒ Types::EBSOptions
The type and size of the EBS volume to attach to instances in the domain.
-
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptions
Encryption at rest options for the domain.
-
#engine_mode ⇒ String
The engine mode for the domain.
-
#identity_center_options ⇒ Types::IdentityCenterOptionsInput
Configuration settings for enabling and managing IAM Identity Center.
-
#ip_address_type ⇒ String
Specify either dual stack or IPv4 as your IP address type.
-
#log_publishing_options ⇒ Hash<String,Types::LogPublishingOption>
Options to publish OpenSearch logs to Amazon CloudWatch Logs.
-
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptions
Node-to-node encryption options for the domain.
-
#off_peak_window_options ⇒ Types::OffPeakWindowOptions
Off-peak window options for the domain.
-
#snapshot_options ⇒ Types::SnapshotOptions
Option to set the time, in UTC format, for the daily automated snapshot.
-
#software_update_options ⇒ Types::SoftwareUpdateOptions
Service software update options for the domain.
-
#use_case ⇒ String
The primary use case for the domain.
-
#vpc_options ⇒ Types::VPCOptions
Options to specify the subnets and security groups for a VPC endpoint.
Instance Attribute Details
#access_policies ⇒ String
Identity and Access Management (IAM) access policy as a JSON-formatted string.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#advanced_options ⇒ Hash<String,String>
Key-value pairs to specify advanced configuration options. The following key-value pairs are supported:
-
"rest.action.multi.allow_explicit_index": "true" | "false"- Note the use of a string rather than a boolean. Specifies whether explicit references to indexes are allowed inside the body of HTTP requests. If you want to configure access policies for domain sub-resources, such as specific indexes and domain APIs, you must disable this property. Default is true. -
"indices.fielddata.cache.size": "80"- Note the use of a string rather than a boolean. Specifies the percentage of heap space allocated to field data. Default is unbounded. -
"indices.query.bool.max_clause_count": "1024"- Note the use of a string rather than a boolean. Specifies the maximum number of clauses allowed in a Lucene boolean query. Default is 1,024. Queries with more than the permitted number of clauses result in aTooManyClauseserror.
For more information, see Advanced cluster parameters.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsInput
Options for fine-grained access control.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#aiml_options ⇒ Types::AIMLOptionsInput
Options for all machine learning features for the specified domain.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#auto_tune_options ⇒ Types::AutoTuneOptions
Options for Auto-Tune.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#automated_snapshot_pause_options ⇒ Types::AutomatedSnapshotPauseRequestOptions
Specifies the automated snapshot pause options for the domain.
Suspending snapshots reduces data protection. You cannot restore your domain to points in time when snapshots are suspended. Use this feature only for short-term operational needs such as migrations or maintenance windows.
Maximum suspension duration: 3 days.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#cluster_config ⇒ Types::ClusterConfig
Changes that you want to make to the cluster configuration, such as the instance type and number of EC2 instances.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#cognito_options ⇒ Types::CognitoOptions
Key-value pairs to configure Amazon Cognito authentication for OpenSearch Dashboards.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptions
Specifies the deployment strategy options for the domain.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#domain_endpoint_options ⇒ Types::DomainEndpointOptions
Additional options for the domain endpoint, such as whether to require HTTPS for all traffic.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain that you're updating.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
This flag, when set to True, specifies whether the UpdateDomain
request should return the results of a dry run analysis without
actually applying the change. A dry run determines what type of
deployment the update will cause.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#dry_run_mode ⇒ String
The type of dry run to perform.
-
Basiconly returns the type of deployment (blue/green or dynamic) that the update will cause. -
Verboseruns an additional check to validate the changes you're making. For more information, see Validating a domain update.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#ebs_options ⇒ Types::EBSOptions
The type and size of the EBS volume to attach to instances in the domain.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptions
Encryption at rest options for the domain.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#engine_mode ⇒ String
The engine mode for the domain. The engine mode can't be changed
after the domain is created. For valid values, see EngineMode.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#identity_center_options ⇒ Types::IdentityCenterOptionsInput
Configuration settings for enabling and managing IAM Identity Center.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
Specify either dual stack or IPv4 as your IP address type. Dual stack allows you to share domain resources across IPv4 and IPv6 address types, and is the recommended option. If your IP address type is currently set to dual stack, you can't change it.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#log_publishing_options ⇒ Hash<String,Types::LogPublishingOption>
Options to publish OpenSearch logs to Amazon CloudWatch Logs.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptions
Node-to-node encryption options for the domain.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#off_peak_window_options ⇒ Types::OffPeakWindowOptions
Off-peak window options for the domain.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#snapshot_options ⇒ Types::SnapshotOptions
Option to set the time, in UTC format, for the daily automated
snapshot. Default value is 0 hours.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#software_update_options ⇒ Types::SoftwareUpdateOptions
Service software update options for the domain.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#use_case ⇒ String
The primary use case for the domain. For valid values, see
DomainUseCase.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |
#vpc_options ⇒ Types::VPCOptions
Options to specify the subnets and security groups for a VPC endpoint. For more information, see Launching your Amazon OpenSearch Service domains using a VPC.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9465 class UpdateDomainConfigRequest < Struct.new( :domain_name, :cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :ip_address_type, :log_publishing_options, :encryption_at_rest_options, :domain_endpoint_options, :node_to_node_encryption_options, :advanced_security_options, :identity_center_options, :auto_tune_options, :dry_run, :dry_run_mode, :off_peak_window_options, :software_update_options, :aiml_options, :deployment_strategy_options, :automated_snapshot_pause_options, :use_case, :engine_mode) SENSITIVE = [] include Aws::Structure end |