Class: Aws::OpenSearchService::Types::UpdatePackageScopeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationString

The operation to perform on the package scope (e.g., add/remove/override users).

Returns:

  • (String)


8647
8648
8649
8650
8651
8652
8653
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8647

class UpdatePackageScopeRequest < Struct.new(
  :package_id,
  :operation,
  :package_user_list)
  SENSITIVE = []
  include Aws::Structure
end

#package_idString

ID of the package whose scope is being updated.

Returns:

  • (String)


8647
8648
8649
8650
8651
8652
8653
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8647

class UpdatePackageScopeRequest < Struct.new(
  :package_id,
  :operation,
  :package_user_list)
  SENSITIVE = []
  include Aws::Structure
end

#package_user_listArray<String>

List of users to be added or removed from the package scope.

Returns:

  • (Array<String>)


8647
8648
8649
8650
8651
8652
8653
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8647

class UpdatePackageScopeRequest < Struct.new(
  :package_id,
  :operation,
  :package_user_list)
  SENSITIVE = []
  include Aws::Structure
end