Class: Aws::OpenSearchService::Types::UpdatePackageScopeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationString

The operation that was performed on the package scope.

Returns:



8081
8082
8083
8084
8085
8086
8087
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8081

class UpdatePackageScopeResponse < Struct.new(
  :package_id,
  :operation,
  :package_user_list)
  SENSITIVE = []
  include Aws::Structure
end

#package_idString

ID of the package whose scope was updated.

Returns:



8081
8082
8083
8084
8085
8086
8087
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8081

class UpdatePackageScopeResponse < Struct.new(
  :package_id,
  :operation,
  :package_user_list)
  SENSITIVE = []
  include Aws::Structure
end

#package_user_listArray<String>

List of users who have access to the package after the scope update.

Returns:



8081
8082
8083
8084
8085
8086
8087
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8081

class UpdatePackageScopeResponse < Struct.new(
  :package_id,
  :operation,
  :package_user_list)
  SENSITIVE = []
  include Aws::Structure
end