Class: Aws::OpenSearchService::Types::UpgradeHistory

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

History of the last 10 upgrades and upgrade eligibility checks for an Amazon OpenSearch Service domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#start_timestampTime

UTC timestamp at which the upgrade API call was made, in the format yyyy-MM-ddTHH:mm:ssZ.



8328
8329
8330
8331
8332
8333
8334
8335
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8328

class UpgradeHistory < Struct.new(
  :upgrade_name,
  :start_timestamp,
  :upgrade_status,
  :steps_list)
  SENSITIVE = []
  include Aws::Structure
end

#steps_listArray<Types::UpgradeStepItem>

A list of each step performed as part of a specific upgrade or upgrade eligibility check.



8328
8329
8330
8331
8332
8333
8334
8335
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8328

class UpgradeHistory < Struct.new(
  :upgrade_name,
  :start_timestamp,
  :upgrade_status,
  :steps_list)
  SENSITIVE = []
  include Aws::Structure
end

#upgrade_nameString

A string that describes the upgrade.



8328
8329
8330
8331
8332
8333
8334
8335
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8328

class UpgradeHistory < Struct.new(
  :upgrade_name,
  :start_timestamp,
  :upgrade_status,
  :steps_list)
  SENSITIVE = []
  include Aws::Structure
end

#upgrade_statusString

The current status of the upgrade. The status can take one of the following values:

  • In Progress

  • Succeeded

  • Succeeded with Issues

  • Failed



8328
8329
8330
8331
8332
8333
8334
8335
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8328

class UpgradeHistory < Struct.new(
  :upgrade_name,
  :start_timestamp,
  :upgrade_status,
  :steps_list)
  SENSITIVE = []
  include Aws::Structure
end