Class: Aws::OpenSearchService::Types::UseCaseStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::UseCaseStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The status of the use case for the domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#options ⇒ String
The use case configured for the domain.
-
#status ⇒ Types::OptionStatus
The current status of the use case for the domain.
Instance Attribute Details
#options ⇒ String
The use case configured for the domain.
9932 9933 9934 9935 9936 9937 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9932 class UseCaseStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OptionStatus
The current status of the use case for the domain.
9932 9933 9934 9935 9936 9937 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9932 class UseCaseStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |