Class: Aws::OpenSearchService::Types::VPCDerivedInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Information about the subnets and security groups for an Amazon OpenSearch Service domain provisioned within a virtual private cloud (VPC). For more information, see Launching your Amazon OpenSearch Service domains using a VPC. This information only exists if the domain was created with VPCOptions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zonesArray<String>

The list of Availability Zones associated with the VPC subnets.

Returns:

  • (Array<String>)


9977
9978
9979
9980
9981
9982
9983
9984
9985
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9977

class VPCDerivedInfo < Struct.new(
  :vpc_id,
  :subnet_ids,
  :availability_zones,
  :security_group_ids,
  :egress_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#egress_enabledBoolean

Indicates whether egress traffic from the domain is routed through the customer VPC. When true, outbound traffic flows through the VPC. When false, outbound traffic goes through the public internet.

Returns:

  • (Boolean)


9977
9978
9979
9980
9981
9982
9983
9984
9985
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9977

class VPCDerivedInfo < Struct.new(
  :vpc_id,
  :subnet_ids,
  :availability_zones,
  :security_group_ids,
  :egress_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The list of security group IDs associated with the VPC endpoints for the domain.

Returns:

  • (Array<String>)


9977
9978
9979
9980
9981
9982
9983
9984
9985
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9977

class VPCDerivedInfo < Struct.new(
  :vpc_id,
  :subnet_ids,
  :availability_zones,
  :security_group_ids,
  :egress_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

A list of subnet IDs associated with the VPC endpoints for the domain.

Returns:

  • (Array<String>)


9977
9978
9979
9980
9981
9982
9983
9984
9985
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9977

class VPCDerivedInfo < Struct.new(
  :vpc_id,
  :subnet_ids,
  :availability_zones,
  :security_group_ids,
  :egress_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID for your VPC. Amazon VPC generates this value when you create a VPC.

Returns:

  • (String)


9977
9978
9979
9980
9981
9982
9983
9984
9985
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9977

class VPCDerivedInfo < Struct.new(
  :vpc_id,
  :subnet_ids,
  :availability_zones,
  :security_group_ids,
  :egress_enabled)
  SENSITIVE = []
  include Aws::Structure
end