Class: Aws::OpenSearchService::Types::VpcEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::VpcEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The connection endpoint for connecting to an Amazon OpenSearch Service domain through a proxy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_arn ⇒ String
The Amazon Resource Name (ARN) of the domain associated with the endpoint.
-
#endpoint ⇒ String
The connection endpoint ID for connecting to the domain.
-
#status ⇒ String
The current status of the endpoint.
-
#vpc_endpoint_id ⇒ String
The unique identifier of the endpoint.
-
#vpc_endpoint_owner ⇒ String
The creator of the endpoint.
-
#vpc_options ⇒ Types::VPCDerivedInfo
Options to specify the subnets and security groups for an Amazon OpenSearch Service VPC endpoint.
Instance Attribute Details
#domain_arn ⇒ String
The Amazon Resource Name (ARN) of the domain associated with the endpoint.
9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9598 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_owner, :domain_arn, :vpc_options, :status, :endpoint) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The connection endpoint ID for connecting to the domain.
9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9598 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_owner, :domain_arn, :vpc_options, :status, :endpoint) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the endpoint.
9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9598 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_owner, :domain_arn, :vpc_options, :status, :endpoint) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The unique identifier of the endpoint.
9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9598 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_owner, :domain_arn, :vpc_options, :status, :endpoint) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_owner ⇒ String
The creator of the endpoint.
9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9598 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_owner, :domain_arn, :vpc_options, :status, :endpoint) SENSITIVE = [] include Aws::Structure end |
#vpc_options ⇒ Types::VPCDerivedInfo
Options to specify the subnets and security groups for an Amazon OpenSearch Service VPC endpoint.
9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9598 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_owner, :domain_arn, :vpc_options, :status, :endpoint) SENSITIVE = [] include Aws::Structure end |