Class: Aws::OpenSearchService::Types::WorkspaceConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Configuration for creating a new workspace when attaching a data source to an OpenSearch application. The workspace is created after the data source is successfully attached.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the workspace to create. Must be between 1 and 40 characters and can contain alphanumeric characters, parentheses, brackets, hyphens, underscores, and spaces.

Returns:

  • (String)


10229
10230
10231
10232
10233
10234
# File 'lib/aws-sdk-opensearchservice/types.rb', line 10229

class WorkspaceConfigurationInput < Struct.new(
  :name,
  :workspace_type)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_typeString

The type of workspace to create, which determines the use-case features enabled for the workspace. Valid values are OBSERVABILITY, SECURITY_ANALYTICS, and SEARCH.

Returns:

  • (String)


10229
10230
10231
10232
10233
10234
# File 'lib/aws-sdk-opensearchservice/types.rb', line 10229

class WorkspaceConfigurationInput < Struct.new(
  :name,
  :workspace_type)
  SENSITIVE = []
  include Aws::Structure
end