Class: Aws::OpenSearchService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::OpenSearchService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-opensearchservice/client.rb
Overview
An API client for OpenSearchService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::OpenSearchService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_inbound_connection(params = {}) ⇒ Types::AcceptInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to accept an inbound cross-cluster search connection request.
-
#add_data_source(params = {}) ⇒ Types::AddDataSourceResponse
Creates a new direct-query data source to the specified domain.
-
#add_direct_query_data_source(params = {}) ⇒ Types::AddDirectQueryDataSourceResponse
Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data.
-
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Amazon OpenSearch Service domain, data source, or application.
-
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon OpenSearch Service domain.
-
#associate_packages(params = {}) ⇒ Types::AssociatePackagesResponse
Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.
-
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
-
#cancel_service_software_update(params = {}) ⇒ Types::CancelServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon OpenSearch Service domain.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an OpenSearch UI application.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates an Amazon OpenSearch Service domain.
-
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an OpenSearch index with optional automatic semantic enrichment for specified text fields.
-
#create_outbound_connection(params = {}) ⇒ Types::CreateOutboundConnectionResponse
Creates a new cross-cluster search connection from a source Amazon OpenSearch Service domain to a destination domain.
-
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Creates a package for use with Amazon OpenSearch Service domains.
-
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
-
#delete_application(params = {}) ⇒ Struct
Deletes a specified OpenSearch application.
-
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceResponse
Deletes a direct-query data source.
-
#delete_direct_query_data_source(params = {}) ⇒ Struct
Deletes a previously configured direct query data source from Amazon OpenSearch Service.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Deletes an Amazon OpenSearch Service domain and all of its data.
-
#delete_inbound_connection(params = {}) ⇒ Types::DeleteInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to delete an existing inbound cross-cluster search connection.
-
#delete_index(params = {}) ⇒ Types::DeleteIndexResponse
Deletes an OpenSearch index.
-
#delete_outbound_connection(params = {}) ⇒ Types::DeleteOutboundConnectionResponse
Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection.
-
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Deletes an Amazon OpenSearch Service package.
-
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#deregister_capability(params = {}) ⇒ Types::DeregisterCapabilityResponse
Deregisters a capability from an OpenSearch UI application.
-
#describe_domain(params = {}) ⇒ Types::DescribeDomainResponse
Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN.
-
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain.
-
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain.
-
#describe_domain_config(params = {}) ⇒ Types::DescribeDomainConfigResponse
Returns the configuration of an Amazon OpenSearch Service domain.
-
#describe_domain_health(params = {}) ⇒ Types::DescribeDomainHealthResponse
Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node.
-
#describe_domain_nodes(params = {}) ⇒ Types::DescribeDomainNodesResponse
Returns information about domain and nodes, including data nodes, master nodes, ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and node states.
-
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Returns domain configuration information about the specified Amazon OpenSearch Service domains.
-
#describe_dry_run_progress(params = {}) ⇒ Types::DescribeDryRunProgressResponse
Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain.
-
#describe_inbound_connections(params = {}) ⇒ Types::DescribeInboundConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain.
-
#describe_insight_details(params = {}) ⇒ Types::DescribeInsightDetailsResponse
Describes the details of an existing insight for an Amazon OpenSearch Service domain.
-
#describe_instance_type_limits(params = {}) ⇒ Types::DescribeInstanceTypeLimitsResponse
Describes the instance count, storage, and master node limits for a given OpenSearch or Elasticsearch version and instance type.
-
#describe_outbound_connections(params = {}) ⇒ Types::DescribeOutboundConnectionsResponse
Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain.
-
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to OpenSearch Service.
-
#describe_reserved_instance_offerings(params = {}) ⇒ Types::DescribeReservedInstanceOfferingsResponse
Describes the available Amazon OpenSearch Service Reserved Instance offerings for a given Region.
-
#describe_reserved_instances(params = {}) ⇒ Types::DescribeReservedInstancesResponse
Describes the Amazon OpenSearch Service instances that you have reserved in a given Region.
-
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
-
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Removes a package from the specified Amazon OpenSearch Service domain.
-
#dissociate_packages(params = {}) ⇒ Types::DissociatePackagesResponse
Dissociates multiple packages from a domain simultaneously.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves the configuration and status of an existing OpenSearch application.
-
#get_capability(params = {}) ⇒ Types::GetCapabilityResponse
Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
-
#get_compatible_versions(params = {}) ⇒ Types::GetCompatibleVersionsResponse
Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to.
-
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves information about a direct query data source.
-
#get_default_application_setting(params = {}) ⇒ Types::GetDefaultApplicationSettingResponse
Gets the ARN of the current default application.
-
#get_direct_query_data_source(params = {}) ⇒ Types::GetDirectQueryDataSourceResponse
Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service.
-
#get_domain_maintenance_status(params = {}) ⇒ Types::GetDomainMaintenanceStatusResponse
The status of the maintenance action.
-
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an OpenSearch index including its schema and semantic enrichment configuration.
-
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of Amazon OpenSearch Service package versions, along with their creation time, commit message, and plugin properties (if the package is a zip plugin package).
-
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades performed on an Amazon OpenSearch Service domain.
-
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all OpenSearch applications under your account.
-
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists direct-query data sources for a specific domain.
-
#list_direct_query_data_sources(params = {}) ⇒ Types::ListDirectQueryDataSourcesResponse
Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.
-
#list_domain_maintenances(params = {}) ⇒ Types::ListDomainMaintenancesResponse
A list of maintenance actions for the domain.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the names of all Amazon OpenSearch Service domains owned by the current user in the active Region.
-
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon OpenSearch Service domains associated with a given package.
-
#list_insights(params = {}) ⇒ Types::ListInsightsResponse
Lists insights for an Amazon OpenSearch Service domain or Amazon Web Services account.
-
#list_instance_type_details(params = {}) ⇒ Types::ListInstanceTypeDetailsResponse
Lists all instance types and available features for a given OpenSearch or Elasticsearch version.
-
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with an Amazon OpenSearch Service domain.
-
#list_scheduled_actions(params = {}) ⇒ Types::ListScheduledActionsResponse
Retrieves a list of configuration changes that are scheduled for a domain.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all resource tags for an Amazon OpenSearch Service domain, data source, or application.
-
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
-
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.
-
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
-
#purchase_reserved_instance_offering(params = {}) ⇒ Types::PurchaseReservedInstanceOfferingResponse
Allows you to purchase Amazon OpenSearch Service Reserved Instances.
-
#put_default_application_setting(params = {}) ⇒ Types::PutDefaultApplicationSettingResponse
Sets the default application to the application with the specified ARN.
-
#register_capability(params = {}) ⇒ Types::RegisterCapabilityResponse
Registers a capability for an OpenSearch UI application.
-
#reject_inbound_connection(params = {}) ⇒ Types::RejectInboundConnectionResponse
Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request.
-
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from an Amazon OpenSearch Service domain, data source, or application.
-
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
-
#rollback_service_software_update(params = {}) ⇒ Types::RollbackServiceSoftwareUpdateResponse
Rolls back a service software update for a domain to the previous version.
-
#start_domain_maintenance(params = {}) ⇒ Types::StartDomainMaintenanceResponse
Starts the node maintenance process on the data node.
-
#start_service_software_update(params = {}) ⇒ Types::StartServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon OpenSearch Service domain.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration and settings of an existing OpenSearch application.
-
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a direct-query data source.
-
#update_direct_query_data_source(params = {}) ⇒ Types::UpdateDirectQueryDataSourceResponse
Updates the configuration or properties of an existing direct query data source in Amazon OpenSearch Service.
-
#update_domain_config(params = {}) ⇒ Types::UpdateDomainConfigResponse
Modifies the cluster configuration of the specified Amazon OpenSearch Service domain.
-
#update_index(params = {}) ⇒ Types::UpdateIndexResponse
Updates an existing OpenSearch index schema and semantic enrichment configuration.
-
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon OpenSearch Service domains.
-
#update_package_scope(params = {}) ⇒ Types::UpdatePackageScopeResponse
Updates the scope of a package.
-
#update_scheduled_action(params = {}) ⇒ Types::UpdateScheduledActionResponse
Reschedules a planned domain configuration change for a later time.
-
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#upgrade_domain(params = {}) ⇒ Types::UpgradeDomainResponse
Allows you to either upgrade your Amazon OpenSearch Service domain or perform an upgrade eligibility check to a compatible version of OpenSearch or Elasticsearch.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6541 6542 6543 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6541 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6544 6545 6546 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6544 def errors_module Errors end |
Instance Method Details
#accept_inbound_connection(params = {}) ⇒ Types::AcceptInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to accept an inbound cross-cluster search connection request. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
518 519 520 521 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 518 def accept_inbound_connection(params = {}, = {}) req = build_request(:accept_inbound_connection, params) req.send_request() end |
#add_data_source(params = {}) ⇒ Types::AddDataSourceResponse
Creates a new direct-query data source to the specified domain. For more information, see [Creating Amazon OpenSearch Service data source integrations with Amazon S3].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-creating.html
568 569 570 571 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 568 def add_data_source(params = {}, = {}) req = build_request(:add_data_source, params) req.send_request() end |
#add_direct_query_data_source(params = {}) ⇒ Types::AddDirectQueryDataSourceResponse
Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data.
641 642 643 644 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 641 def add_direct_query_data_source(params = {}, = {}) req = build_request(:add_direct_query_data_source, params) req.send_request() end |
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Amazon OpenSearch Service domain, data source, or application.
Tags are a set of case-sensitive key-value pairs. A domain, data source, or application can have up to 10 tags. For more information, see [Tagging Amazon OpenSearch Service resources].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-awsresourcetagging.html
682 683 684 685 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 682 def (params = {}, = {}) req = build_request(:add_tags, params) req.send_request() end |
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon OpenSearch Service domain. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
749 750 751 752 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 749 def associate_package(params = {}, = {}) req = build_request(:associate_package, params) req.send_request() end |
#associate_packages(params = {}) ⇒ Types::AssociatePackagesResponse
Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.
810 811 812 813 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 810 def associate_packages(params = {}, = {}) req = build_request(:associate_packages, params) req.send_request() end |
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
857 858 859 860 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 857 def (params = {}, = {}) req = build_request(:authorize_vpc_endpoint_access, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 6529 6530 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6514 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::OpenSearchService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-opensearchservice' context[:gem_version] = '1.98.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
901 902 903 904 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 901 def cancel_domain_config_change(params = {}, = {}) req = build_request(:cancel_domain_config_change, params) req.send_request() end |
#cancel_service_software_update(params = {}) ⇒ Types::CancelServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon OpenSearch Service domain. You can only perform this operation before the ‘AutomatedUpdateDate` and when the domain’s ‘UpdateStatus` is `PENDING_UPDATE`. For more information, see [Service software updates in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html
945 946 947 948 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 945 def cancel_service_software_update(params = {}, = {}) req = build_request(:cancel_service_software_update, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an OpenSearch UI application. For more information, see [Using the OpenSearch user interface in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/application.html
1059 1060 1061 1062 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1059 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates an Amazon OpenSearch Service domain. For more information, see [Creating and managing Amazon OpenSearch Service domains].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/createupdatedomains.html
1503 1504 1505 1506 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1503 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an OpenSearch index with optional automatic semantic enrichment for specified text fields. Automatic semantic enrichment enables semantic search capabilities without requiring machine learning expertise, improving search relevance by up to 20% by understanding search intent and contextual meaning beyond keyword matching. The semantic enrichment process has zero impact on search latency as sparse encodings are stored directly within the index during indexing. For more information, see [Automatic semantic enrichment].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/opensearch-semantic-enrichment.html
1563 1564 1565 1566 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1563 def create_index(params = {}, = {}) req = build_request(:create_index, params) req.send_request() end |
#create_outbound_connection(params = {}) ⇒ Types::CreateOutboundConnectionResponse
Creates a new cross-cluster search connection from a source Amazon OpenSearch Service domain to a destination domain. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
1649 1650 1651 1652 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1649 def create_outbound_connection(params = {}, = {}) req = build_request(:create_outbound_connection, params) req.send_request() end |
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Creates a package for use with Amazon OpenSearch Service domains. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
1752 1753 1754 1755 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1752 def create_package(params = {}, = {}) req = build_request(:create_package, params) req.send_request() end |
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
1806 1807 1808 1809 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1806 def create_vpc_endpoint(params = {}, = {}) req = build_request(:create_vpc_endpoint, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes a specified OpenSearch application.
1828 1829 1830 1831 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1828 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceResponse
Deletes a direct-query data source. For more information, see [Deleting an Amazon OpenSearch Service data source with Amazon S3].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-delete.html
1865 1866 1867 1868 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1865 def delete_data_source(params = {}, = {}) req = build_request(:delete_data_source, params) req.send_request() end |
#delete_direct_query_data_source(params = {}) ⇒ Struct
Deletes a previously configured direct query data source from Amazon OpenSearch Service.
1889 1890 1891 1892 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1889 def delete_direct_query_data_source(params = {}, = {}) req = build_request(:delete_direct_query_data_source, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Deletes an Amazon OpenSearch Service domain and all of its data. You can’t recover a domain after you delete it.
2038 2039 2040 2041 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2038 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#delete_inbound_connection(params = {}) ⇒ Types::DeleteInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to delete an existing inbound cross-cluster search connection. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
2082 2083 2084 2085 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2082 def delete_inbound_connection(params = {}, = {}) req = build_request(:delete_inbound_connection, params) req.send_request() end |
#delete_index(params = {}) ⇒ Types::DeleteIndexResponse
Deletes an OpenSearch index. This operation permanently removes the index and cannot be undone.
2117 2118 2119 2120 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2117 def delete_index(params = {}, = {}) req = build_request(:delete_index, params) req.send_request() end |
#delete_outbound_connection(params = {}) ⇒ Types::DeleteOutboundConnectionResponse
Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
2164 2165 2166 2167 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2164 def delete_outbound_connection(params = {}, = {}) req = build_request(:delete_outbound_connection, params) req.send_request() end |
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Deletes an Amazon OpenSearch Service package. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
2223 2224 2225 2226 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2223 def delete_package(params = {}, = {}) req = build_request(:delete_package, params) req.send_request() end |
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
2254 2255 2256 2257 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2254 def delete_vpc_endpoint(params = {}, = {}) req = build_request(:delete_vpc_endpoint, params) req.send_request() end |
#deregister_capability(params = {}) ⇒ Types::DeregisterCapabilityResponse
Deregisters a capability from an OpenSearch UI application. This operation removes the capability and its associated configuration.
2288 2289 2290 2291 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2288 def deregister_capability(params = {}, = {}) req = build_request(:deregister_capability, params) req.send_request() end |
#describe_domain(params = {}) ⇒ Types::DescribeDomainResponse
Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN.
2438 2439 2440 2441 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2438 def describe_domain(params = {}, = {}) req = build_request(:describe_domain, params) req.send_request() end |
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain. For more information, see [Auto-Tune for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2493 2494 2495 2496 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2493 def describe_domain_auto_tunes(params = {}, = {}) req = build_request(:describe_domain_auto_tunes, params) req.send_request() end |
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain. For more information, see [Making configuration changes in Amazon OpenSearch Service].
2548 2549 2550 2551 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2548 def describe_domain_change_progress(params = {}, = {}) req = build_request(:describe_domain_change_progress, params) req.send_request() end |
#describe_domain_config(params = {}) ⇒ Types::DescribeDomainConfigResponse
Returns the configuration of an Amazon OpenSearch Service domain.
2782 2783 2784 2785 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2782 def describe_domain_config(params = {}, = {}) req = build_request(:describe_domain_config, params) req.send_request() end |
#describe_domain_health(params = {}) ⇒ Types::DescribeDomainHealthResponse
Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node.
2843 2844 2845 2846 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2843 def describe_domain_health(params = {}, = {}) req = build_request(:describe_domain_health, params) req.send_request() end |
#describe_domain_nodes(params = {}) ⇒ Types::DescribeDomainNodesResponse
Returns information about domain and nodes, including data nodes, master nodes, ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and node states.
2881 2882 2883 2884 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2881 def describe_domain_nodes(params = {}, = {}) req = build_request(:describe_domain_nodes, params) req.send_request() end |
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Returns domain configuration information about the specified Amazon OpenSearch Service domains.
3032 3033 3034 3035 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3032 def describe_domains(params = {}, = {}) req = build_request(:describe_domains, params) req.send_request() end |
#describe_dry_run_progress(params = {}) ⇒ Types::DescribeDryRunProgressResponse
Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain. For more information, see [Determining whether a change will cause a blue/green deployment].
3207 3208 3209 3210 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3207 def describe_dry_run_progress(params = {}, = {}) req = build_request(:describe_dry_run_progress, params) req.send_request() end |
#describe_inbound_connections(params = {}) ⇒ Types::DescribeInboundConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3274 3275 3276 3277 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3274 def describe_inbound_connections(params = {}, = {}) req = build_request(:describe_inbound_connections, params) req.send_request() end |
#describe_insight_details(params = {}) ⇒ Types::DescribeInsightDetailsResponse
Describes the details of an existing insight for an Amazon OpenSearch Service domain. Returns detailed fields associated with the specified insight, such as text descriptions and metric data.
3321 3322 3323 3324 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3321 def describe_insight_details(params = {}, = {}) req = build_request(:describe_insight_details, params) req.send_request() end |
#describe_instance_type_limits(params = {}) ⇒ Types::DescribeInstanceTypeLimitsResponse
Describes the instance count, storage, and master node limits for a given OpenSearch or Elasticsearch version and instance type.
3375 3376 3377 3378 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3375 def describe_instance_type_limits(params = {}, = {}) req = build_request(:describe_instance_type_limits, params) req.send_request() end |
#describe_outbound_connections(params = {}) ⇒ Types::DescribeOutboundConnectionsResponse
Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3443 3444 3445 3446 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3443 def describe_outbound_connections(params = {}, = {}) req = build_request(:describe_outbound_connections, params) req.send_request() end |
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to OpenSearch Service. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3524 3525 3526 3527 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3524 def describe_packages(params = {}, = {}) req = build_request(:describe_packages, params) req.send_request() end |
#describe_reserved_instance_offerings(params = {}) ⇒ Types::DescribeReservedInstanceOfferingsResponse
Describes the available Amazon OpenSearch Service Reserved Instance offerings for a given Region. For more information, see [Reserved Instances in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/ri.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3586 3587 3588 3589 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3586 def describe_reserved_instance_offerings(params = {}, = {}) req = build_request(:describe_reserved_instance_offerings, params) req.send_request() end |
#describe_reserved_instances(params = {}) ⇒ Types::DescribeReservedInstancesResponse
Describes the Amazon OpenSearch Service instances that you have reserved in a given Region. For more information, see [Reserved Instances in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/ri.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3654 3655 3656 3657 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3654 def describe_reserved_instances(params = {}, = {}) req = build_request(:describe_reserved_instances, params) req.send_request() end |
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
3700 3701 3702 3703 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3700 def describe_vpc_endpoints(params = {}, = {}) req = build_request(:describe_vpc_endpoints, params) req.send_request() end |
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Removes a package from the specified Amazon OpenSearch Service domain. The package can’t be in use with any OpenSearch index for the dissociation to succeed. The package is still available in OpenSearch Service for association later. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
3754 3755 3756 3757 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3754 def dissociate_package(params = {}, = {}) req = build_request(:dissociate_package, params) req.send_request() end |
#dissociate_packages(params = {}) ⇒ Types::DissociatePackagesResponse
Dissociates multiple packages from a domain simultaneously.
3802 3803 3804 3805 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3802 def dissociate_packages(params = {}, = {}) req = build_request(:dissociate_packages, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves the configuration and status of an existing OpenSearch application.
3859 3860 3861 3862 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3859 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_capability(params = {}) ⇒ Types::GetCapabilityResponse
Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
3901 3902 3903 3904 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3901 def get_capability(params = {}, = {}) req = build_request(:get_capability, params) req.send_request() end |
#get_compatible_versions(params = {}) ⇒ Types::GetCompatibleVersionsResponse
Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to.
3934 3935 3936 3937 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3934 def get_compatible_versions(params = {}, = {}) req = build_request(:get_compatible_versions, params) req.send_request() end |
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves information about a direct query data source.
3972 3973 3974 3975 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3972 def get_data_source(params = {}, = {}) req = build_request(:get_data_source, params) req.send_request() end |
#get_default_application_setting(params = {}) ⇒ Types::GetDefaultApplicationSettingResponse
Gets the ARN of the current default application.
If the default application isn’t set, the operation returns a resource not found error.
3994 3995 3996 3997 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3994 def get_default_application_setting(params = {}, = {}) req = build_request(:get_default_application_setting, params) req.send_request() end |
#get_direct_query_data_source(params = {}) ⇒ Types::GetDirectQueryDataSourceResponse
Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service.
4038 4039 4040 4041 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4038 def get_direct_query_data_source(params = {}, = {}) req = build_request(:get_direct_query_data_source, params) req.send_request() end |
#get_domain_maintenance_status(params = {}) ⇒ Types::GetDomainMaintenanceStatusResponse
The status of the maintenance action.
4080 4081 4082 4083 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4080 def get_domain_maintenance_status(params = {}, = {}) req = build_request(:get_domain_maintenance_status, params) req.send_request() end |
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an OpenSearch index including its schema and semantic enrichment configuration. Use this operation to view the current index structure and semantic search settings.
4116 4117 4118 4119 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4116 def get_index(params = {}, = {}) req = build_request(:get_index, params) req.send_request() end |
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of Amazon OpenSearch Service package versions, along with their creation time, commit message, and plugin properties (if the package is a zip plugin package). For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4181 4182 4183 4184 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4181 def get_package_version_history(params = {}, = {}) req = build_request(:get_package_version_history, params) req.send_request() end |
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades performed on an Amazon OpenSearch Service domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4235 4236 4237 4238 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4235 def get_upgrade_history(params = {}, = {}) req = build_request(:get_upgrade_history, params) req.send_request() end |
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain.
4268 4269 4270 4271 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4268 def get_upgrade_status(params = {}, = {}) req = build_request(:get_upgrade_status, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all OpenSearch applications under your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4320 4321 4322 4323 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4320 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists direct-query data sources for a specific domain. For more information, see For more information, see [Working with Amazon OpenSearch Service direct queries with Amazon S3].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3.html
4358 4359 4360 4361 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4358 def list_data_sources(params = {}, = {}) req = build_request(:list_data_sources, params) req.send_request() end |
#list_direct_query_data_sources(params = {}) ⇒ Types::ListDirectQueryDataSourcesResponse
Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.
4403 4404 4405 4406 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4403 def list_direct_query_data_sources(params = {}, = {}) req = build_request(:list_direct_query_data_sources, params) req.send_request() end |
#list_domain_maintenances(params = {}) ⇒ Types::ListDomainMaintenancesResponse
A list of maintenance actions for the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4463 4464 4465 4466 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4463 def list_domain_maintenances(params = {}, = {}) req = build_request(:list_domain_maintenances, params) req.send_request() end |
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the names of all Amazon OpenSearch Service domains owned by the current user in the active Region.
4494 4495 4496 4497 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4494 def list_domain_names(params = {}, = {}) req = build_request(:list_domain_names, params) req.send_request() end |
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon OpenSearch Service domains associated with a given package. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4559 4560 4561 4562 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4559 def list_domains_for_package(params = {}, = {}) req = build_request(:list_domains_for_package, params) req.send_request() end |
#list_insights(params = {}) ⇒ Types::ListInsightsResponse
Lists insights for an Amazon OpenSearch Service domain or Amazon Web Services account. Returns a paginated list of insights based on the specified entity, filters, time range, and sort order.
4628 4629 4630 4631 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4628 def list_insights(params = {}, = {}) req = build_request(:list_insights, params) req.send_request() end |
#list_instance_type_details(params = {}) ⇒ Types::ListInstanceTypeDetailsResponse
Lists all instance types and available features for a given OpenSearch or Elasticsearch version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4699 4700 4701 4702 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4699 def list_instance_type_details(params = {}, = {}) req = build_request(:list_instance_type_details, params) req.send_request() end |
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with an Amazon OpenSearch Service domain. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4763 4764 4765 4766 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4763 def list_packages_for_domain(params = {}, = {}) req = build_request(:list_packages_for_domain, params) req.send_request() end |
#list_scheduled_actions(params = {}) ⇒ Types::ListScheduledActionsResponse
Retrieves a list of configuration changes that are scheduled for a domain. These changes can be [service software updates] or [blue/green Auto-Tune enhancements].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html [2]: docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html#auto-tune-types
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4823 4824 4825 4826 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4823 def list_scheduled_actions(params = {}, = {}) req = build_request(:list_scheduled_actions, params) req.send_request() end |
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all resource tags for an Amazon OpenSearch Service domain, data source, or application. For more information, see [Tagging Amazon OpenSearch Service resources].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-awsresourcetagging.html
4860 4861 4862 4863 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4860 def (params = {}, = {}) req = build_request(:list_tags, params) req.send_request() end |
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4901 4902 4903 4904 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4901 def list_versions(params = {}, = {}) req = build_request(:list_versions, params) req.send_request() end |
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
4945 4946 4947 4948 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4945 def list_vpc_endpoint_access(params = {}, = {}) req = build_request(:list_vpc_endpoint_access, params) req.send_request() end |
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.
4982 4983 4984 4985 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4982 def list_vpc_endpoints(params = {}, = {}) req = build_request(:list_vpc_endpoints, params) req.send_request() end |
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
5024 5025 5026 5027 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5024 def list_vpc_endpoints_for_domain(params = {}, = {}) req = build_request(:list_vpc_endpoints_for_domain, params) req.send_request() end |
#purchase_reserved_instance_offering(params = {}) ⇒ Types::PurchaseReservedInstanceOfferingResponse
Allows you to purchase Amazon OpenSearch Service Reserved Instances.
5062 5063 5064 5065 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5062 def purchase_reserved_instance_offering(params = {}, = {}) req = build_request(:purchase_reserved_instance_offering, params) req.send_request() end |
#put_default_application_setting(params = {}) ⇒ Types::PutDefaultApplicationSettingResponse
Sets the default application to the application with the specified ARN.
To remove the default application, use the ‘GetDefaultApplicationSetting` operation to get the current default and then call the `PutDefaultApplicationSetting` with the current applications ARN and the `setAsDefault` parameter set to `false`.
5107 5108 5109 5110 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5107 def put_default_application_setting(params = {}, = {}) req = build_request(:put_default_application_setting, params) req.send_request() end |
#register_capability(params = {}) ⇒ Types::RegisterCapabilityResponse
Registers a capability for an OpenSearch UI application. Use this operation to enable specific capabilities, such as AI features, for a given application. The capability configuration defines the type and settings of the capability to register. For more information about the AI features, see [Agentic AI for OpenSearch UI].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/application-ai-assistant.html
5164 5165 5166 5167 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5164 def register_capability(params = {}, = {}) req = build_request(:register_capability, params) req.send_request() end |
#reject_inbound_connection(params = {}) ⇒ Types::RejectInboundConnectionResponse
Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request.
5202 5203 5204 5205 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5202 def reject_inbound_connection(params = {}, = {}) req = build_request(:reject_inbound_connection, params) req.send_request() end |
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from an Amazon OpenSearch Service domain, data source, or application. For more information, see [ Tagging Amazon OpenSearch Service resources].
5236 5237 5238 5239 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5236 def (params = {}, = {}) req = build_request(:remove_tags, params) req.send_request() end |
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
5274 5275 5276 5277 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5274 def revoke_vpc_endpoint_access(params = {}, = {}) req = build_request(:revoke_vpc_endpoint_access, params) req.send_request() end |
#rollback_service_software_update(params = {}) ⇒ Types::RollbackServiceSoftwareUpdateResponse
Rolls back a service software update for a domain to the previous version. For more information, see [Service software updates in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html
5311 5312 5313 5314 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5311 def rollback_service_software_update(params = {}, = {}) req = build_request(:rollback_service_software_update, params) req.send_request() end |
#start_domain_maintenance(params = {}) ⇒ Types::StartDomainMaintenanceResponse
Starts the node maintenance process on the data node. These processes can include a node reboot, an Opensearch or Elasticsearch process restart, or a Dashboard or Kibana restart.
5349 5350 5351 5352 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5349 def start_domain_maintenance(params = {}, = {}) req = build_request(:start_domain_maintenance, params) req.send_request() end |
#start_service_software_update(params = {}) ⇒ Types::StartServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon OpenSearch Service domain. For more information, see [Service software updates in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html
5416 5417 5418 5419 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5416 def start_service_software_update(params = {}, = {}) req = build_request(:start_service_software_update, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration and settings of an existing OpenSearch application.
5486 5487 5488 5489 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5486 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a direct-query data source. For more information, see [Working with Amazon OpenSearch Service data source integrations with Amazon S3].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-creating.html
5540 5541 5542 5543 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5540 def update_data_source(params = {}, = {}) req = build_request(:update_data_source, params) req.send_request() end |
#update_direct_query_data_source(params = {}) ⇒ Types::UpdateDirectQueryDataSourceResponse
Updates the configuration or properties of an existing direct query data source in Amazon OpenSearch Service.
5606 5607 5608 5609 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5606 def update_direct_query_data_source(params = {}, = {}) req = build_request(:update_direct_query_data_source, params) req.send_request() end |
#update_domain_config(params = {}) ⇒ Types::UpdateDomainConfigResponse
Modifies the cluster configuration of the specified Amazon OpenSearch Service domain.
6125 6126 6127 6128 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6125 def update_domain_config(params = {}, = {}) req = build_request(:update_domain_config, params) req.send_request() end |
#update_index(params = {}) ⇒ Types::UpdateIndexResponse
Updates an existing OpenSearch index schema and semantic enrichment configuration. This operation allows modification of field mappings and semantic search settings for text fields. Changes to semantic enrichment configuration will apply to newly ingested documents.
6173 6174 6175 6176 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6173 def update_index(params = {}, = {}) req = build_request(:update_index, params) req.send_request() end |
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon OpenSearch Service domains. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
6264 6265 6266 6267 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6264 def update_package(params = {}, = {}) req = build_request(:update_package, params) req.send_request() end |
#update_package_scope(params = {}) ⇒ Types::UpdatePackageScopeResponse
Updates the scope of a package. Scope of the package defines users who can view and associate a package.
6307 6308 6309 6310 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6307 def update_package_scope(params = {}, = {}) req = build_request(:update_package_scope, params) req.send_request() end |
#update_scheduled_action(params = {}) ⇒ Types::UpdateScheduledActionResponse
Reschedules a planned domain configuration change for a later time. This change can be a scheduled [service software update] or a [blue/green Auto-Tune enhancement].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html [2]: docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html#auto-tune-types
6391 6392 6393 6394 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6391 def update_scheduled_action(params = {}, = {}) req = build_request(:update_scheduled_action, params) req.send_request() end |
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
6439 6440 6441 6442 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6439 def update_vpc_endpoint(params = {}, = {}) req = build_request(:update_vpc_endpoint, params) req.send_request() end |
#upgrade_domain(params = {}) ⇒ Types::UpgradeDomainResponse
Allows you to either upgrade your Amazon OpenSearch Service domain or perform an upgrade eligibility check to a compatible version of OpenSearch or Elasticsearch.
6505 6506 6507 6508 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6505 def upgrade_domain(params = {}, = {}) req = build_request(:upgrade_domain, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6534 6535 6536 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6534 def waiter_names [] end |