Class: Aws::OpenSearchService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::OpenSearchService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-opensearchservice/client.rb
Overview
An API client for OpenSearchService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::OpenSearchService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_inbound_connection(params = {}) ⇒ Types::AcceptInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to accept an inbound cross-cluster search connection request.
-
#add_data_source(params = {}) ⇒ Types::AddDataSourceResponse
Creates a new direct-query data source to the specified domain.
-
#add_direct_query_data_source(params = {}) ⇒ Types::AddDirectQueryDataSourceResponse
Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data.
-
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Amazon OpenSearch Service domain, data source, or application.
-
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon OpenSearch Service domain.
-
#associate_packages(params = {}) ⇒ Types::AssociatePackagesResponse
Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.
-
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
-
#cancel_service_software_update(params = {}) ⇒ Types::CancelServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon OpenSearch Service domain.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an OpenSearch UI application.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates an Amazon OpenSearch Service domain.
-
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an OpenSearch index with optional automatic semantic enrichment for specified text fields.
-
#create_outbound_connection(params = {}) ⇒ Types::CreateOutboundConnectionResponse
Creates a new cross-cluster search connection from a source Amazon OpenSearch Service domain to a destination domain.
-
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Creates a package for use with Amazon OpenSearch Service domains.
-
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
-
#delete_application(params = {}) ⇒ Struct
Deletes a specified OpenSearch application.
-
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceResponse
Deletes a direct-query data source.
-
#delete_direct_query_data_source(params = {}) ⇒ Struct
Deletes a previously configured direct query data source from Amazon OpenSearch Service.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Deletes an Amazon OpenSearch Service domain and all of its data.
-
#delete_inbound_connection(params = {}) ⇒ Types::DeleteInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to delete an existing inbound cross-cluster search connection.
-
#delete_index(params = {}) ⇒ Types::DeleteIndexResponse
Deletes an OpenSearch index.
-
#delete_outbound_connection(params = {}) ⇒ Types::DeleteOutboundConnectionResponse
Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection.
-
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Deletes an Amazon OpenSearch Service package.
-
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#deregister_capability(params = {}) ⇒ Types::DeregisterCapabilityResponse
Deregisters a capability from an OpenSearch UI application.
-
#describe_domain(params = {}) ⇒ Types::DescribeDomainResponse
Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN.
-
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain.
-
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain.
-
#describe_domain_config(params = {}) ⇒ Types::DescribeDomainConfigResponse
Returns the configuration of an Amazon OpenSearch Service domain.
-
#describe_domain_health(params = {}) ⇒ Types::DescribeDomainHealthResponse
Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node.
-
#describe_domain_nodes(params = {}) ⇒ Types::DescribeDomainNodesResponse
Returns information about domain and nodes, including data nodes, master nodes, ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and node states.
-
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Returns domain configuration information about the specified Amazon OpenSearch Service domains.
-
#describe_dry_run_progress(params = {}) ⇒ Types::DescribeDryRunProgressResponse
Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain.
-
#describe_inbound_connections(params = {}) ⇒ Types::DescribeInboundConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain.
-
#describe_insight_details(params = {}) ⇒ Types::DescribeInsightDetailsResponse
Describes the details of an existing insight for an Amazon OpenSearch Service domain.
-
#describe_instance_type_limits(params = {}) ⇒ Types::DescribeInstanceTypeLimitsResponse
Describes the instance count, storage, and master node limits for a given OpenSearch or Elasticsearch version and instance type.
-
#describe_outbound_connections(params = {}) ⇒ Types::DescribeOutboundConnectionsResponse
Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain.
-
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to OpenSearch Service.
-
#describe_reserved_instance_offerings(params = {}) ⇒ Types::DescribeReservedInstanceOfferingsResponse
Describes the available Amazon OpenSearch Service Reserved Instance offerings for a given Region.
-
#describe_reserved_instances(params = {}) ⇒ Types::DescribeReservedInstancesResponse
Describes the Amazon OpenSearch Service instances that you have reserved in a given Region.
-
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
-
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Removes a package from the specified Amazon OpenSearch Service domain.
-
#dissociate_packages(params = {}) ⇒ Types::DissociatePackagesResponse
Dissociates multiple packages from a domain simultaneously.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves the configuration and status of an existing OpenSearch application.
-
#get_capability(params = {}) ⇒ Types::GetCapabilityResponse
Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
-
#get_compatible_versions(params = {}) ⇒ Types::GetCompatibleVersionsResponse
Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to.
-
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves information about a direct query data source.
-
#get_default_application_setting(params = {}) ⇒ Types::GetDefaultApplicationSettingResponse
Gets the ARN of the current default application.
-
#get_direct_query_data_source(params = {}) ⇒ Types::GetDirectQueryDataSourceResponse
Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service.
-
#get_domain_maintenance_status(params = {}) ⇒ Types::GetDomainMaintenanceStatusResponse
The status of the maintenance action.
-
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an OpenSearch index including its schema and semantic enrichment configuration.
-
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of Amazon OpenSearch Service package versions, along with their creation time, commit message, and plugin properties (if the package is a zip plugin package).
-
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades performed on an Amazon OpenSearch Service domain.
-
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all OpenSearch applications under your account.
-
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists direct-query data sources for a specific domain.
-
#list_direct_query_data_sources(params = {}) ⇒ Types::ListDirectQueryDataSourcesResponse
Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.
-
#list_domain_maintenances(params = {}) ⇒ Types::ListDomainMaintenancesResponse
A list of maintenance actions for the domain.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the names of all Amazon OpenSearch Service domains owned by the current user in the active Region.
-
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon OpenSearch Service domains associated with a given package.
-
#list_insights(params = {}) ⇒ Types::ListInsightsResponse
Lists insights for an Amazon OpenSearch Service domain or Amazon Web Services account.
-
#list_instance_type_details(params = {}) ⇒ Types::ListInstanceTypeDetailsResponse
Lists all instance types and available features for a given OpenSearch or Elasticsearch version.
-
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with an Amazon OpenSearch Service domain.
-
#list_scheduled_actions(params = {}) ⇒ Types::ListScheduledActionsResponse
Retrieves a list of configuration changes that are scheduled for a domain.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all resource tags for an Amazon OpenSearch Service domain, data source, or application.
-
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
-
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.
-
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
-
#purchase_reserved_instance_offering(params = {}) ⇒ Types::PurchaseReservedInstanceOfferingResponse
Allows you to purchase Amazon OpenSearch Service Reserved Instances.
-
#put_default_application_setting(params = {}) ⇒ Types::PutDefaultApplicationSettingResponse
Sets the default application to the application with the specified ARN.
-
#register_capability(params = {}) ⇒ Types::RegisterCapabilityResponse
Registers a capability for an OpenSearch UI application.
-
#reject_inbound_connection(params = {}) ⇒ Types::RejectInboundConnectionResponse
Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request.
-
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from an Amazon OpenSearch Service domain, data source, or application.
-
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
-
#rollback_service_software_update(params = {}) ⇒ Types::RollbackServiceSoftwareUpdateResponse
Rolls back a service software update for a domain to the previous version.
-
#start_domain_maintenance(params = {}) ⇒ Types::StartDomainMaintenanceResponse
Starts the node maintenance process on the data node.
-
#start_service_software_update(params = {}) ⇒ Types::StartServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon OpenSearch Service domain.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration and settings of an existing OpenSearch application.
-
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a direct-query data source.
-
#update_direct_query_data_source(params = {}) ⇒ Types::UpdateDirectQueryDataSourceResponse
Updates the configuration or properties of an existing direct query data source in Amazon OpenSearch Service.
-
#update_domain_config(params = {}) ⇒ Types::UpdateDomainConfigResponse
Modifies the cluster configuration of the specified Amazon OpenSearch Service domain.
-
#update_index(params = {}) ⇒ Types::UpdateIndexResponse
Updates an existing OpenSearch index schema and semantic enrichment configuration.
-
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon OpenSearch Service domains.
-
#update_package_scope(params = {}) ⇒ Types::UpdatePackageScopeResponse
Updates the scope of a package.
-
#update_scheduled_action(params = {}) ⇒ Types::UpdateScheduledActionResponse
Reschedules a planned domain configuration change for a later time.
-
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#upgrade_domain(params = {}) ⇒ Types::UpgradeDomainResponse
Allows you to either upgrade your Amazon OpenSearch Service domain or perform an upgrade eligibility check to a compatible version of OpenSearch or Elasticsearch.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6527 6528 6529 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6527 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6530 6531 6532 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6530 def errors_module Errors end |
Instance Method Details
#accept_inbound_connection(params = {}) ⇒ Types::AcceptInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to accept an inbound cross-cluster search connection request. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
518 519 520 521 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 518 def accept_inbound_connection(params = {}, = {}) req = build_request(:accept_inbound_connection, params) req.send_request() end |
#add_data_source(params = {}) ⇒ Types::AddDataSourceResponse
Creates a new direct-query data source to the specified domain. For more information, see [Creating Amazon OpenSearch Service data source integrations with Amazon S3].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-creating.html
568 569 570 571 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 568 def add_data_source(params = {}, = {}) req = build_request(:add_data_source, params) req.send_request() end |
#add_direct_query_data_source(params = {}) ⇒ Types::AddDirectQueryDataSourceResponse
Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data.
641 642 643 644 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 641 def add_direct_query_data_source(params = {}, = {}) req = build_request(:add_direct_query_data_source, params) req.send_request() end |
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Amazon OpenSearch Service domain, data source, or application.
Tags are a set of case-sensitive key-value pairs. A domain, data source, or application can have up to 10 tags. For more information, see [Tagging Amazon OpenSearch Service resources].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-awsresourcetagging.html
682 683 684 685 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 682 def (params = {}, = {}) req = build_request(:add_tags, params) req.send_request() end |
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon OpenSearch Service domain. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
749 750 751 752 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 749 def associate_package(params = {}, = {}) req = build_request(:associate_package, params) req.send_request() end |
#associate_packages(params = {}) ⇒ Types::AssociatePackagesResponse
Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.
810 811 812 813 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 810 def associate_packages(params = {}, = {}) req = build_request(:associate_packages, params) req.send_request() end |
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
857 858 859 860 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 857 def (params = {}, = {}) req = build_request(:authorize_vpc_endpoint_access, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6500 6501 6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6500 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::OpenSearchService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-opensearchservice' context[:gem_version] = '1.97.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
901 902 903 904 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 901 def cancel_domain_config_change(params = {}, = {}) req = build_request(:cancel_domain_config_change, params) req.send_request() end |
#cancel_service_software_update(params = {}) ⇒ Types::CancelServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon OpenSearch Service domain. You can only perform this operation before the ‘AutomatedUpdateDate` and when the domain’s ‘UpdateStatus` is `PENDING_UPDATE`. For more information, see [Service software updates in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html
945 946 947 948 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 945 def cancel_service_software_update(params = {}, = {}) req = build_request(:cancel_service_software_update, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an OpenSearch UI application. For more information, see [Using the OpenSearch user interface in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/application.html
1059 1060 1061 1062 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1059 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates an Amazon OpenSearch Service domain. For more information, see [Creating and managing Amazon OpenSearch Service domains].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/createupdatedomains.html
1501 1502 1503 1504 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1501 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an OpenSearch index with optional automatic semantic enrichment for specified text fields. Automatic semantic enrichment enables semantic search capabilities without requiring machine learning expertise, improving search relevance by up to 20% by understanding search intent and contextual meaning beyond keyword matching. The semantic enrichment process has zero impact on search latency as sparse encodings are stored directly within the index during indexing. For more information, see [Automatic semantic enrichment].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/opensearch-semantic-enrichment.html
1561 1562 1563 1564 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1561 def create_index(params = {}, = {}) req = build_request(:create_index, params) req.send_request() end |
#create_outbound_connection(params = {}) ⇒ Types::CreateOutboundConnectionResponse
Creates a new cross-cluster search connection from a source Amazon OpenSearch Service domain to a destination domain. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
1647 1648 1649 1650 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1647 def create_outbound_connection(params = {}, = {}) req = build_request(:create_outbound_connection, params) req.send_request() end |
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Creates a package for use with Amazon OpenSearch Service domains. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
1750 1751 1752 1753 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1750 def create_package(params = {}, = {}) req = build_request(:create_package, params) req.send_request() end |
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
1802 1803 1804 1805 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1802 def create_vpc_endpoint(params = {}, = {}) req = build_request(:create_vpc_endpoint, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes a specified OpenSearch application.
1824 1825 1826 1827 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1824 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceResponse
Deletes a direct-query data source. For more information, see [Deleting an Amazon OpenSearch Service data source with Amazon S3].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-delete.html
1861 1862 1863 1864 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1861 def delete_data_source(params = {}, = {}) req = build_request(:delete_data_source, params) req.send_request() end |
#delete_direct_query_data_source(params = {}) ⇒ Struct
Deletes a previously configured direct query data source from Amazon OpenSearch Service.
1885 1886 1887 1888 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 1885 def delete_direct_query_data_source(params = {}, = {}) req = build_request(:delete_direct_query_data_source, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Deletes an Amazon OpenSearch Service domain and all of its data. You can’t recover a domain after you delete it.
2033 2034 2035 2036 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2033 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#delete_inbound_connection(params = {}) ⇒ Types::DeleteInboundConnectionResponse
Allows the destination Amazon OpenSearch Service domain owner to delete an existing inbound cross-cluster search connection. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
2077 2078 2079 2080 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2077 def delete_inbound_connection(params = {}, = {}) req = build_request(:delete_inbound_connection, params) req.send_request() end |
#delete_index(params = {}) ⇒ Types::DeleteIndexResponse
Deletes an OpenSearch index. This operation permanently removes the index and cannot be undone.
2112 2113 2114 2115 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2112 def delete_index(params = {}, = {}) req = build_request(:delete_index, params) req.send_request() end |
#delete_outbound_connection(params = {}) ⇒ Types::DeleteOutboundConnectionResponse
Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
2159 2160 2161 2162 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2159 def delete_outbound_connection(params = {}, = {}) req = build_request(:delete_outbound_connection, params) req.send_request() end |
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Deletes an Amazon OpenSearch Service package. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
2218 2219 2220 2221 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2218 def delete_package(params = {}, = {}) req = build_request(:delete_package, params) req.send_request() end |
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
2249 2250 2251 2252 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2249 def delete_vpc_endpoint(params = {}, = {}) req = build_request(:delete_vpc_endpoint, params) req.send_request() end |
#deregister_capability(params = {}) ⇒ Types::DeregisterCapabilityResponse
Deregisters a capability from an OpenSearch UI application. This operation removes the capability and its associated configuration.
2283 2284 2285 2286 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2283 def deregister_capability(params = {}, = {}) req = build_request(:deregister_capability, params) req.send_request() end |
#describe_domain(params = {}) ⇒ Types::DescribeDomainResponse
Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN.
2432 2433 2434 2435 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2432 def describe_domain(params = {}, = {}) req = build_request(:describe_domain, params) req.send_request() end |
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain. For more information, see [Auto-Tune for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2487 2488 2489 2490 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2487 def describe_domain_auto_tunes(params = {}, = {}) req = build_request(:describe_domain_auto_tunes, params) req.send_request() end |
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain. For more information, see [Making configuration changes in Amazon OpenSearch Service].
2542 2543 2544 2545 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2542 def describe_domain_change_progress(params = {}, = {}) req = build_request(:describe_domain_change_progress, params) req.send_request() end |
#describe_domain_config(params = {}) ⇒ Types::DescribeDomainConfigResponse
Returns the configuration of an Amazon OpenSearch Service domain.
2775 2776 2777 2778 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2775 def describe_domain_config(params = {}, = {}) req = build_request(:describe_domain_config, params) req.send_request() end |
#describe_domain_health(params = {}) ⇒ Types::DescribeDomainHealthResponse
Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node.
2836 2837 2838 2839 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2836 def describe_domain_health(params = {}, = {}) req = build_request(:describe_domain_health, params) req.send_request() end |
#describe_domain_nodes(params = {}) ⇒ Types::DescribeDomainNodesResponse
Returns information about domain and nodes, including data nodes, master nodes, ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and node states.
2874 2875 2876 2877 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 2874 def describe_domain_nodes(params = {}, = {}) req = build_request(:describe_domain_nodes, params) req.send_request() end |
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Returns domain configuration information about the specified Amazon OpenSearch Service domains.
3024 3025 3026 3027 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3024 def describe_domains(params = {}, = {}) req = build_request(:describe_domains, params) req.send_request() end |
#describe_dry_run_progress(params = {}) ⇒ Types::DescribeDryRunProgressResponse
Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain. For more information, see [Determining whether a change will cause a blue/green deployment].
3198 3199 3200 3201 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3198 def describe_dry_run_progress(params = {}, = {}) req = build_request(:describe_dry_run_progress, params) req.send_request() end |
#describe_inbound_connections(params = {}) ⇒ Types::DescribeInboundConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3265 3266 3267 3268 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3265 def describe_inbound_connections(params = {}, = {}) req = build_request(:describe_inbound_connections, params) req.send_request() end |
#describe_insight_details(params = {}) ⇒ Types::DescribeInsightDetailsResponse
Describes the details of an existing insight for an Amazon OpenSearch Service domain. Returns detailed fields associated with the specified insight, such as text descriptions and metric data.
3312 3313 3314 3315 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3312 def describe_insight_details(params = {}, = {}) req = build_request(:describe_insight_details, params) req.send_request() end |
#describe_instance_type_limits(params = {}) ⇒ Types::DescribeInstanceTypeLimitsResponse
Describes the instance count, storage, and master node limits for a given OpenSearch or Elasticsearch version and instance type.
3366 3367 3368 3369 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3366 def describe_instance_type_limits(params = {}, = {}) req = build_request(:describe_instance_type_limits, params) req.send_request() end |
#describe_outbound_connections(params = {}) ⇒ Types::DescribeOutboundConnectionsResponse
Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain. For more information, see [Cross-cluster search for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3434 3435 3436 3437 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3434 def describe_outbound_connections(params = {}, = {}) req = build_request(:describe_outbound_connections, params) req.send_request() end |
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to OpenSearch Service. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3515 3516 3517 3518 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3515 def describe_packages(params = {}, = {}) req = build_request(:describe_packages, params) req.send_request() end |
#describe_reserved_instance_offerings(params = {}) ⇒ Types::DescribeReservedInstanceOfferingsResponse
Describes the available Amazon OpenSearch Service Reserved Instance offerings for a given Region. For more information, see [Reserved Instances in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/ri.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3577 3578 3579 3580 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3577 def describe_reserved_instance_offerings(params = {}, = {}) req = build_request(:describe_reserved_instance_offerings, params) req.send_request() end |
#describe_reserved_instances(params = {}) ⇒ Types::DescribeReservedInstancesResponse
Describes the Amazon OpenSearch Service instances that you have reserved in a given Region. For more information, see [Reserved Instances in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/ri.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3645 3646 3647 3648 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3645 def describe_reserved_instances(params = {}, = {}) req = build_request(:describe_reserved_instances, params) req.send_request() end |
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
3690 3691 3692 3693 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3690 def describe_vpc_endpoints(params = {}, = {}) req = build_request(:describe_vpc_endpoints, params) req.send_request() end |
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Removes a package from the specified Amazon OpenSearch Service domain. The package can’t be in use with any OpenSearch index for the dissociation to succeed. The package is still available in OpenSearch Service for association later. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
3744 3745 3746 3747 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3744 def dissociate_package(params = {}, = {}) req = build_request(:dissociate_package, params) req.send_request() end |
#dissociate_packages(params = {}) ⇒ Types::DissociatePackagesResponse
Dissociates multiple packages from a domain simultaneously.
3792 3793 3794 3795 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3792 def dissociate_packages(params = {}, = {}) req = build_request(:dissociate_packages, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves the configuration and status of an existing OpenSearch application.
3849 3850 3851 3852 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3849 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_capability(params = {}) ⇒ Types::GetCapabilityResponse
Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
3891 3892 3893 3894 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3891 def get_capability(params = {}, = {}) req = build_request(:get_capability, params) req.send_request() end |
#get_compatible_versions(params = {}) ⇒ Types::GetCompatibleVersionsResponse
Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to.
3924 3925 3926 3927 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3924 def get_compatible_versions(params = {}, = {}) req = build_request(:get_compatible_versions, params) req.send_request() end |
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves information about a direct query data source.
3962 3963 3964 3965 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3962 def get_data_source(params = {}, = {}) req = build_request(:get_data_source, params) req.send_request() end |
#get_default_application_setting(params = {}) ⇒ Types::GetDefaultApplicationSettingResponse
Gets the ARN of the current default application.
If the default application isn’t set, the operation returns a resource not found error.
3984 3985 3986 3987 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 3984 def get_default_application_setting(params = {}, = {}) req = build_request(:get_default_application_setting, params) req.send_request() end |
#get_direct_query_data_source(params = {}) ⇒ Types::GetDirectQueryDataSourceResponse
Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service.
4028 4029 4030 4031 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4028 def get_direct_query_data_source(params = {}, = {}) req = build_request(:get_direct_query_data_source, params) req.send_request() end |
#get_domain_maintenance_status(params = {}) ⇒ Types::GetDomainMaintenanceStatusResponse
The status of the maintenance action.
4070 4071 4072 4073 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4070 def get_domain_maintenance_status(params = {}, = {}) req = build_request(:get_domain_maintenance_status, params) req.send_request() end |
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an OpenSearch index including its schema and semantic enrichment configuration. Use this operation to view the current index structure and semantic search settings.
4106 4107 4108 4109 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4106 def get_index(params = {}, = {}) req = build_request(:get_index, params) req.send_request() end |
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of Amazon OpenSearch Service package versions, along with their creation time, commit message, and plugin properties (if the package is a zip plugin package). For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4171 4172 4173 4174 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4171 def get_package_version_history(params = {}, = {}) req = build_request(:get_package_version_history, params) req.send_request() end |
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades performed on an Amazon OpenSearch Service domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4225 4226 4227 4228 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4225 def get_upgrade_history(params = {}, = {}) req = build_request(:get_upgrade_history, params) req.send_request() end |
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain.
4258 4259 4260 4261 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4258 def get_upgrade_status(params = {}, = {}) req = build_request(:get_upgrade_status, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all OpenSearch applications under your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4310 4311 4312 4313 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4310 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists direct-query data sources for a specific domain. For more information, see For more information, see [Working with Amazon OpenSearch Service direct queries with Amazon S3].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3.html
4348 4349 4350 4351 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4348 def list_data_sources(params = {}, = {}) req = build_request(:list_data_sources, params) req.send_request() end |
#list_direct_query_data_sources(params = {}) ⇒ Types::ListDirectQueryDataSourcesResponse
Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.
4393 4394 4395 4396 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4393 def list_direct_query_data_sources(params = {}, = {}) req = build_request(:list_direct_query_data_sources, params) req.send_request() end |
#list_domain_maintenances(params = {}) ⇒ Types::ListDomainMaintenancesResponse
A list of maintenance actions for the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4453 4454 4455 4456 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4453 def list_domain_maintenances(params = {}, = {}) req = build_request(:list_domain_maintenances, params) req.send_request() end |
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the names of all Amazon OpenSearch Service domains owned by the current user in the active Region.
4484 4485 4486 4487 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4484 def list_domain_names(params = {}, = {}) req = build_request(:list_domain_names, params) req.send_request() end |
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon OpenSearch Service domains associated with a given package. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4549 4550 4551 4552 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4549 def list_domains_for_package(params = {}, = {}) req = build_request(:list_domains_for_package, params) req.send_request() end |
#list_insights(params = {}) ⇒ Types::ListInsightsResponse
Lists insights for an Amazon OpenSearch Service domain or Amazon Web Services account. Returns a paginated list of insights based on the specified entity, filters, time range, and sort order.
4618 4619 4620 4621 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4618 def list_insights(params = {}, = {}) req = build_request(:list_insights, params) req.send_request() end |
#list_instance_type_details(params = {}) ⇒ Types::ListInstanceTypeDetailsResponse
Lists all instance types and available features for a given OpenSearch or Elasticsearch version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4689 4690 4691 4692 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4689 def list_instance_type_details(params = {}, = {}) req = build_request(:list_instance_type_details, params) req.send_request() end |
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with an Amazon OpenSearch Service domain. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4753 4754 4755 4756 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4753 def list_packages_for_domain(params = {}, = {}) req = build_request(:list_packages_for_domain, params) req.send_request() end |
#list_scheduled_actions(params = {}) ⇒ Types::ListScheduledActionsResponse
Retrieves a list of configuration changes that are scheduled for a domain. These changes can be [service software updates] or [blue/green Auto-Tune enhancements].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html [2]: docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html#auto-tune-types
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4813 4814 4815 4816 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4813 def list_scheduled_actions(params = {}, = {}) req = build_request(:list_scheduled_actions, params) req.send_request() end |
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all resource tags for an Amazon OpenSearch Service domain, data source, or application. For more information, see [Tagging Amazon OpenSearch Service resources].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-awsresourcetagging.html
4850 4851 4852 4853 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4850 def (params = {}, = {}) req = build_request(:list_tags, params) req.send_request() end |
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4891 4892 4893 4894 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4891 def list_versions(params = {}, = {}) req = build_request(:list_versions, params) req.send_request() end |
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
4935 4936 4937 4938 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4935 def list_vpc_endpoint_access(params = {}, = {}) req = build_request(:list_vpc_endpoint_access, params) req.send_request() end |
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.
4972 4973 4974 4975 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 4972 def list_vpc_endpoints(params = {}, = {}) req = build_request(:list_vpc_endpoints, params) req.send_request() end |
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
5014 5015 5016 5017 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5014 def list_vpc_endpoints_for_domain(params = {}, = {}) req = build_request(:list_vpc_endpoints_for_domain, params) req.send_request() end |
#purchase_reserved_instance_offering(params = {}) ⇒ Types::PurchaseReservedInstanceOfferingResponse
Allows you to purchase Amazon OpenSearch Service Reserved Instances.
5052 5053 5054 5055 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5052 def purchase_reserved_instance_offering(params = {}, = {}) req = build_request(:purchase_reserved_instance_offering, params) req.send_request() end |
#put_default_application_setting(params = {}) ⇒ Types::PutDefaultApplicationSettingResponse
Sets the default application to the application with the specified ARN.
To remove the default application, use the ‘GetDefaultApplicationSetting` operation to get the current default and then call the `PutDefaultApplicationSetting` with the current applications ARN and the `setAsDefault` parameter set to `false`.
5097 5098 5099 5100 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5097 def put_default_application_setting(params = {}, = {}) req = build_request(:put_default_application_setting, params) req.send_request() end |
#register_capability(params = {}) ⇒ Types::RegisterCapabilityResponse
Registers a capability for an OpenSearch UI application. Use this operation to enable specific capabilities, such as AI features, for a given application. The capability configuration defines the type and settings of the capability to register. For more information about the AI features, see [Agentic AI for OpenSearch UI].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/application-ai-assistant.html
5154 5155 5156 5157 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5154 def register_capability(params = {}, = {}) req = build_request(:register_capability, params) req.send_request() end |
#reject_inbound_connection(params = {}) ⇒ Types::RejectInboundConnectionResponse
Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request.
5192 5193 5194 5195 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5192 def reject_inbound_connection(params = {}, = {}) req = build_request(:reject_inbound_connection, params) req.send_request() end |
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from an Amazon OpenSearch Service domain, data source, or application. For more information, see [ Tagging Amazon OpenSearch Service resources].
5226 5227 5228 5229 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5226 def (params = {}, = {}) req = build_request(:remove_tags, params) req.send_request() end |
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
5264 5265 5266 5267 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5264 def revoke_vpc_endpoint_access(params = {}, = {}) req = build_request(:revoke_vpc_endpoint_access, params) req.send_request() end |
#rollback_service_software_update(params = {}) ⇒ Types::RollbackServiceSoftwareUpdateResponse
Rolls back a service software update for a domain to the previous version. For more information, see [Service software updates in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html
5301 5302 5303 5304 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5301 def rollback_service_software_update(params = {}, = {}) req = build_request(:rollback_service_software_update, params) req.send_request() end |
#start_domain_maintenance(params = {}) ⇒ Types::StartDomainMaintenanceResponse
Starts the node maintenance process on the data node. These processes can include a node reboot, an Opensearch or Elasticsearch process restart, or a Dashboard or Kibana restart.
5339 5340 5341 5342 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5339 def start_domain_maintenance(params = {}, = {}) req = build_request(:start_domain_maintenance, params) req.send_request() end |
#start_service_software_update(params = {}) ⇒ Types::StartServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon OpenSearch Service domain. For more information, see [Service software updates in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html
5406 5407 5408 5409 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5406 def start_service_software_update(params = {}, = {}) req = build_request(:start_service_software_update, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration and settings of an existing OpenSearch application.
5476 5477 5478 5479 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5476 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a direct-query data source. For more information, see [Working with Amazon OpenSearch Service data source integrations with Amazon S3].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-creating.html
5530 5531 5532 5533 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5530 def update_data_source(params = {}, = {}) req = build_request(:update_data_source, params) req.send_request() end |
#update_direct_query_data_source(params = {}) ⇒ Types::UpdateDirectQueryDataSourceResponse
Updates the configuration or properties of an existing direct query data source in Amazon OpenSearch Service.
5596 5597 5598 5599 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 5596 def update_direct_query_data_source(params = {}, = {}) req = build_request(:update_direct_query_data_source, params) req.send_request() end |
#update_domain_config(params = {}) ⇒ Types::UpdateDomainConfigResponse
Modifies the cluster configuration of the specified Amazon OpenSearch Service domain.
6113 6114 6115 6116 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6113 def update_domain_config(params = {}, = {}) req = build_request(:update_domain_config, params) req.send_request() end |
#update_index(params = {}) ⇒ Types::UpdateIndexResponse
Updates an existing OpenSearch index schema and semantic enrichment configuration. This operation allows modification of field mappings and semantic search settings for text fields. Changes to semantic enrichment configuration will apply to newly ingested documents.
6161 6162 6163 6164 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6161 def update_index(params = {}, = {}) req = build_request(:update_index, params) req.send_request() end |
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon OpenSearch Service domains. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
6252 6253 6254 6255 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6252 def update_package(params = {}, = {}) req = build_request(:update_package, params) req.send_request() end |
#update_package_scope(params = {}) ⇒ Types::UpdatePackageScopeResponse
Updates the scope of a package. Scope of the package defines users who can view and associate a package.
6295 6296 6297 6298 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6295 def update_package_scope(params = {}, = {}) req = build_request(:update_package_scope, params) req.send_request() end |
#update_scheduled_action(params = {}) ⇒ Types::UpdateScheduledActionResponse
Reschedules a planned domain configuration change for a later time. This change can be a scheduled [service software update] or a [blue/green Auto-Tune enhancement].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html [2]: docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html#auto-tune-types
6379 6380 6381 6382 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6379 def update_scheduled_action(params = {}, = {}) req = build_request(:update_scheduled_action, params) req.send_request() end |
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
6425 6426 6427 6428 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6425 def update_vpc_endpoint(params = {}, = {}) req = build_request(:update_vpc_endpoint, params) req.send_request() end |
#upgrade_domain(params = {}) ⇒ Types::UpgradeDomainResponse
Allows you to either upgrade your Amazon OpenSearch Service domain or perform an upgrade eligibility check to a compatible version of OpenSearch or Elasticsearch.
6491 6492 6493 6494 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6491 def upgrade_domain(params = {}, = {}) req = build_request(:upgrade_domain, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6520 6521 6522 |
# File 'lib/aws-sdk-opensearchservice/client.rb', line 6520 def waiter_names [] end |