Class: Aws::OpenSearchService::Types::AttachDataSourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::AttachDataSourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the domain.
-
#id ⇒ String
The unique identifier or name of the OpenSearch application to attach the data source to.
-
#workspace_configuration ⇒ Types::WorkspaceConfigurationInput
Configuration for creating a new workspace during the attachment.
-
#workspace_id ⇒ String
The identifier of an existing workspace to update with the new data source.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. If you retry a request with the same client token and the same parameters, the retry succeeds without performing any further actions.
719 720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 719 class AttachDataSourceRequest < Struct.new( :id, :data_source_arn, :workspace_id, :workspace_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the domain. See [Identifiers for IAM Entities ][1] in *Using Amazon Web Services Identity and Access Management* for more information.
719 720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 719 class AttachDataSourceRequest < Struct.new( :id, :data_source_arn, :workspace_id, :workspace_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier or name of the OpenSearch application to attach the data source to. This is the same identifier used with ‘UpdateApplication`, `GetApplication`, and `DeleteApplication`.
719 720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 719 class AttachDataSourceRequest < Struct.new( :id, :data_source_arn, :workspace_id, :workspace_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_configuration ⇒ Types::WorkspaceConfigurationInput
Configuration for creating a new workspace during the attachment. If specified, a workspace is created and linked to the data source after the attachment completes. Mutually exclusive with ‘workspaceId`.
719 720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 719 class AttachDataSourceRequest < Struct.new( :id, :data_source_arn, :workspace_id, :workspace_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of an existing workspace to update with the new data source. Mutually exclusive with ‘workspaceConfiguration`.
719 720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 719 class AttachDataSourceRequest < Struct.new( :id, :data_source_arn, :workspace_id, :workspace_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |