Class: Aws::OpenSearchService::Types::AuthorizedPrincipal

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Information about an Amazon Web Services account or service that has access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#principalString

Returns:

  • (String)


840
841
842
843
844
845
846
# File 'lib/aws-sdk-opensearchservice/types.rb', line 840

class AuthorizedPrincipal < Struct.new(
  :principal_type,
  :principal,
  :service_options)
  SENSITIVE = []
  include Aws::Structure
end

#principal_typeString

The type of principal.

Returns:

  • (String)


840
841
842
843
844
845
846
# File 'lib/aws-sdk-opensearchservice/types.rb', line 840

class AuthorizedPrincipal < Struct.new(
  :principal_type,
  :principal,
  :service_options)
  SENSITIVE = []
  include Aws::Structure
end

#service_optionsTypes::ServiceOptions

The options for the service, including the supported Regions for the endpoint access.



840
841
842
843
844
845
846
# File 'lib/aws-sdk-opensearchservice/types.rb', line 840

class AuthorizedPrincipal < Struct.new(
  :principal_type,
  :principal,
  :service_options)
  SENSITIVE = []
  include Aws::Structure
end