Class: Aws::OpenSearchService::Types::AuthorizedPrincipal

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Information about an Amazon Web Services account or service that has access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#principalString

Returns:

  • (String)


735
736
737
738
739
740
# File 'lib/aws-sdk-opensearchservice/types.rb', line 735

class AuthorizedPrincipal < Struct.new(
  :principal_type,
  :principal)
  SENSITIVE = []
  include Aws::Structure
end

#principal_typeString

The type of principal.

Returns:

  • (String)


735
736
737
738
739
740
# File 'lib/aws-sdk-opensearchservice/types.rb', line 735

class AuthorizedPrincipal < Struct.new(
  :principal_type,
  :principal)
  SENSITIVE = []
  include Aws::Structure
end