Class: Aws::OpenSearchService::Types::AvailabilityZoneInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::AvailabilityZoneInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Information about an Availability Zone on a domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone_name ⇒ String
The name of the Availability Zone.
-
#available_data_node_count ⇒ String
The number of data nodes active in the Availability Zone.
-
#configured_data_node_count ⇒ String
The total number of data nodes configured in the Availability Zone.
-
#total_shards ⇒ String
The total number of primary and replica shards in the Availability Zone.
-
#total_un_assigned_shards ⇒ String
The total number of primary and replica shards that aren’t allocated to any of the nodes in the Availability Zone.
-
#zone_status ⇒ String
The current state of the Availability Zone.
Instance Attribute Details
#availability_zone_name ⇒ String
The name of the Availability Zone.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1232 class AvailabilityZoneInfo < Struct.new( :availability_zone_name, :zone_status, :configured_data_node_count, :available_data_node_count, :total_shards, :total_un_assigned_shards) SENSITIVE = [] include Aws::Structure end |
#available_data_node_count ⇒ String
The number of data nodes active in the Availability Zone.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1232 class AvailabilityZoneInfo < Struct.new( :availability_zone_name, :zone_status, :configured_data_node_count, :available_data_node_count, :total_shards, :total_un_assigned_shards) SENSITIVE = [] include Aws::Structure end |
#configured_data_node_count ⇒ String
The total number of data nodes configured in the Availability Zone.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1232 class AvailabilityZoneInfo < Struct.new( :availability_zone_name, :zone_status, :configured_data_node_count, :available_data_node_count, :total_shards, :total_un_assigned_shards) SENSITIVE = [] include Aws::Structure end |
#total_shards ⇒ String
The total number of primary and replica shards in the Availability Zone.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1232 class AvailabilityZoneInfo < Struct.new( :availability_zone_name, :zone_status, :configured_data_node_count, :available_data_node_count, :total_shards, :total_un_assigned_shards) SENSITIVE = [] include Aws::Structure end |
#total_un_assigned_shards ⇒ String
The total number of primary and replica shards that aren’t allocated to any of the nodes in the Availability Zone.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1232 class AvailabilityZoneInfo < Struct.new( :availability_zone_name, :zone_status, :configured_data_node_count, :available_data_node_count, :total_shards, :total_un_assigned_shards) SENSITIVE = [] include Aws::Structure end |
#zone_status ⇒ String
The current state of the Availability Zone. Current options are ‘Active` and `StandBy`.
-
‘Active` - Data nodes in the Availability Zone are in use.
-
‘StandBy` - Data nodes in the Availability Zone are in a standby state.
-
‘NotAvailable` - Unable to retrieve information.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1232 class AvailabilityZoneInfo < Struct.new( :availability_zone_name, :zone_status, :configured_data_node_count, :available_data_node_count, :total_shards, :total_un_assigned_shards) SENSITIVE = [] include Aws::Structure end |