Class: Aws::OpenSearchService::Types::CreateIndexRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.

Returns:

  • (String)


2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2187

class CreateIndexRequest < Struct.new(
  :domain_name,
  :index_name,
  :index_schema)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the index to create. Must be between 1 and 255 characters and follow OpenSearch naming conventions.

Returns:

  • (String)


2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2187

class CreateIndexRequest < Struct.new(
  :domain_name,
  :index_name,
  :index_schema)
  SENSITIVE = []
  include Aws::Structure
end

#index_schemaHash, ...

The JSON schema defining index mappings, settings, and semantic enrichment configuration. The schema specifies which text fields should be automatically enriched for semantic search capabilities and includes OpenSearch index configuration parameters.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2187

class CreateIndexRequest < Struct.new(
  :domain_name,
  :index_name,
  :index_schema)
  SENSITIVE = []
  include Aws::Structure
end