Class: Aws::OpenSearchService::Types::CreateIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::CreateIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an OpenSearch Service domain.
-
#index_name ⇒ String
The name of the index to create.
-
#index_schema ⇒ Hash, ...
The JSON schema defining index mappings, settings, and semantic enrichment configuration.
Instance Attribute Details
#domain_name ⇒ String
The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.
1887 1888 1889 1890 1891 1892 1893 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1887 class CreateIndexRequest < Struct.new( :domain_name, :index_name, :index_schema) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to create. Must be between 1 and 255 characters and follow OpenSearch naming conventions.
1887 1888 1889 1890 1891 1892 1893 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1887 class CreateIndexRequest < Struct.new( :domain_name, :index_name, :index_schema) SENSITIVE = [] include Aws::Structure end |
#index_schema ⇒ Hash, ...
The JSON schema defining index mappings, settings, and semantic enrichment configuration. The schema specifies which text fields should be automatically enriched for semantic search capabilities and includes OpenSearch index configuration parameters.
1887 1888 1889 1890 1891 1892 1893 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 1887 class CreateIndexRequest < Struct.new( :domain_name, :index_name, :index_schema) SENSITIVE = [] include Aws::Structure end |