Class: Aws::OpenSearchService::Types::CreatePackageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::CreatePackageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for request parameters to the ‘CreatePackage` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine_version ⇒ String
The version of the Amazon OpenSearch Service engine for which is compatible with the package.
-
#package_configuration ⇒ Types::PackageConfiguration
The configuration parameters for the package being created.
-
#package_description ⇒ String
Description of the package.
-
#package_encryption_options ⇒ Types::PackageEncryptionOptions
The encryption parameters for the package being created.
-
#package_name ⇒ String
Unique name for the package.
-
#package_source ⇒ Types::PackageSource
The Amazon S3 location from which to import the package.
-
#package_type ⇒ String
The type of package.
-
#package_vending_options ⇒ Types::PackageVendingOptions
The vending options for the package being created.
Instance Attribute Details
#engine_version ⇒ String
The version of the Amazon OpenSearch Service engine for which is compatible with the package. This can only be specified for package type ‘ZIP-PLUGIN`
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2327 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_configuration ⇒ Types::PackageConfiguration
The configuration parameters for the package being created.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2327 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_description ⇒ String
Description of the package.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2327 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_encryption_options ⇒ Types::PackageEncryptionOptions
The encryption parameters for the package being created.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2327 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_name ⇒ String
Unique name for the package.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2327 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_source ⇒ Types::PackageSource
The Amazon S3 location from which to import the package.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2327 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_type ⇒ String
The type of package.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2327 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_vending_options ⇒ Types::PackageVendingOptions
The vending options for the package being created. They determine if the package can be vended to other users.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2327 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |