Class: Aws::OpenSearchService::Types::CreatePackageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::CreatePackageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for request parameters to the ‘CreatePackage` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine_version ⇒ String
The version of the Amazon OpenSearch Service engine for which is compatible with the package.
-
#package_configuration ⇒ Types::PackageConfiguration
The configuration parameters for the package being created.
-
#package_description ⇒ String
Description of the package.
-
#package_encryption_options ⇒ Types::PackageEncryptionOptions
The encryption parameters for the package being created.
-
#package_name ⇒ String
Unique name for the package.
-
#package_source ⇒ Types::PackageSource
The Amazon S3 location from which to import the package.
-
#package_type ⇒ String
The type of package.
-
#package_vending_options ⇒ Types::PackageVendingOptions
The vending options for the package being created.
Instance Attribute Details
#engine_version ⇒ String
The version of the Amazon OpenSearch Service engine for which is compatible with the package. This can only be specified for package type ‘ZIP-PLUGIN`
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2135 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_configuration ⇒ Types::PackageConfiguration
The configuration parameters for the package being created.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2135 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_description ⇒ String
Description of the package.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2135 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_encryption_options ⇒ Types::PackageEncryptionOptions
The encryption parameters for the package being created.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2135 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_name ⇒ String
Unique name for the package.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2135 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_source ⇒ Types::PackageSource
The Amazon S3 location from which to import the package.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2135 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_type ⇒ String
The type of package.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2135 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |
#package_vending_options ⇒ Types::PackageVendingOptions
The vending options for the package being created. They determine if the package can be vended to other users.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2135 class CreatePackageRequest < Struct.new( :package_name, :package_type, :package_description, :package_source, :package_configuration, :engine_version, :package_vending_options, :package_encryption_options) SENSITIVE = [] include Aws::Structure end |