Class: Aws::OpenSearchService::Types::DataSourceAttachmentSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DataSourceAttachmentSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Summary information about a data source attachment, including its identifier, data source ARN, and current status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The unique identifier assigned to the data source attachment.
-
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the domain.
-
#status ⇒ String
The current status of the data source attachment.
Instance Attribute Details
#attachment_id ⇒ String
The unique identifier assigned to the data source attachment.
2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2462 class DataSourceAttachmentSummary < Struct.new( :attachment_id, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the domain. See [Identifiers for IAM Entities ][1] in *Using Amazon Web Services Identity and Access Management* for more information.
2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2462 class DataSourceAttachmentSummary < Struct.new( :attachment_id, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the data source attachment. Valid values are ‘PENDING`, `ATTACHED`, and `FAILED`.
2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2462 class DataSourceAttachmentSummary < Struct.new( :attachment_id, :data_source_arn, :status) SENSITIVE = [] include Aws::Structure end |