Class: Aws::OpenSearchService::Types::DeleteIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DeleteIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an OpenSearch Service domain.
-
#index_name ⇒ String
The name of the index to delete.
Instance Attribute Details
#domain_name ⇒ String
The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.
2668 2669 2670 2671 2672 2673 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2668 class DeleteIndexRequest < Struct.new( :domain_name, :index_name) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to delete.
2668 2669 2670 2671 2672 2673 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2668 class DeleteIndexRequest < Struct.new( :domain_name, :index_name) SENSITIVE = [] include Aws::Structure end |