Class: Aws::OpenSearchService::Types::DescribeDomainChangeProgressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeDomainChangeProgressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters to the ‘DescribeDomainChangeProgress` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_id ⇒ String
The specific change ID for which you want to get progress information.
-
#domain_name ⇒ String
The name of the domain to get progress information for.
Instance Attribute Details
#change_id ⇒ String
The specific change ID for which you want to get progress information. If omitted, the request returns information about the most recent configuration change.
2972 2973 2974 2975 2976 2977 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2972 class DescribeDomainChangeProgressRequest < Struct.new( :domain_name, :change_id) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain to get progress information for.
2972 2973 2974 2975 2976 2977 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2972 class DescribeDomainChangeProgressRequest < Struct.new( :domain_name, :change_id) SENSITIVE = [] include Aws::Structure end |