Class: Aws::OpenSearchService::Types::DescribeDryRunProgressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeDryRunProgressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of the domain.
-
#dry_run_id ⇒ String
The unique identifier of the dry run.
-
#load_dry_run_config ⇒ Boolean
Whether to include the configuration of the dry run in the response.
Instance Attribute Details
#domain_name ⇒ String
The name of the domain.
3250 3251 3252 3253 3254 3255 3256 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3250 class DescribeDryRunProgressRequest < Struct.new( :domain_name, :dry_run_id, :load_dry_run_config) SENSITIVE = [] include Aws::Structure end |
#dry_run_id ⇒ String
The unique identifier of the dry run.
3250 3251 3252 3253 3254 3255 3256 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3250 class DescribeDryRunProgressRequest < Struct.new( :domain_name, :dry_run_id, :load_dry_run_config) SENSITIVE = [] include Aws::Structure end |
#load_dry_run_config ⇒ Boolean
Whether to include the configuration of the dry run in the response. The configuration specifies the updates that you’re planning to make on the domain.
3250 3251 3252 3253 3254 3255 3256 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3250 class DescribeDryRunProgressRequest < Struct.new( :domain_name, :dry_run_id, :load_dry_run_config) SENSITIVE = [] include Aws::Structure end |