Class: Aws::OpenSearchService::Types::DescribeDryRunProgressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeDryRunProgressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of the domain.
-
#dry_run_id ⇒ String
The unique identifier of the dry run.
-
#load_dry_run_config ⇒ Boolean
Whether to include the configuration of the dry run in the response.
Instance Attribute Details
#domain_name ⇒ String
The name of the domain.
2958 2959 2960 2961 2962 2963 2964 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2958 class DescribeDryRunProgressRequest < Struct.new( :domain_name, :dry_run_id, :load_dry_run_config) SENSITIVE = [] include Aws::Structure end |
#dry_run_id ⇒ String
The unique identifier of the dry run.
2958 2959 2960 2961 2962 2963 2964 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2958 class DescribeDryRunProgressRequest < Struct.new( :domain_name, :dry_run_id, :load_dry_run_config) SENSITIVE = [] include Aws::Structure end |
#load_dry_run_config ⇒ Boolean
Whether to include the configuration of the dry run in the response. The configuration specifies the updates that you’re planning to make on the domain.
2958 2959 2960 2961 2962 2963 2964 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2958 class DescribeDryRunProgressRequest < Struct.new( :domain_name, :dry_run_id, :load_dry_run_config) SENSITIVE = [] include Aws::Structure end |