Class: Aws::OpenSearchService::Types::DescribeInboundConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DescribeInboundConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters to the DescribeInboundConnections operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
A list of filters used to match properties for inbound cross-cluster connections.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
DescribeInboundConnectionsoperation returns anextToken, you can include the returnednextTokenin subsequentDescribeInboundConnectionsoperations, which returns results in the next page.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
A list of filters used to match properties for inbound cross-cluster connections.
2854 2855 2856 2857 2858 2859 2860 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2854 class DescribeInboundConnectionsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.
2854 2855 2856 2857 2858 2859 2860 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2854 class DescribeInboundConnectionsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial DescribeInboundConnections operation returns a nextToken, you can include the returned nextToken in subsequent DescribeInboundConnections operations, which returns results in the next page.
2854 2855 2856 2857 2858 2859 2860 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 2854 class DescribeInboundConnectionsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |