Class: Aws::OpenSearchService::Types::DomainNodesStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DomainNodesStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for information about nodes on the domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone of the node.
-
#instance_type ⇒ String
The instance type information of the node.
-
#node_id ⇒ String
The ID of the node.
-
#node_status ⇒ String
Indicates if the node is active or in standby.
-
#node_type ⇒ String
Indicates whether the nodes is a data, master, or UltraWarm node.
-
#storage_size ⇒ String
The storage size of the node, in GiB.
-
#storage_type ⇒ String
Indicates if the node has EBS or instance storage.
-
#storage_volume_type ⇒ String
If the nodes has EBS storage, indicates if the volume type is gp2 or gp3.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone of the node.
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4226 class DomainNodesStatus < Struct.new( :node_id, :node_type, :availability_zone, :instance_type, :node_status, :storage_type, :storage_volume_type, :storage_size) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type information of the node.
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4226 class DomainNodesStatus < Struct.new( :node_id, :node_type, :availability_zone, :instance_type, :node_status, :storage_type, :storage_volume_type, :storage_size) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
The ID of the node.
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4226 class DomainNodesStatus < Struct.new( :node_id, :node_type, :availability_zone, :instance_type, :node_status, :storage_type, :storage_volume_type, :storage_size) SENSITIVE = [] include Aws::Structure end |
#node_status ⇒ String
Indicates if the node is active or in standby.
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4226 class DomainNodesStatus < Struct.new( :node_id, :node_type, :availability_zone, :instance_type, :node_status, :storage_type, :storage_volume_type, :storage_size) SENSITIVE = [] include Aws::Structure end |
#node_type ⇒ String
Indicates whether the nodes is a data, master, or UltraWarm node.
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4226 class DomainNodesStatus < Struct.new( :node_id, :node_type, :availability_zone, :instance_type, :node_status, :storage_type, :storage_volume_type, :storage_size) SENSITIVE = [] include Aws::Structure end |
#storage_size ⇒ String
The storage size of the node, in GiB.
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4226 class DomainNodesStatus < Struct.new( :node_id, :node_type, :availability_zone, :instance_type, :node_status, :storage_type, :storage_volume_type, :storage_size) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
Indicates if the node has EBS or instance storage.
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4226 class DomainNodesStatus < Struct.new( :node_id, :node_type, :availability_zone, :instance_type, :node_status, :storage_type, :storage_volume_type, :storage_size) SENSITIVE = [] include Aws::Structure end |
#storage_volume_type ⇒ String
If the nodes has EBS storage, indicates if the volume type is gp2 or gp3. Only applicable for data nodes.
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4226 class DomainNodesStatus < Struct.new( :node_id, :node_type, :availability_zone, :instance_type, :node_status, :storage_type, :storage_volume_type, :storage_size) SENSITIVE = [] include Aws::Structure end |