Class: Aws::OpenSearchService::Types::DomainPackageDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::DomainPackageDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Information about a package that is associated with a domain. For more information, see [Custom packages for Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_configuration ⇒ Types::PackageAssociationConfiguration
The configuration for associating a package with an Amazon OpenSearch Service domain.
-
#domain_name ⇒ String
Name of the domain that the package is associated with.
-
#domain_package_status ⇒ String
State of the association.
-
#error_details ⇒ Types::ErrorDetails
Additional information if the package is in an error state.
-
#last_updated ⇒ Time
Timestamp of the most recent update to the package association status.
-
#package_id ⇒ String
Internal ID of the package.
-
#package_name ⇒ String
User-specified name of the package.
-
#package_type ⇒ String
The type of package.
-
#package_version ⇒ String
The current version of the package.
-
#prerequisite_package_id_list ⇒ Array<String>
A list of package IDs that must be associated with the domain before or with the package can be associated.
-
#reference_path ⇒ String
The relative path of the package on the OpenSearch Service cluster nodes.
Instance Attribute Details
#association_configuration ⇒ Types::PackageAssociationConfiguration
The configuration for associating a package with an Amazon OpenSearch Service domain.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
Name of the domain that the package is associated with.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#domain_package_status ⇒ String
State of the association.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#error_details ⇒ Types::ErrorDetails
Additional information if the package is in an error state. Null otherwise.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
Timestamp of the most recent update to the package association status.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#package_id ⇒ String
Internal ID of the package.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#package_name ⇒ String
User-specified name of the package.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#package_type ⇒ String
The type of package.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#package_version ⇒ String
The current version of the package.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#prerequisite_package_id_list ⇒ Array<String>
A list of package IDs that must be associated with the domain before or with the package can be associated.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |
#reference_path ⇒ String
The relative path of the package on the OpenSearch Service cluster nodes. This is ‘synonym_path` when the package is for synonym files.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 3942 class DomainPackageDetails < Struct.new( :package_id, :package_name, :package_type, :last_updated, :domain_name, :domain_package_status, :package_version, :prerequisite_package_id_list, :reference_path, :error_details, :association_configuration) SENSITIVE = [] include Aws::Structure end |