Class: Aws::OpenSearchService::Types::ExportOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ExportOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Options to filter the scope of saved objects to export during a migration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#include_references_deep ⇒ Boolean
Specifies whether to include all objects referenced by the exported objects, recursively.
-
#objects ⇒ Array<Types::SavedObjectIdentifier>
A list of specific saved objects to include in the migration, identified by type and ID.
-
#types ⇒ Array<String>
A list of saved object types to include in the migration.
Instance Attribute Details
#include_references_deep ⇒ Boolean
Specifies whether to include all objects referenced by the exported objects, recursively.
4837 4838 4839 4840 4841 4842 4843 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4837 class ExportOptions < Struct.new( :types, :objects, :include_references_deep) SENSITIVE = [] include Aws::Structure end |
#objects ⇒ Array<Types::SavedObjectIdentifier>
A list of specific saved objects to include in the migration, identified by type and ID.
4837 4838 4839 4840 4841 4842 4843 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4837 class ExportOptions < Struct.new( :types, :objects, :include_references_deep) SENSITIVE = [] include Aws::Structure end |
#types ⇒ Array<String>
A list of saved object types to include in the migration. Valid
values include dashboard, visualization, index-pattern,
search, and query.
4837 4838 4839 4840 4841 4842 4843 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4837 class ExportOptions < Struct.new( :types, :objects, :include_references_deep) SENSITIVE = [] include Aws::Structure end |