Class: Aws::OpenSearchService::Types::GetApplicationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::GetApplicationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_configs ⇒ Array<Types::AppConfig>
The configuration settings of the OpenSearch application.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the domain.
-
#created_at ⇒ Time
The timestamp when the OpenSearch application was created.
-
#data_sources ⇒ Array<Types::DataSource>
The data sources associated with the OpenSearch application.
-
#endpoint ⇒ String
The endpoint URL of the OpenSearch application.
-
#iam_identity_center_options ⇒ Types::IamIdentityCenterOptions
The IAM Identity Center settings configured for the OpenSearch application.
-
#id ⇒ String
The unique identifier of the OpenSearch application.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the application’s data at rest.
-
#last_updated_at ⇒ Time
The timestamp of the last update to the OpenSearch application.
-
#name ⇒ String
The name of the OpenSearch application.
-
#status ⇒ String
The current status of the OpenSearch application.
Instance Attribute Details
#app_configs ⇒ Array<Types::AppConfig>
The configuration settings of the OpenSearch application.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the domain. See [Identifiers for IAM Entities ][1] in *Using Amazon Web Services Identity and Access Management* for more information.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the OpenSearch application was created.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#data_sources ⇒ Array<Types::DataSource>
The data sources associated with the OpenSearch application.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint URL of the OpenSearch application.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#iam_identity_center_options ⇒ Types::IamIdentityCenterOptions
The IAM Identity Center settings configured for the OpenSearch application.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the OpenSearch application.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the application’s data at rest.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of the last update to the OpenSearch application.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the OpenSearch application.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the OpenSearch application. Possible values: ‘CREATING`, `UPDATING`, `DELETING`, `FAILED`, `ACTIVE`, and `DELETED`.
4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4494 class GetApplicationResponse < Struct.new( :id, :arn, :name, :endpoint, :status, :iam_identity_center_options, :data_sources, :app_configs, :created_at, :last_updated_at, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |