Class: Aws::OpenSearchService::Types::GetIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::GetIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an OpenSearch Service domain.
-
#index_name ⇒ String
The name of the index to retrieve information about.
Instance Attribute Details
#domain_name ⇒ String
The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.
5243 5244 5245 5246 5247 5248 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5243 class GetIndexRequest < Struct.new( :domain_name, :index_name) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to retrieve information about.
5243 5244 5245 5246 5247 5248 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5243 class GetIndexRequest < Struct.new( :domain_name, :index_name) SENSITIVE = [] include Aws::Structure end |