Class: Aws::OpenSearchService::Types::GetIndexRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.

Returns:

  • (String)


4911
4912
4913
4914
4915
4916
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4911

class GetIndexRequest < Struct.new(
  :domain_name,
  :index_name)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the index to retrieve information about.

Returns:

  • (String)


4911
4912
4913
4914
4915
4916
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4911

class GetIndexRequest < Struct.new(
  :domain_name,
  :index_name)
  SENSITIVE = []
  include Aws::Structure
end