Class: Aws::OpenSearchService::Types::GetPackageVersionHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Container for the request parameters to the GetPackageVersionHistory operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

Returns:

  • (Integer)


4518
4519
4520
4521
4522
4523
4524
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4518

class GetPackageVersionHistoryRequest < Struct.new(
  :package_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your initial GetPackageVersionHistory operation returns a nextToken, you can include the returned nextToken in subsequent GetPackageVersionHistory operations, which returns results in the next page.

Returns:

  • (String)


4518
4519
4520
4521
4522
4523
4524
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4518

class GetPackageVersionHistoryRequest < Struct.new(
  :package_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#package_idString

The unique identifier of the package.

Returns:

  • (String)


4518
4519
4520
4521
4522
4523
4524
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4518

class GetPackageVersionHistoryRequest < Struct.new(
  :package_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end