Class: Aws::OpenSearchService::Types::GetPackageVersionHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::GetPackageVersionHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the request parameters to the GetPackageVersionHistory operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
GetPackageVersionHistoryoperation returns anextToken, you can include the returnednextTokenin subsequentGetPackageVersionHistoryoperations, which returns results in the next page. -
#package_id ⇒ String
The unique identifier of the package.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.
4518 4519 4520 4521 4522 4523 4524 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4518 class GetPackageVersionHistoryRequest < Struct.new( :package_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial GetPackageVersionHistory operation returns a nextToken, you can include the returned nextToken in subsequent GetPackageVersionHistory operations, which returns results in the next page.
4518 4519 4520 4521 4522 4523 4524 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4518 class GetPackageVersionHistoryRequest < Struct.new( :package_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#package_id ⇒ String
The unique identifier of the package.
4518 4519 4520 4521 4522 4523 4524 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4518 class GetPackageVersionHistoryRequest < Struct.new( :package_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |