Class: Aws::OpenSearchService::Types::GetUpgradeHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::GetUpgradeHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the request parameters to the GetUpgradeHistory operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an existing domain.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
GetUpgradeHistoryoperation returns anextToken, you can include the returnednextTokenin subsequentGetUpgradeHistoryoperations, which returns results in the next page.
Instance Attribute Details
#domain_name ⇒ String
The name of an existing domain.
4576 4577 4578 4579 4580 4581 4582 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4576 class GetUpgradeHistoryRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.
4576 4577 4578 4579 4580 4581 4582 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4576 class GetUpgradeHistoryRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial GetUpgradeHistory operation returns a nextToken, you can include the returned nextToken in subsequent GetUpgradeHistory operations, which returns results in the next page.
4576 4577 4578 4579 4580 4581 4582 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4576 class GetUpgradeHistoryRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |