Class: Aws::OpenSearchService::Types::GetUpgradeHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::GetUpgradeHistoryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the response returned by the GetUpgradeHistory operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
When
nextTokenis returned, there are more results available. -
#upgrade_histories ⇒ Array<Types::UpgradeHistory>
A list of objects corresponding to each upgrade or upgrade eligibility check performed on a domain.
Instance Attribute Details
#next_token ⇒ String
When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.
4601 4602 4603 4604 4605 4606 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4601 class GetUpgradeHistoryResponse < Struct.new( :upgrade_histories, :next_token) SENSITIVE = [] include Aws::Structure end |
#upgrade_histories ⇒ Array<Types::UpgradeHistory>
A list of objects corresponding to each upgrade or upgrade eligibility check performed on a domain.
4601 4602 4603 4604 4605 4606 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 4601 class GetUpgradeHistoryResponse < Struct.new( :upgrade_histories, :next_token) SENSITIVE = [] include Aws::Structure end |