Class: Aws::OpenSearchService::Types::InsightFeedbackEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::InsightFeedbackEntity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Specifies the entity for which to submit insight feedback. An entity represents an Amazon OpenSearch Service domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
The type of the entity.
-
#value ⇒ String
The value of the entity, such as a domain name.
Instance Attribute Details
#type ⇒ String
The type of the entity. Possible values are DomainName.
5912 5913 5914 5915 5916 5917 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5912 class InsightFeedbackEntity < Struct.new( :type, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the entity, such as a domain name.
5912 5913 5914 5915 5916 5917 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5912 class InsightFeedbackEntity < Struct.new( :type, :value) SENSITIVE = [] include Aws::Structure end |