Class: Aws::OpenSearchService::Types::ListDataSourceAttachmentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListDataSourceAttachmentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier or name of the OpenSearch application to list attachments for.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The pagination token from a previous call to retrieve the next set of results.
Instance Attribute Details
#id ⇒ String
The unique identifier or name of the OpenSearch application to list attachments for.
6312 6313 6314 6315 6316 6317 6318 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6312 class ListDataSourceAttachmentsRequest < Struct.new( :id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default is 50.
6312 6313 6314 6315 6316 6317 6318 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6312 class ListDataSourceAttachmentsRequest < Struct.new( :id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from a previous call to retrieve the next set of results.
6312 6313 6314 6315 6316 6317 6318 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6312 class ListDataSourceAttachmentsRequest < Struct.new( :id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |