Class: Aws::OpenSearchService::Types::ListDirectQueryDataSourcesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.

Returns:

  • (String)


5287
5288
5289
5290
5291
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5287

class ListDirectQueryDataSourcesRequest < Struct.new(
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end