Class: Aws::OpenSearchService::Types::ListDirectQueryDataSourcesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListDirectQueryDataSourcesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#direct_query_data_sources ⇒ Array<Types::DirectQueryDataSource>
A list of the direct query data sources that are returned by the
ListDirectQueryDataSourcesAPI operation. -
#next_token ⇒ String
When
nextTokenis returned, there are more results available.
Instance Attribute Details
#direct_query_data_sources ⇒ Array<Types::DirectQueryDataSource>
A list of the direct query data sources that are returned by the ListDirectQueryDataSources API operation.
5307 5308 5309 5310 5311 5312 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5307 class ListDirectQueryDataSourcesResponse < Struct.new( :next_token, :direct_query_data_sources) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.
5307 5308 5309 5310 5311 5312 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5307 class ListDirectQueryDataSourcesResponse < Struct.new( :next_token, :direct_query_data_sources) SENSITIVE = [] include Aws::Structure end |