Class: Aws::OpenSearchService::Types::ListDomainMaintenancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListDomainMaintenancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters to the ListDomainMaintenances operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The name of the action.
-
#domain_name ⇒ String
The name of the domain.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListDomainMaintenancesoperation returns anextToken, include the returnednextTokenin subsequentListDomainMaintenancesoperations, which returns results in the next page. -
#status ⇒ String
The status of the action.
Instance Attribute Details
#action ⇒ String
The name of the action.
5422 5423 5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5422 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain.
5422 5423 5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5422 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.
5422 5423 5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5422 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListDomainMaintenances operation returns a nextToken, include the returned nextToken in subsequent ListDomainMaintenances operations, which returns results in the next page.
5422 5423 5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5422 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the action.
5422 5423 5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5422 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |