Class: Aws::OpenSearchService::Types::ListDomainMaintenancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListDomainMaintenancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters to the ListDomainMaintenances operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The name of the action.
-
#domain_name ⇒ String
The name of the domain.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListDomainMaintenancesoperation returns anextToken, include the returnednextTokenin subsequentListDomainMaintenancesoperations, which returns results in the next page. -
#status ⇒ String
The status of the action.
Instance Attribute Details
#action ⇒ String
The name of the action.
5393 5394 5395 5396 5397 5398 5399 5400 5401 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5393 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain.
5393 5394 5395 5396 5397 5398 5399 5400 5401 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5393 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.
5393 5394 5395 5396 5397 5398 5399 5400 5401 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5393 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListDomainMaintenances operation returns a nextToken, include the returned nextToken in subsequent ListDomainMaintenances operations, which returns results in the next page.
5393 5394 5395 5396 5397 5398 5399 5400 5401 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5393 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the action.
5393 5394 5395 5396 5397 5398 5399 5400 5401 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5393 class ListDomainMaintenancesRequest < Struct.new( :domain_name, :action, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |