Class: Aws::OpenSearchService::Types::ListInsightsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListInsightsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the parameters to the ListInsights operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity ⇒ Types::InsightEntity
The entity for which to list insights.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListInsightsoperation returns aNextToken, include the returnedNextTokenin subsequentListInsightsoperations to retrieve the next page of results. -
#sort_order ⇒ String
The sort order for the results.
-
#time_range ⇒ Types::InsightTimeRange
The time range for filtering insights, specified as epoch millisecond timestamps.
Instance Attribute Details
#entity ⇒ Types::InsightEntity
The entity for which to list insights. Specifies the type and value of the entity, such as a domain name or Amazon Web Services account ID.
6580 6581 6582 6583 6584 6585 6586 6587 6588 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580 class ListInsightsRequest < Struct.new( :entity, :time_range, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use NextToken to get the next page of results.
Valid values are 1 to 500.
6580 6581 6582 6583 6584 6585 6586 6587 6588 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580 class ListInsightsRequest < Struct.new( :entity, :time_range, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListInsights operation returns a NextToken,
include the returned NextToken in subsequent ListInsights
operations to retrieve the next page of results.
6580 6581 6582 6583 6584 6585 6586 6587 6588 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580 class ListInsightsRequest < Struct.new( :entity, :time_range, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for the results. Possible values are ASC
(ascending) and DESC (descending).
6580 6581 6582 6583 6584 6585 6586 6587 6588 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580 class ListInsightsRequest < Struct.new( :entity, :time_range, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#time_range ⇒ Types::InsightTimeRange
The time range for filtering insights, specified as epoch millisecond timestamps.
6580 6581 6582 6583 6584 6585 6586 6587 6588 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6580 class ListInsightsRequest < Struct.new( :entity, :time_range, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |