Class: Aws::OpenSearchService::Types::ListInsightsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListInsightsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The result of a ListInsights request. Contains the list of insights
and a pagination token for retrieving the next page of results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#insights ⇒ Array<Types::Insight>
The list of insights returned for the specified entity.
-
#next_token ⇒ String
When
NextTokenis returned, there are more results available.
Instance Attribute Details
#insights ⇒ Array<Types::Insight>
The list of insights returned for the specified entity.
6606 6607 6608 6609 6610 6611 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6606 class ListInsightsResponse < Struct.new( :insights, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When NextToken is returned, there are more results available. The
value of NextToken is a unique pagination token for each page.
Send the request again using the returned token to retrieve the next
page.
6606 6607 6608 6609 6610 6611 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6606 class ListInsightsResponse < Struct.new( :insights, :next_token) SENSITIVE = [] include Aws::Structure end |