Class: Aws::OpenSearchService::Types::ListInstanceTypeDetailsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListInstanceTypeDetailsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of the domain.
-
#engine_version ⇒ String
The version of OpenSearch or Elasticsearch, in the format Elasticsearch_X.Y or OpenSearch_X.Y.
-
#instance_type ⇒ String
An optional parameter that lists information for a given instance type.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListInstanceTypeDetailsoperation returns anextToken, you can include the returnednextTokenin subsequentListInstanceTypeDetailsoperations, which returns results in the next page. -
#retrieve_a_zs ⇒ Boolean
An optional parameter that specifies the Availability Zones for the domain.
Instance Attribute Details
#domain_name ⇒ String
The name of the domain.
5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5564 class ListInstanceTypeDetailsRequest < Struct.new( :engine_version, :domain_name, :max_results, :next_token, :retrieve_a_zs, :instance_type) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version of OpenSearch or Elasticsearch, in the format Elasticsearch_X.Y or OpenSearch_X.Y. Defaults to the latest version of OpenSearch.
5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5564 class ListInstanceTypeDetailsRequest < Struct.new( :engine_version, :domain_name, :max_results, :next_token, :retrieve_a_zs, :instance_type) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
An optional parameter that lists information for a given instance type.
5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5564 class ListInstanceTypeDetailsRequest < Struct.new( :engine_version, :domain_name, :max_results, :next_token, :retrieve_a_zs, :instance_type) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.
5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5564 class ListInstanceTypeDetailsRequest < Struct.new( :engine_version, :domain_name, :max_results, :next_token, :retrieve_a_zs, :instance_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListInstanceTypeDetails operation returns a nextToken, you can include the returned nextToken in subsequent ListInstanceTypeDetails operations, which returns results in the next page.
5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5564 class ListInstanceTypeDetailsRequest < Struct.new( :engine_version, :domain_name, :max_results, :next_token, :retrieve_a_zs, :instance_type) SENSITIVE = [] include Aws::Structure end |
#retrieve_a_zs ⇒ Boolean
An optional parameter that specifies the Availability Zones for the domain.
5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5564 class ListInstanceTypeDetailsRequest < Struct.new( :engine_version, :domain_name, :max_results, :next_token, :retrieve_a_zs, :instance_type) SENSITIVE = [] include Aws::Structure end |