Class: Aws::OpenSearchService::Types::ListInstanceTypeDetailsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListInstanceTypeDetailsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_type_details ⇒ Array<Types::InstanceTypeDetails>
Lists all supported instance types and features for the given OpenSearch or Elasticsearch version.
-
#next_token ⇒ String
When
nextTokenis returned, there are more results available.
Instance Attribute Details
#instance_type_details ⇒ Array<Types::InstanceTypeDetails>
Lists all supported instance types and features for the given OpenSearch or Elasticsearch version.
5568 5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5568 class ListInstanceTypeDetailsResponse < Struct.new( :instance_type_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.
5568 5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5568 class ListInstanceTypeDetailsResponse < Struct.new( :instance_type_details, :next_token) SENSITIVE = [] include Aws::Structure end |