Class: Aws::OpenSearchService::Types::ListMigrationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListMigrationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The unique identifier of the OpenSearch application to list migrations for.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The pagination token from a previous call to retrieve the next set of results.
-
#status ⇒ String
Filters the results by migration status.
Instance Attribute Details
#application_id ⇒ String
The unique identifier of the OpenSearch application to list migrations for.
6700 6701 6702 6703 6704 6705 6706 6707 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6700 class ListMigrationsRequest < Struct.new( :application_id, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
6700 6701 6702 6703 6704 6705 6706 6707 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6700 class ListMigrationsRequest < Struct.new( :application_id, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from a previous call to retrieve the next set of results.
6700 6701 6702 6703 6704 6705 6706 6707 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6700 class ListMigrationsRequest < Struct.new( :application_id, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filters the results by migration status. Valid values are PENDING,
IN_PROGRESS, SUCCEEDED, and FAILED.
6700 6701 6702 6703 6704 6705 6706 6707 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6700 class ListMigrationsRequest < Struct.new( :application_id, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |