Class: Aws::OpenSearchService::Types::ListScheduledActionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ListScheduledActionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of the domain.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListScheduledActionsoperation returns anextToken, you can include the returnednextTokenin subsequentListScheduledActionsoperations, which returns results in the next page.
Instance Attribute Details
#domain_name ⇒ String
The name of the domain.
6798 6799 6800 6801 6802 6803 6804 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6798 class ListScheduledActionsRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use nextToken to get the next page of results.
6798 6799 6800 6801 6802 6803 6804 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6798 class ListScheduledActionsRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListScheduledActions operation returns a
nextToken, you can include the returned nextToken in subsequent
ListScheduledActions operations, which returns results in the next
page.
6798 6799 6800 6801 6802 6803 6804 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 6798 class ListScheduledActionsRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |