Class: Aws::OpenSearchService::Types::ListVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Container for the request parameters to the ListVersions operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.



5669
5670
5671
5672
5673
5674
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5669

class ListVersionsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your initial ListVersions operation returns a nextToken, you can include the returned nextToken in subsequent ListVersions operations, which returns results in the next page.



5669
5670
5671
5672
5673
5674
# File 'lib/aws-sdk-opensearchservice/types.rb', line 5669

class ListVersionsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end