Class: Aws::OpenSearchService::Types::MigrationOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::MigrationOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The configuration options for a saved objects migration job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conflict_resolution ⇒ String
The strategy for resolving conflicts when saved objects already exist in the target workspace.
-
#export_options ⇒ Types::ExportOptions
Options to filter the scope of saved objects to export from the source.
-
#source ⇒ Types::MigrationSource
The data source from which to export saved objects.
-
#workspace ⇒ Types::MigrationWorkspace
The target workspace configuration for importing saved objects.
Instance Attribute Details
#conflict_resolution ⇒ String
The strategy for resolving conflicts when saved objects already
exist in the target workspace. Valid values are CREATE_NEW_COPIES,
which creates new objects with unique IDs, and overwrite, which
replaces existing objects.
7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7147 class MigrationOptions < Struct.new( :source, :workspace, :export_options, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#export_options ⇒ Types::ExportOptions
Options to filter the scope of saved objects to export from the source.
7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7147 class MigrationOptions < Struct.new( :source, :workspace, :export_options, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::MigrationSource
The data source from which to export saved objects.
7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7147 class MigrationOptions < Struct.new( :source, :workspace, :export_options, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#workspace ⇒ Types::MigrationWorkspace
The target workspace configuration for importing saved objects. You can specify an existing workspace or request creation of a new workspace.
7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7147 class MigrationOptions < Struct.new( :source, :workspace, :export_options, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |