Class: Aws::OpenSearchService::Types::MigrationSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::MigrationSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The source configuration for a migration, specifying the data source from which to export saved objects.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#datasource_arn ⇒ String
The Amazon Resource Name (ARN) of the data source to migrate saved objects from.
Instance Attribute Details
#datasource_arn ⇒ String
The Amazon Resource Name (ARN) of the data source to migrate saved objects from.
7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7166 class MigrationSource < Struct.new( :datasource_arn) SENSITIVE = [] include Aws::Structure end |