Class: Aws::OpenSearchService::Types::MigrationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::MigrationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
A summary of a migration job, including its status and progress.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The unique identifier of the OpenSearch application associated with the migration.
-
#created_at ⇒ Time
The date and time when the migration job was created.
-
#error ⇒ Types::MigrationError
Error details if the migration failed or completed with errors.
-
#exported_count ⇒ Integer
The number of saved objects exported from the source data source.
-
#imported_count ⇒ Integer
The number of saved objects successfully imported into the target workspace.
-
#migration_id ⇒ String
The unique identifier of the migration job.
-
#source ⇒ Types::MigrationSource
The source configuration for the migration.
-
#status ⇒ String
The current status of the migration job.
-
#updated_at ⇒ Time
The date and time when the migration job was last updated.
Instance Attribute Details
#application_id ⇒ String
The unique identifier of the OpenSearch application associated with the migration.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the migration job was created.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#error ⇒ Types::MigrationError
Error details if the migration failed or completed with errors.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#exported_count ⇒ Integer
The number of saved objects exported from the source data source.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#imported_count ⇒ Integer
The number of saved objects successfully imported into the target workspace.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#migration_id ⇒ String
The unique identifier of the migration job.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::MigrationSource
The source configuration for the migration.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the migration job.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the migration job was last updated.
7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7214 class MigrationSummary < Struct.new( :migration_id, :status, :application_id, :source, :exported_count, :imported_count, :error, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |