Class: Aws::OpenSearchService::Types::MigrationWorkspace
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::MigrationWorkspace
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The target workspace configuration for a migration. You can specify an existing workspace by ID or request creation of a new workspace.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_workspace ⇒ Boolean
Specifies whether to create a new workspace as the migration target.
-
#name ⇒ String
The name of the new workspace to create.
-
#type ⇒ String
The type of the new workspace to create.
-
#workspace_id ⇒ String
The unique identifier of an existing workspace to use as the migration target.
Instance Attribute Details
#create_workspace ⇒ Boolean
Specifies whether to create a new workspace as the migration target.
If true, you must also specify name.
7253 7254 7255 7256 7257 7258 7259 7260 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7253 class MigrationWorkspace < Struct.new( :workspace_id, :create_workspace, :name, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the new workspace to create. Required when
createWorkspace is true.
7253 7254 7255 7256 7257 7258 7259 7260 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7253 class MigrationWorkspace < Struct.new( :workspace_id, :create_workspace, :name, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the new workspace to create.
7253 7254 7255 7256 7257 7258 7259 7260 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7253 class MigrationWorkspace < Struct.new( :workspace_id, :create_workspace, :name, :type) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The unique identifier of an existing workspace to use as the
migration target. Specify either this parameter or
createWorkspace.
7253 7254 7255 7256 7257 7258 7259 7260 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7253 class MigrationWorkspace < Struct.new( :workspace_id, :create_workspace, :name, :type) SENSITIVE = [] include Aws::Structure end |