Class: Aws::OpenSearchService::Types::ReservedInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ReservedInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Details of an OpenSearch Reserved Instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_subscription_id ⇒ Integer
The unique identifier of the billing subscription.
-
#currency_code ⇒ String
The currency code for the offering.
-
#duration ⇒ Integer
The duration, in seconds, for which the OpenSearch instance is reserved.
-
#fixed_price ⇒ Float
The upfront fixed charge you will paid to purchase the specific Reserved Instance offering.
-
#instance_count ⇒ Integer
The number of OpenSearch instances that have been reserved.
-
#instance_type ⇒ String
The OpenSearch instance type offered by theReserved Instance offering.
-
#payment_option ⇒ String
The payment option as defined in the Reserved Instance offering.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring charge to your account, regardless of whether you create any domains using the Reserved Instance offering.
-
#reservation_name ⇒ String
The customer-specified identifier to track this reservation.
-
#reserved_instance_id ⇒ String
The unique identifier for the reservation.
-
#reserved_instance_offering_id ⇒ String
The unique identifier of the Reserved Instance offering.
-
#start_time ⇒ Time
The date and time when the reservation was purchased.
-
#state ⇒ String
The state of the Reserved Instance.
-
#usage_price ⇒ Float
The hourly rate at which you’re charged for the domain using this Reserved Instance.
Instance Attribute Details
#billing_subscription_id ⇒ Integer
The unique identifier of the billing subscription.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency code for the offering.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration, in seconds, for which the OpenSearch instance is reserved.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The upfront fixed charge you will paid to purchase the specific Reserved Instance offering.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of OpenSearch instances that have been reserved.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The OpenSearch instance type offered by theReserved Instance offering.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option as defined in the Reserved Instance offering.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring charge to your account, regardless of whether you create any domains using the Reserved Instance offering.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#reservation_name ⇒ String
The customer-specified identifier to track this reservation.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#reserved_instance_id ⇒ String
The unique identifier for the reservation.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#reserved_instance_offering_id ⇒ String
The unique identifier of the Reserved Instance offering.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time when the reservation was purchased.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the Reserved Instance.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The hourly rate at which you’re charged for the domain using this Reserved Instance.
7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7402 class ReservedInstance < Struct.new( :reservation_name, :reserved_instance_id, :billing_subscription_id, :reserved_instance_offering_id, :instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |