Class: Aws::OpenSearchService::Types::RollbackServiceSoftwareOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::RollbackServiceSoftwareOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Details about the rollback options for a service software update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_version ⇒ String
The current service software version on the domain.
-
#description ⇒ String
A description of the rollback status.
-
#new_version ⇒ String
The service software version that the domain will roll back to.
-
#rollback_available ⇒ Boolean
Whether a service software rollback is available for the domain.
Instance Attribute Details
#current_version ⇒ String
The current service software version on the domain.
7499 7500 7501 7502 7503 7504 7505 7506 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7499 class RollbackServiceSoftwareOptions < Struct.new( :current_version, :new_version, :rollback_available, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the rollback status.
7499 7500 7501 7502 7503 7504 7505 7506 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7499 class RollbackServiceSoftwareOptions < Struct.new( :current_version, :new_version, :rollback_available, :description) SENSITIVE = [] include Aws::Structure end |
#new_version ⇒ String
The service software version that the domain will roll back to.
7499 7500 7501 7502 7503 7504 7505 7506 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7499 class RollbackServiceSoftwareOptions < Struct.new( :current_version, :new_version, :rollback_available, :description) SENSITIVE = [] include Aws::Structure end |
#rollback_available ⇒ Boolean
Whether a service software rollback is available for the domain.
7499 7500 7501 7502 7503 7504 7505 7506 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7499 class RollbackServiceSoftwareOptions < Struct.new( :current_version, :new_version, :rollback_available, :description) SENSITIVE = [] include Aws::Structure end |