Class: Aws::OpenSearchService::Types::SavedObjectIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::SavedObjectIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Identifies a specific saved object by its type and unique identifier.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier of the saved object.
-
#type ⇒ String
The type of the saved object, such as
dashboard,visualization,index-pattern,search, orquery.
Instance Attribute Details
#id ⇒ String
The unique identifier of the saved object.
8553 8554 8555 8556 8557 8558 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8553 class SavedObjectIdentifier < Struct.new( :type, :id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the saved object, such as dashboard, visualization,
index-pattern, search, or query.
8553 8554 8555 8556 8557 8558 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8553 class SavedObjectIdentifier < Struct.new( :type, :id) SENSITIVE = [] include Aws::Structure end |