Class: Aws::OpenSearchService::Types::ServiceSoftwareOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::ServiceSoftwareOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
The current status of the service software for an Amazon OpenSearch Service domain. For more information, see [Service software updates in Amazon OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automated_update_date ⇒ Time
The timestamp, in Epoch time, until which you can manually request a service software update.
-
#cancellable ⇒ Boolean
True if you’re able to cancel your service software version update.
-
#current_version ⇒ String
The current service software version present on the domain.
-
#description ⇒ String
A description of the service software update status.
-
#new_version ⇒ String
The new service software version, if one is available.
-
#optional_deployment ⇒ Boolean
True if a service software is never automatically updated.
-
#update_available ⇒ Boolean
True if you’re able to update your service software version.
-
#update_status ⇒ String
The status of your service software update.
Instance Attribute Details
#automated_update_date ⇒ Time
The timestamp, in Epoch time, until which you can manually request a service software update. After this date, we automatically update your service software.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7903 class ServiceSoftwareOptions < Struct.new( :current_version, :new_version, :update_available, :cancellable, :update_status, :description, :automated_update_date, :optional_deployment) SENSITIVE = [] include Aws::Structure end |
#cancellable ⇒ Boolean
True if you’re able to cancel your service software version update. False if you can’t cancel your service software update.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7903 class ServiceSoftwareOptions < Struct.new( :current_version, :new_version, :update_available, :cancellable, :update_status, :description, :automated_update_date, :optional_deployment) SENSITIVE = [] include Aws::Structure end |
#current_version ⇒ String
The current service software version present on the domain.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7903 class ServiceSoftwareOptions < Struct.new( :current_version, :new_version, :update_available, :cancellable, :update_status, :description, :automated_update_date, :optional_deployment) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the service software update status.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7903 class ServiceSoftwareOptions < Struct.new( :current_version, :new_version, :update_available, :cancellable, :update_status, :description, :automated_update_date, :optional_deployment) SENSITIVE = [] include Aws::Structure end |
#new_version ⇒ String
The new service software version, if one is available.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7903 class ServiceSoftwareOptions < Struct.new( :current_version, :new_version, :update_available, :cancellable, :update_status, :description, :automated_update_date, :optional_deployment) SENSITIVE = [] include Aws::Structure end |
#optional_deployment ⇒ Boolean
True if a service software is never automatically updated. False if a service software is automatically updated after the automated update date.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7903 class ServiceSoftwareOptions < Struct.new( :current_version, :new_version, :update_available, :cancellable, :update_status, :description, :automated_update_date, :optional_deployment) SENSITIVE = [] include Aws::Structure end |
#update_available ⇒ Boolean
True if you’re able to update your service software version. False if you can’t update your service software version.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7903 class ServiceSoftwareOptions < Struct.new( :current_version, :new_version, :update_available, :cancellable, :update_status, :description, :automated_update_date, :optional_deployment) SENSITIVE = [] include Aws::Structure end |
#update_status ⇒ String
The status of your service software update.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7903 class ServiceSoftwareOptions < Struct.new( :current_version, :new_version, :update_available, :cancellable, :update_status, :description, :automated_update_date, :optional_deployment) SENSITIVE = [] include Aws::Structure end |