Class: Aws::OpenSearchService::Types::SoftwareUpdateOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::SoftwareUpdateOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Options for configuring service software updates for a domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_software_update_enabled ⇒ Boolean
Whether automatic service software updates are enabled for the domain.
-
#use_latest_service_software_for_blue_green ⇒ Boolean
Whether the domain should use the latest service software version during a blue/green deployment.
Instance Attribute Details
#auto_software_update_enabled ⇒ Boolean
Whether automatic service software updates are enabled for the domain.
7942 7943 7944 7945 7946 7947 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7942 class SoftwareUpdateOptions < Struct.new( :auto_software_update_enabled, :use_latest_service_software_for_blue_green) SENSITIVE = [] include Aws::Structure end |
#use_latest_service_software_for_blue_green ⇒ Boolean
Whether the domain should use the latest service software version during a blue/green deployment. If enabled, the domain will automatically use the latest available service software when a blue/green deployment is triggered.
7942 7943 7944 7945 7946 7947 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 7942 class SoftwareUpdateOptions < Struct.new( :auto_software_update_enabled, :use_latest_service_software_for_blue_green) SENSITIVE = [] include Aws::Structure end |