Class: Aws::OpenSearchService::Types::UpdateDirectQueryDataSourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::UpdateDirectQueryDataSourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_access_policy ⇒ String
An optional IAM access policy document that defines the updated permissions for accessing the direct query data source.
-
#data_source_name ⇒ String
A unique, user-defined label to identify the data source within your OpenSearch Service environment.
-
#data_source_type ⇒ Types::DirectQueryDataSourceType
The supported Amazon Web Services service that you want to use as the source for direct queries in OpenSearch Service.
-
#description ⇒ String
An optional text field for providing additional context and details about the data source.
-
#open_search_arns ⇒ Array<String>
An optional list of Amazon Resource Names (ARNs) for the OpenSearch collections that are associated with the direct query data source.
Instance Attribute Details
#data_source_access_policy ⇒ String
An optional IAM access policy document that defines the updated permissions for accessing the direct query data source. The policy document must be in valid JSON format and follow IAM policy syntax. If not specified, the existing access policy if present remains unchanged.
8375 8376 8377 8378 8379 8380 8381 8382 8383 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8375 class UpdateDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy) SENSITIVE = [] include Aws::Structure end |
#data_source_name ⇒ String
A unique, user-defined label to identify the data source within your OpenSearch Service environment.
8375 8376 8377 8378 8379 8380 8381 8382 8383 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8375 class UpdateDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy) SENSITIVE = [] include Aws::Structure end |
#data_source_type ⇒ Types::DirectQueryDataSourceType
The supported Amazon Web Services service that you want to use as the source for direct queries in OpenSearch Service.
8375 8376 8377 8378 8379 8380 8381 8382 8383 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8375 class UpdateDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional text field for providing additional context and details about the data source.
8375 8376 8377 8378 8379 8380 8381 8382 8383 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8375 class UpdateDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy) SENSITIVE = [] include Aws::Structure end |
#open_search_arns ⇒ Array<String>
An optional list of Amazon Resource Names (ARNs) for the OpenSearch collections that are associated with the direct query data source. This field is required for CloudWatchLogs and SecurityLake datasource types.
8375 8376 8377 8378 8379 8380 8381 8382 8383 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8375 class UpdateDirectQueryDataSourceRequest < Struct.new( :data_source_name, :data_source_type, :description, :open_search_arns, :data_source_access_policy) SENSITIVE = [] include Aws::Structure end |