Class: Aws::OpenSearchService::Types::UpdateDomainConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Container for the request parameters to the ‘UpdateDomain` operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_policiesString

Identity and Access Management (IAM) access policy as a JSON-formatted string.

Returns:

  • (String)


8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#advanced_optionsHash<String,String>

Key-value pairs to specify advanced configuration options. The following key-value pairs are supported:

  • ‘“rest.action.multi.allow_explicit_index”: “true” | “false”` - Note the use of a string rather than a boolean. Specifies whether explicit references to indexes are allowed inside the body of HTTP requests. If you want to configure access policies for domain sub-resources, such as specific indexes and domain APIs, you must disable this property. Default is true.

  • ‘“indices.fielddata.cache.size”: “80” ` - Note the use of a string rather than a boolean. Specifies the percentage of heap space allocated to field data. Default is unbounded.

  • ‘“indices.query.bool.max_clause_count”: “1024”` - Note the use of a string rather than a boolean. Specifies the maximum number of clauses allowed in a Lucene boolean query. Default is 1,024. Queries with more than the permitted number of clauses result in a `TooManyClauses` error.

For more information, see [Advanced cluster parameters].

[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/createupdatedomains.html#createdomain-configure-advanced-options

Returns:

  • (Hash<String,String>)


8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#advanced_security_optionsTypes::AdvancedSecurityOptionsInput

Options for fine-grained access control.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#aiml_optionsTypes::AIMLOptionsInput

Options for all machine learning features for the specified domain.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#auto_tune_optionsTypes::AutoTuneOptions

Options for Auto-Tune.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_configTypes::ClusterConfig

Changes that you want to make to the cluster configuration, such as the instance type and number of EC2 instances.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#cognito_optionsTypes::CognitoOptions

Key-value pairs to configure Amazon Cognito authentication for OpenSearch Dashboards.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_strategy_optionsTypes::DeploymentStrategyOptions

Specifies the deployment strategy options for the domain.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_endpoint_optionsTypes::DomainEndpointOptions

Additional options for the domain endpoint, such as whether to require HTTPS for all traffic.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The name of the domain that you’re updating.

Returns:

  • (String)


8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

This flag, when set to True, specifies whether the ‘UpdateDomain` request should return the results of a dry run analysis without actually applying the change. A dry run determines what type of deployment the update will cause.

Returns:

  • (Boolean)


8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#dry_run_modeString

The type of dry run to perform.

  • ‘Basic` only returns the type of deployment (blue/green or dynamic) that the update will cause.

  • ‘Verbose` runs an additional check to validate the changes you’re making. For more information, see [Validating a domain update].

[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-configuration-changes#validation-check

Returns:

  • (String)


8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_optionsTypes::EBSOptions

The type and size of the EBS volume to attach to instances in the domain.

Returns:



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_at_rest_optionsTypes::EncryptionAtRestOptions

Encryption at rest options for the domain.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#identity_center_optionsTypes::IdentityCenterOptionsInput

Configuration settings for enabling and managing IAM Identity Center.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

Specify either dual stack or IPv4 as your IP address type. Dual stack allows you to share domain resources across IPv4 and IPv6 address types, and is the recommended option. If your IP address type is currently set to dual stack, you can’t change it.

Returns:

  • (String)


8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#log_publishing_optionsHash<String,Types::LogPublishingOption>

Options to publish OpenSearch logs to Amazon CloudWatch Logs.

Returns:



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#node_to_node_encryption_optionsTypes::NodeToNodeEncryptionOptions

Node-to-node encryption options for the domain.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#off_peak_window_optionsTypes::OffPeakWindowOptions

Off-peak window options for the domain.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_optionsTypes::SnapshotOptions

Option to set the time, in UTC format, for the daily automated snapshot. Default value is ‘0` hours.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#software_update_optionsTypes::SoftwareUpdateOptions

Service software update options for the domain.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_optionsTypes::VPCOptions

Options to specify the subnets and security groups for a VPC endpoint. For more information, see [Launching your Amazon OpenSearch Service domains using a VPC].

[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/vpc.html

Returns:



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8531

class UpdateDomainConfigRequest < Struct.new(
  :domain_name,
  :cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :ip_address_type,
  :log_publishing_options,
  :encryption_at_rest_options,
  :domain_endpoint_options,
  :node_to_node_encryption_options,
  :advanced_security_options,
  :identity_center_options,
  :auto_tune_options,
  :dry_run,
  :dry_run_mode,
  :off_peak_window_options,
  :software_update_options,
  :aiml_options,
  :deployment_strategy_options)
  SENSITIVE = []
  include Aws::Structure
end