Class: Aws::OpenSearchService::Types::UpdateIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::UpdateIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an OpenSearch Service domain.
-
#index_name ⇒ String
The name of the index to update.
-
#index_schema ⇒ Hash, ...
The updated JSON schema for the index including any changes to mappings, settings, and semantic enrichment configuration.
Instance Attribute Details
#domain_name ⇒ String
The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.
8739 8740 8741 8742 8743 8744 8745 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8739 class UpdateIndexRequest < Struct.new( :domain_name, :index_name, :index_schema) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to update.
8739 8740 8741 8742 8743 8744 8745 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8739 class UpdateIndexRequest < Struct.new( :domain_name, :index_name, :index_schema) SENSITIVE = [] include Aws::Structure end |
#index_schema ⇒ Hash, ...
The updated JSON schema for the index including any changes to mappings, settings, and semantic enrichment configuration.
8739 8740 8741 8742 8743 8744 8745 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8739 class UpdateIndexRequest < Struct.new( :domain_name, :index_name, :index_schema) SENSITIVE = [] include Aws::Structure end |