Class: Aws::OpenSearchService::Types::UpdateScheduledActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::UpdateScheduledActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_id ⇒ String
The unique identifier of the action to reschedule.
-
#action_type ⇒ String
The type of action to reschedule.
-
#desired_start_time ⇒ Integer
The time to implement the change, in Coordinated Universal Time (UTC).
-
#domain_name ⇒ String
The name of the domain to reschedule an action for.
-
#schedule_at ⇒ String
When to schedule the action.
Instance Attribute Details
#action_id ⇒ String
The unique identifier of the action to reschedule. To retrieve this ID, send a [ListScheduledActions] request.
[1]: docs.aws.amazon.com/opensearch-service/latest/APIReference/API_ListScheduledActions.html
8767 8768 8769 8770 8771 8772 8773 8774 8775 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8767 class UpdateScheduledActionRequest < Struct.new( :domain_name, :action_id, :action_type, :schedule_at, :desired_start_time) SENSITIVE = [] include Aws::Structure end |
#action_type ⇒ String
The type of action to reschedule. Can be one of ‘SERVICE_SOFTWARE_UPDATE`, `JVM_HEAP_SIZE_TUNING`, or `JVM_YOUNG_GEN_TUNING`. To retrieve this value, send a
- ListScheduledActions][1
-
request.
[1]: docs.aws.amazon.com/opensearch-service/latest/APIReference/API_ListScheduledActions.html
8767 8768 8769 8770 8771 8772 8773 8774 8775 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8767 class UpdateScheduledActionRequest < Struct.new( :domain_name, :action_id, :action_type, :schedule_at, :desired_start_time) SENSITIVE = [] include Aws::Structure end |
#desired_start_time ⇒ Integer
The time to implement the change, in Coordinated Universal Time (UTC). Only specify this parameter if you set ‘ScheduleAt` to `TIMESTAMP`.
8767 8768 8769 8770 8771 8772 8773 8774 8775 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8767 class UpdateScheduledActionRequest < Struct.new( :domain_name, :action_id, :action_type, :schedule_at, :desired_start_time) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain to reschedule an action for.
8767 8768 8769 8770 8771 8772 8773 8774 8775 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8767 class UpdateScheduledActionRequest < Struct.new( :domain_name, :action_id, :action_type, :schedule_at, :desired_start_time) SENSITIVE = [] include Aws::Structure end |
#schedule_at ⇒ String
When to schedule the action.
-
‘NOW` - Immediately schedules the update to happen in the current hour if there’s capacity available.
-
‘TIMESTAMP` - Lets you specify a custom date and time to apply the update. If you specify this value, you must also provide a value for `DesiredStartTime`.
-
‘OFF_PEAK_WINDOW` - Marks the action to be picked up during an upcoming off-peak window. There’s no guarantee that the change will be implemented during the next immediate window. Depending on capacity, it might happen in subsequent days.
8767 8768 8769 8770 8771 8772 8773 8774 8775 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8767 class UpdateScheduledActionRequest < Struct.new( :domain_name, :action_id, :action_type, :schedule_at, :desired_start_time) SENSITIVE = [] include Aws::Structure end |