Class: Aws::OpenSearchService::Types::UpgradeDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::UpgradeDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Container for the request parameters to the ‘UpgradeDomain` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advanced_options ⇒ Hash<String,String>
Only supports the ‘override_main_response_version` parameter and not other advanced options.
-
#domain_name ⇒ String
Name of the OpenSearch Service domain that you want to upgrade.
-
#perform_check_only ⇒ Boolean
When true, indicates that an upgrade eligibility check needs to be performed.
-
#target_version ⇒ String
OpenSearch or Elasticsearch version to which you want to upgrade, in the format Opensearch_X.Y or Elasticsearch_X.Y.
Instance Attribute Details
#advanced_options ⇒ Hash<String,String>
Only supports the ‘override_main_response_version` parameter and not other advanced options. You can only include this option when upgrading to an OpenSearch version. Specifies whether the domain reports its version as 7.10 so that it continues to work with Elasticsearch OSS clients and plugins.
8856 8857 8858 8859 8860 8861 8862 8863 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8856 class UpgradeDomainRequest < Struct.new( :domain_name, :target_version, :perform_check_only, :advanced_options) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
Name of the OpenSearch Service domain that you want to upgrade.
8856 8857 8858 8859 8860 8861 8862 8863 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8856 class UpgradeDomainRequest < Struct.new( :domain_name, :target_version, :perform_check_only, :advanced_options) SENSITIVE = [] include Aws::Structure end |
#perform_check_only ⇒ Boolean
When true, indicates that an upgrade eligibility check needs to be performed. Does not actually perform the upgrade.
8856 8857 8858 8859 8860 8861 8862 8863 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8856 class UpgradeDomainRequest < Struct.new( :domain_name, :target_version, :perform_check_only, :advanced_options) SENSITIVE = [] include Aws::Structure end |
#target_version ⇒ String
OpenSearch or Elasticsearch version to which you want to upgrade, in the format Opensearch_X.Y or Elasticsearch_X.Y.
8856 8857 8858 8859 8860 8861 8862 8863 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8856 class UpgradeDomainRequest < Struct.new( :domain_name, :target_version, :perform_check_only, :advanced_options) SENSITIVE = [] include Aws::Structure end |