Class: Aws::OpenSearchService::Types::UpgradeDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Container for the request parameters to the ‘UpgradeDomain` operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#advanced_optionsHash<String,String>

Only supports the ‘override_main_response_version` parameter and not other advanced options. You can only include this option when upgrading to an OpenSearch version. Specifies whether the domain reports its version as 7.10 so that it continues to work with Elasticsearch OSS clients and plugins.

Returns:

  • (Hash<String,String>)


8802
8803
8804
8805
8806
8807
8808
8809
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8802

class UpgradeDomainRequest < Struct.new(
  :domain_name,
  :target_version,
  :perform_check_only,
  :advanced_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

Name of the OpenSearch Service domain that you want to upgrade.

Returns:

  • (String)


8802
8803
8804
8805
8806
8807
8808
8809
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8802

class UpgradeDomainRequest < Struct.new(
  :domain_name,
  :target_version,
  :perform_check_only,
  :advanced_options)
  SENSITIVE = []
  include Aws::Structure
end

#perform_check_onlyBoolean

When true, indicates that an upgrade eligibility check needs to be performed. Does not actually perform the upgrade.

Returns:

  • (Boolean)


8802
8803
8804
8805
8806
8807
8808
8809
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8802

class UpgradeDomainRequest < Struct.new(
  :domain_name,
  :target_version,
  :perform_check_only,
  :advanced_options)
  SENSITIVE = []
  include Aws::Structure
end

#target_versionString

OpenSearch or Elasticsearch version to which you want to upgrade, in the format Opensearch_X.Y or Elasticsearch_X.Y.

Returns:

  • (String)


8802
8803
8804
8805
8806
8807
8808
8809
# File 'lib/aws-sdk-opensearchservice/types.rb', line 8802

class UpgradeDomainRequest < Struct.new(
  :domain_name,
  :target_version,
  :perform_check_only,
  :advanced_options)
  SENSITIVE = []
  include Aws::Structure
end