Class: Aws::OpenSearchService::Types::VPCOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchservice/types.rb

Overview

Options to specify the subnets and security groups for an Amazon OpenSearch Service VPC endpoint. For more information, see [Launching your Amazon OpenSearch Service domains using a VPC].

[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/vpc.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#egress_enabledBoolean

Controls whether egress traffic from the domain is routed through the customer VPC. When ‘true`, outbound traffic flows through the VPC. When `false`, outbound traffic goes through the public internet.

Returns:

  • (Boolean)


9091
9092
9093
9094
9095
9096
9097
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9091

class VPCOptions < Struct.new(
  :subnet_ids,
  :security_group_ids,
  :egress_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The list of security group IDs associated with the VPC endpoints for the domain. If you do not provide a security group ID, OpenSearch Service uses the default security group for the VPC.

Returns:

  • (Array<String>)


9091
9092
9093
9094
9095
9096
9097
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9091

class VPCOptions < Struct.new(
  :subnet_ids,
  :security_group_ids,
  :egress_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

A list of subnet IDs associated with the VPC endpoints for the domain. If your domain uses multiple Availability Zones, you need to provide two subnet IDs, one per zone. Otherwise, provide only one.

Returns:

  • (Array<String>)


9091
9092
9093
9094
9095
9096
9097
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9091

class VPCOptions < Struct.new(
  :subnet_ids,
  :security_group_ids,
  :egress_enabled)
  SENSITIVE = []
  include Aws::Structure
end