Class: Aws::OpenSearchService::Types::WorkspaceConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchService::Types::WorkspaceConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchservice/types.rb
Overview
Configuration for creating a new workspace when attaching a data source to an OpenSearch application. The workspace is created after the data source is successfully attached.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the workspace to create.
-
#workspace_type ⇒ String
The type of workspace to create, which determines the use-case features enabled for the workspace.
Instance Attribute Details
#name ⇒ String
The name of the workspace to create. Must be between 1 and 40 characters and can contain alphanumeric characters, parentheses, brackets, hyphens, underscores, and spaces.
9707 9708 9709 9710 9711 9712 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9707 class WorkspaceConfigurationInput < Struct.new( :name, :workspace_type) SENSITIVE = [] include Aws::Structure end |
#workspace_type ⇒ String
The type of workspace to create, which determines the use-case features enabled for the workspace. Valid values are ‘OBSERVABILITY`, `SECURITY_ANALYTICS`, and `SEARCH`.
9707 9708 9709 9710 9711 9712 |
# File 'lib/aws-sdk-opensearchservice/types.rb', line 9707 class WorkspaceConfigurationInput < Struct.new( :name, :workspace_type) SENSITIVE = [] include Aws::Structure end |